@@ -291,7 +291,7 @@ void File_Aac::program_config_element()
         {
             Infos["Format_Profile"]=__T("HE-AAC");
             Ztring SamplingRate=Infos["SamplingRate"];
-            Infos["SamplingRate"].From_Number((extension_sampling_frequency_index==(int8u)-1)?(sampling_frequency*2):extension_sampling_frequency, 10);
+            Infos["SamplingRate"].From_Number((extension_sampling_frequency_index==(int8u)-1)?(Frequency_b*2):extension_sampling_frequency, 10);
             if (MediaInfoLib::Config.LegacyStreamDisplay_Get())
             {
                 Infos["Format_Profile"]+=__T(" / LC");
@@ -314,7 +314,7 @@ void File_Aac::program_config_element()
                 Infos["Format_Profile"]+=__T(" / HE-AAC / LC");
                 Infos["Channel(s)"]+=__T(" / ")+Channels+__T(" / ")+Channels;
                 Infos["ChannelPositions"]+=__T(" / ")+ChannelPositions+__T(" / ")+ChannelPositions;
-                Infos["SamplingRate"]=Ztring().From_Number((extension_sampling_frequency_index==(int8u)-1)?(sampling_frequency*2):extension_sampling_frequency, 10)+__T(" / ")+SamplingRate;
+                Infos["SamplingRate"]=Ztring().From_Number((extension_sampling_frequency_index==(int8u)-1)?(Frequency_b*2):extension_sampling_frequency, 10)+__T(" / ")+SamplingRate;
             }
             Infos["Format_Settings_PS"]=__T("Yes (Implicit)");
             Ztring Codec=Retrieve(Stream_Audio, StreamPos_Last, Audio_Codec);
@@ -330,7 +330,7 @@ void File_Aac::program_config_element()
 //---------------------------------------------------------------------------
 void File_Aac::raw_data_block()
 {
-    if (sampling_frequency_index>=16 || Aac_sampling_frequency[sampling_frequency_index]==0)
+    if (sampling_frequency_index>=13)
     {
         Trusted_IsNot("(Problem)");
         Skip_BS(Data_BS_Remain(),                               "(Problem)");
@@ -351,6 +351,12 @@ void File_Aac::raw_data_block()
         Element_Begin0();
         id_syn_ele_Previous=id_syn_ele;
         Get_S1 (3, id_syn_ele,                                  "id_syn_ele"); Param_Info1(Aac_id_syn_ele[id_syn_ele]); Element_Name(Aac_id_syn_ele[id_syn_ele]);
+
+        #if MEDIAINFO_TRACE
+            bool Trace_Activated_Save=Trace_Activated;
+            Trace_Activated=false; //It is too big, disabling trace for now for full AAC parsing
+        #endif //MEDIAINFO_TRACE
+
         switch (id_syn_ele)
         {
             case 0x00 : single_channel_element();           break; //ID_SCE
@@ -363,25 +369,17 @@ void File_Aac::raw_data_block()
             case 0x07 :                                     break; //ID_END
             default   :                                          ; //Can not happen
         }
+
+        #if MEDIAINFO_TRACE
+            Trace_Activated=Trace_Activated_Save;
+        #endif //MEDIAINFO_TRACE
+
         Element_End0();
     }
     while(Element_IsOK() && Data_BS_Remain() && id_syn_ele!=0x07); //ID_END
     if (Element_IsOK() && Data_BS_Remain()%8)
         Skip_S1(Data_BS_Remain()%8,                             "byte_alignment");
     Element_End0();
-
-    if (sampling_frequency)
-    {
-        #if MEDIAINFO_TRACE
-            if (FrameInfo.PTS!=(int64u)-1)
-                Element_Info1(__T("PTS ")+Ztring().Duration_From_Milliseconds(float64_int64s(((float64)FrameInfo.PTS)/1000000)));
-            if (FrameInfo.DTS!=(int64u)-1)
-                Element_Info1(__T("DTS ")+Ztring().Duration_From_Milliseconds(float64_int64s(((float64)FrameInfo.DTS)/1000000)));
-        #endif //MEDIAINFO_TRACE
-        FrameInfo.DUR=float64_int64s(((float64)frame_length)*1000000000/sampling_frequency);
-        FrameInfo.DTS+=FrameInfo.DUR;
-        FrameInfo.PTS=FrameInfo.DTS;
-    }
 }
 
 //---------------------------------------------------------------------------
@@ -1083,6 +1081,7 @@ void File_Aac::extension_payload(size_t End, int8u id_aac)
                                     break;
                         default:    ;
                     }
+                    break;
         case 0 : //EXT_FILL
         default:
             Skip_BS(Data_BS_Remain()-End,                       "other_bits");
