@@ -36,7 +36,7 @@ namespace MediaInfoLib
 extern const char* Aac_audioObjectType(int8u audioObjectType);
 
 //---------------------------------------------------------------------------
-int8u Aac_AudioSpecificConfig_sampling_frequency_index(const int32u sampling_frequency);
+int8u Aac_AudioSpecificConfig_sampling_frequency_index(const int64s sampling_frequency);
 
 //---------------------------------------------------------------------------
 // Master frequency band table
@@ -112,6 +112,8 @@ bool Aac_f_master_Compute_0(int8u &num_env_bands_Master, int8u* f_Master, sbr_ha
 
         while (k2Diff)
         {
+            if (k >= 64)
+                break;
             vDk[k]-=incr;
             k+=incr;
             k2Diff+=incr;
@@ -152,7 +154,7 @@ bool Aac_f_master_Compute(int8u &num_env_bands_Master, int8u* f_Master, sbr_hand
     }
 
     int8u numBands0=2*Aac_bands_Compute(false, bands, k0, k1);
-    if (numBands0>=64)
+    if (numBands0 == 0 || numBands0 >= 64)
         return false;
 
     int8u vDk0[64];
@@ -189,7 +191,7 @@ bool Aac_f_master_Compute(int8u &num_env_bands_Master, int8u* f_Master, sbr_hand
     int8u vDk1[64] = { 0 };
     int8u vk1[64];
     numBands1=2*Aac_bands_Compute(true, bands, k1, k2);
-    if (numBands0+numBands1>=64)
+    if (numBands1 == 0 || numBands0 + numBands1 >= 64)
         return false;
 
     Power=(float)pow((float)k2/(float)k1, (float)1/(float)numBands1);
@@ -208,7 +210,7 @@ bool Aac_f_master_Compute(int8u &num_env_bands_Master, int8u* f_Master, sbr_hand
         qsort(vDk1, numBands1+1, sizeof(int8u), int8u_cmp);
         int8u change=vDk0[numBands0-1]-vDk1[0];
         vDk1[0]=vDk0[numBands0-1];
-        vDk1[numBands1-1]=vDk1[numBands1-1]-change;
+        vDk1[numBands1 - 1] = vDk1[numBands1 - 1] - change;
     }
 
     qsort(vDk1, numBands1, sizeof(int8u), int8u_cmp);
@@ -319,8 +321,8 @@ void File_Aac::sbr_extension_data(size_t End, int8u id_aac, bool crc_flag)
             Infos["Format_Profile"]=__T("HE-AAC");
             Ztring SamplingRate=Infos["SamplingRate"];
             if (SamplingRate.empty())
-                SamplingRate.From_Number(sampling_frequency);
-            Infos["SamplingRate"].From_Number((extension_sampling_frequency_index==(int8u)-1)?(sampling_frequency*2):extension_sampling_frequency, 10);
+                SamplingRate.From_Number(Frequency_b);
+            Infos["SamplingRate"].From_Number((extension_sampling_frequency_index==(int8u)-1)?(Frequency_b*2):extension_sampling_frequency, 10);
             if (MediaInfoLib::Config.LegacyStreamDisplay_Get())
             {
                 Infos["Format_Profile"]+=__T(" / LC");
@@ -345,7 +347,7 @@ void File_Aac::sbr_extension_data(size_t End, int8u id_aac, bool crc_flag)
         {
             if (extension_sampling_frequency_index==(int8u)-1)
             {
-                extension_sampling_frequency=sampling_frequency*2;
+                extension_sampling_frequency=(int32u)(Frequency_b*2);
                 extension_sampling_frequency_index=Aac_AudioSpecificConfig_sampling_frequency_index(extension_sampling_frequency);
             }
 
@@ -372,10 +374,8 @@ void File_Aac::sbr_extension_data(size_t End, int8u id_aac, bool crc_flag)
             if (MediaInfoLib::Config.ParseSpeed_Get()<0.3)
             {
                 Frame_Count_Valid=Frame_Count+1;
-                #if MEDIAINFO_ADVANCED
-                    if (aac_frame_lengths.size()<8)
-                        Frame_Count_Valid+=8-aac_frame_lengths.size();
-                #endif //MEDIAINFO_ADVANCED
+                if (Frame_Count<8)
+                    Frame_Count_Valid+=8-Frame_Count;
             }
         FILLING_END();
     }
