@@ -37,9 +37,9 @@ namespace MediaInfoLib
 //***************************************************************************
 
 //---------------------------------------------------------------------------
-extern const int32u Aac_sampling_frequency[]=
+extern const int32u Aac_sampling_frequency[13]=
 {96000, 88200, 64000, 48000, 44100, 32000, 24000, 22050,
- 16000, 12000, 11025,  8000,  7350,     0,     0,     0,};
+ 16000, 12000, 11025,  8000,  7350};
 
 //---------------------------------------------------------------------------
 const char* Aac_Adts_ID[]=
@@ -231,7 +231,7 @@ const char* Aac_ChannelLayout[]=
     "C L R Ls Rs Lrs Rrs LFE",
 };
 
-int8u Aac_AudioSpecificConfig_sampling_frequency_index(const int32u sampling_frequency)
+int8u Aac_AudioSpecificConfig_sampling_frequency_index(const int64s sampling_frequency)
 {
     if (sampling_frequency>=92017) return 0;
     if (sampling_frequency>=75132) return 1;
@@ -257,11 +257,13 @@ void File_Aac::AudioSpecificConfig (size_t End)
     Get_S1 (4, sampling_frequency_index,                        "samplingFrequencyIndex"); Param_Info1(Aac_sampling_frequency[sampling_frequency_index]);
     if (sampling_frequency_index==0xF)
     {
-        Get_S3 (24, sampling_frequency,                         "samplingFrequency");
-        sampling_frequency_index=Aac_AudioSpecificConfig_sampling_frequency_index(sampling_frequency);
+        int32u samplingFrequency;
+        Get_S3 (24, samplingFrequency,                          "samplingFrequency");
+        Frequency_b=samplingFrequency;
+        sampling_frequency_index=Aac_AudioSpecificConfig_sampling_frequency_index(Frequency_b);
     }
     else
-        sampling_frequency=Aac_sampling_frequency[sampling_frequency_index];
+        Frequency_b=Aac_sampling_frequency[sampling_frequency_index];
     Get_S1 (4, channelConfiguration,                            "channelConfiguration"); Param_Info1(Aac_ChannelConfiguration[channelConfiguration]);
     if (audioObjectType==5 || audioObjectType==29)
     {
@@ -357,7 +359,7 @@ void File_Aac::AudioSpecificConfig (size_t End)
             //~ break;
         default:
             Element_Begin1("not implemented part");
-            Skip_BS(Data_BS_Remain()-(End==(size_t)-1)?0:End,   "(Not implemented)");
+            Skip_BS(Data_BS_Remain()-((End==(size_t)-1)?0:End), "(Not implemented)");
             Element_End0();
             FILLING_BEGIN()
                 if (Mode==File_Aac::Mode_ADIF || Mode==File_Aac::Mode_ADTS)
@@ -393,7 +395,7 @@ void File_Aac::AudioSpecificConfig (size_t End)
                 if ( ! directMapping )
                 {
                     Element_Begin1("not implemented part");
-                    Skip_BS(Data_BS_Remain()-(End==(size_t)-1)?0:End, "(Not implemented)");
+                    Skip_BS(Data_BS_Remain()-((End==(size_t)-1)?0:End), "(Not implemented)");
                     Element_End0();
                     if (Mode==File_Aac::Mode_ADIF || Mode==File_Aac::Mode_ADTS)
                         File__Tags_Helper::Finish();
@@ -471,17 +473,17 @@ void File_Aac::AudioSpecificConfig (size_t End)
     }
 
     FILLING_BEGIN();
-        AudioSpecificConfig_OutOfBand (sampling_frequency, audioObjectType, sbrData, psData, sbrPresentFlag, psPresentFlag);
+        AudioSpecificConfig_OutOfBand (Frequency_b, audioObjectType, sbrData, psData, sbrPresentFlag, psPresentFlag);
     FILLING_END();
 }
 
 //---------------------------------------------------------------------------
-void File_Aac::AudioSpecificConfig_OutOfBand (int32u sampling_frequency_, int8u audioObjectType_, bool sbrData, bool psData, bool sbrPresentFlag, bool psPresentFlag)
+void File_Aac::AudioSpecificConfig_OutOfBand (int64s sampling_frequency_, int8u audioObjectType_, bool sbrData, bool psData, bool sbrPresentFlag, bool psPresentFlag)
 {
-    if (sampling_frequency==(int32u)-1 && sampling_frequency_) //Only if not yet set
+    if (!Frequency_b && sampling_frequency_) //Only if not yet set
     {
-        sampling_frequency=sampling_frequency_;
-        sampling_frequency_index=Aac_AudioSpecificConfig_sampling_frequency_index(sampling_frequency);
+        Frequency_b=sampling_frequency_;
+        sampling_frequency_index=Aac_AudioSpecificConfig_sampling_frequency_index((int32u)Frequency_b);
     }
 
     if (audioObjectType_==(int8u)-1)
@@ -512,8 +514,8 @@ void File_Aac::AudioSpecificConfig_OutOfBand (int32u sampling_frequency_, int8u
     else
         audioObjectType=audioObjectType_;
 
-    if (sampling_frequency)
-        Infos["SamplingRate"].From_Number(sampling_frequency);
+    if (Frequency_b)
+        Infos["SamplingRate"].From_Number(Frequency_b);
     Infos["Format"].From_Local(Aac_Format(audioObjectType));
     Infos["Format_Profile"].From_Local(Aac_Format_Profile(audioObjectType));
     Infos["Codec"].From_Local(Aac_audioObjectType(audioObjectType));
@@ -529,7 +531,7 @@ void File_Aac::AudioSpecificConfig_OutOfBand (int32u sampling_frequency_, int8u
     {
         Infos["Format_Profile"]=__T("HE-AAC");
         Ztring SamplingRate_Previous=Infos["SamplingRate"];
-        int32u SamplingRate=(extension_sampling_frequency_index==(int8u)-1)?(sampling_frequency*2):extension_sampling_frequency;
+        int32u SamplingRate=(extension_sampling_frequency_index==(int8u)-1)?(((int32u)Frequency_b)*2):extension_sampling_frequency;
         if (SamplingRate)
         {
             Infos["SamplingRate"].From_Number(SamplingRate, 10);
@@ -558,7 +560,7 @@ void File_Aac::AudioSpecificConfig_OutOfBand (int32u sampling_frequency_, int8u
             Infos["Format_Profile"]+=__T(" / HE-AAC / LC");
             Infos["Channel(s)"]+=__T(" / ")+Channels+__T(" / ")+Channels;
             Infos["ChannelPositions"]+=__T(" / ")+ChannelPositions+__T(" / ")+ChannelPositions;
-            int32u SamplingRate=(extension_sampling_frequency_index==(int8u)-1)?(sampling_frequency*2):extension_sampling_frequency;
+            int32u SamplingRate=(extension_sampling_frequency_index==(int8u)-1)?(((int32u)Frequency_b)*2):extension_sampling_frequency;
             if (SamplingRate)
                 Infos["SamplingRate"]=Ztring().From_Number(SamplingRate, 10)+__T(" / ")+SamplingRate_Previous;
         }
@@ -1083,7 +1085,7 @@ void File_Aac::adts_fixed_header()
     Get_SB (    protection_absent,                              "protection_absent");
     Get_S1 ( 2, audioObjectType,                                "profile_ObjectType"); audioObjectType++; Param_Info1(Aac_audioObjectType(audioObjectType));
     Get_S1 ( 4, sampling_frequency_index,                       "sampling_frequency_index"); Param_Info2(Aac_sampling_frequency[sampling_frequency_index], " Hz");
-    sampling_frequency=Aac_sampling_frequency[sampling_frequency_index];
+    Frequency_b=Aac_sampling_frequency[sampling_frequency_index];
     Skip_SB(                                                    "private");
     Get_S1 ( 3, channelConfiguration,                           "channel_configuration");
     Skip_SB(                                                    "original");
@@ -1125,27 +1127,11 @@ void File_Aac::adts_variable_header()
     Element_End0();
 
     FILLING_BEGIN();
-        aac_frame_lengths.push_back(aac_frame_length);
-
-        Infos["BitRate_Mode"].From_Local(adts_buffer_fullness==0x7FF?"VBR":"CBR");
-        if (adts_buffer_fullness!=0x7FF
+        if (adts_buffer_fullness==0x7FF)
+            adts_buffer_fullness_Is7FF=true;
         #if MEDIAINFO_ADVANCED
-         || Config->File_RiskyBitRateEstimation_Get()
+            aac_frame_length_Total+=aac_frame_length;
         #endif //MEDIAINFO_ADVANCED
-        )
-        {
-            //Calculating
-            int64u aac_frame_length_Total=0;
-            for (size_t Pos=0; Pos<aac_frame_lengths.size(); Pos++)
-                aac_frame_length_Total+=aac_frame_lengths[Pos];
-
-            int64u BitRate=(Aac_sampling_frequency[sampling_frequency_index]/1024);
-            BitRate*=aac_frame_length_Total*8;
-            BitRate/=aac_frame_lengths.size();
-
-            //Filling
-            Infos["BitRate"].From_Number(BitRate);
-        }
     FILLING_END();
 }
 
