@@ -700,6 +700,7 @@ File_Ac3::File_Ac3()
     HD_MajorSync_Parsed=false;
     Core_IsPresent=false;
     HD_IsPresent=false;
+    HD_HasAtmos=false;
     dynrnge_Exists=false;
     TimeStamp_IsPresent=false;
     TimeStamp_IsParsing=false;
@@ -724,12 +725,24 @@ void File_Ac3::Streams_Fill()
 
         if (HD_StreamType==0xBA) //TrueHD
         {
+            if (HD_HasAtmos)
+            {
+
+                Fill(Stream_General, 0, General_Format, "Atmos");
+                Fill(Stream_Audio, 0, Audio_Format, "Atmos");
+                Fill(Stream_Audio, 0, Audio_Codec, "Atmos");
+                Fill(Stream_Audio, 0, Audio_Channel_s_, "Object Based");
+                Fill(Stream_Audio, 0, Audio_ChannelPositions, "Object Based");
+                Fill(Stream_Audio, 0, Audio_ChannelPositions_String2, "Object Based");
+            }
             Fill(Stream_General, 0, General_Format, "TrueHD");
             Fill(Stream_Audio, 0, Audio_Format, "TrueHD");
-
             Fill(Stream_Audio, 0, Audio_Codec, "TrueHD");
             Fill(Stream_Audio, 0, Audio_BitRate_Mode, "VBR");
-            Fill(Stream_Audio, 0, Audio_SamplingRate, AC3_HD_SamplingRate(HD_SamplingRate1));
+            Ztring Sampling;
+            Sampling.From_Number(AC3_HD_SamplingRate(HD_SamplingRate1));
+            if (HD_HasAtmos) Sampling.insert(0, __T(" / "));
+            Fill(Stream_Audio, 0, Audio_SamplingRate, Sampling);
             Fill(Stream_Audio, 0, Audio_Channel_s_, AC3_TrueHD_Channels(HD_Channels2));
             Fill(Stream_Audio, 0, Audio_ChannelPositions, AC3_TrueHD_Channels_Positions(HD_Channels2));
             Fill(Stream_Audio, 0, Audio_ChannelPositions_String2, AC3_TrueHD_Channels_Positions2(HD_Channels2));
@@ -766,7 +779,6 @@ void File_Ac3::Streams_Fill()
         Fill(Stream_General, 0, General_Format, "AC-3");
         Fill(Stream_Audio, 0, Audio_Format, "AC-3");
         Fill(Stream_Audio, 0, Audio_Codec, "AC3");
-        Fill(Stream_Audio, 0, Audio_BitDepth, 16);
 
         int32u Divider=bsid_Max==9?2:1; // Unofficial hack for low sample rate (e.g. 22.05 kHz)
         if (Ztring::ToZtring(AC3_SamplingRate[fscod]/Divider)!=Retrieve(Stream_Audio, 0, Audio_SamplingRate))
@@ -844,7 +856,7 @@ void File_Ac3::Streams_Fill()
 
                 }
 
-                if (fscod!=2)
+                if (fscod!=3)
                     Fill(Stream_Audio, 0, Audio_SamplingRate, AC3_SamplingRate[fscod]);
                 else
                     Fill(Stream_Audio, 0, Audio_SamplingRate, AC3_SamplingRate2[fscod2]);
@@ -964,6 +976,21 @@ void File_Ac3::Streams_Fill()
         if (TimeStamp_DropFrame_IsValid)
             Fill(Stream_Audio, 0, Audio_Delay_Settings, TimeStamp_DropFrame_Content?"drop_frame_flag=1":"drop_frame_flag=0");
     }
+
+    //Samples per frame
+    int16u SamplesPerFrame;
+    if (bsid_Max<=0x08)
+        SamplesPerFrame=1536;
+    else if (bsid_Max<=0x09)
+        SamplesPerFrame=768; // Unofficial hack for low sample rate (e.g. 22.05 kHz)
+    else if (bsid_Max>0x0A && bsid_Max<=0x10)
+        SamplesPerFrame=256;
+    else if (HD_MajorSync_Parsed && (HD_StreamType==0xBA || HD_StreamType==0xBB)) // TrueHD or MLP
+        SamplesPerFrame=40;
+    else
+        SamplesPerFrame=0;
+    if (SamplesPerFrame)
+        Fill(Stream_Audio, 0, Audio_SamplesPerFrame, SamplesPerFrame);
 }
 
 //---------------------------------------------------------------------------
@@ -1612,8 +1639,6 @@ void File_Ac3::Data_Parse()
     switch (Element_Code)
     {
         case 0 :
-                    Element_Info1C((FrameInfo.PTS!=(int64u)-1), __T("PTS ")+Ztring().Duration_From_Milliseconds(float64_int64s(((float64)FrameInfo.PTS)/1000000)));
-                    Element_Info1(Frame_Count);
                     Core();
                     break;
         case 1 :
@@ -1655,39 +1680,31 @@ void File_Ac3::Core()
         return; //Waiting for the first sync frame
 
     FILLING_BEGIN();
+        if (bsid>0x10)
+            return; //Not supported
+
         //Counting
         if (Frame_Count==0)
         {
             Core_IsPresent=true;
             PTS_Begin=FrameInfo.PTS;
         }
-        Frame_Count++;
-        Frame_Count_InThisBlock++;
-        if (Frame_Count_NotParsedIncluded!=(int64u)-1)
-            Frame_Count_NotParsedIncluded++;
-        if (bsid<=0x08)
-            FrameInfo.DUR=32000000;
-        else if (bsid<=0x09)
-            FrameInfo.DUR=16000000; // Unofficial hack for low sample rate (e.g. 22.05 kHz)
-        else if (bsid>0x0A && bsid<=0x10)
+        if (bsid==0x09)
+            Frequency_b=AC3_SamplingRate2[fscod]; // Unofficial hack for low sample rate (e.g. 22.05 kHz)
+        else
+        {
+            if (fscod!=3)
+                Frequency_b=AC3_SamplingRate[fscod];
+            else
+                Frequency_b=AC3_SamplingRate2[fscod2];
+        }
+        if (bsid>0x0A)
         {
             int64u numblks = numblkscod == 3 ? 6 : numblkscod + 1;
-            FrameInfo.DUR=32000000*numblks/6;
+            TS_Add(numblks*256);
         }
-        if (fscod && AC3_SamplingRate[fscod])
-        {
-            FrameInfo.DUR*=48000;
-            FrameInfo.DUR/=AC3_SamplingRate[fscod];
-        }
-        if (fscod==3 && AC3_SamplingRate2[fscod2])
-        {
-            FrameInfo.DUR*=48000;
-            FrameInfo.DUR/=AC3_SamplingRate2[fscod2];
-        }
-        if (FrameInfo.DTS!=(int64u)-1)
-            FrameInfo.DTS+=FrameInfo.DUR;
-        if (FrameInfo.PTS!=(int64u)-1)
-            FrameInfo.PTS=FrameInfo.DTS;
+        else
+            TS_Add(1536);
 
         if (File_Offset+Buffer_Offset+Element_Size==File_Size)
             Frame_Count_Valid=Frame_Count; //Finish frames in case of there are less than Frame_Count_Valid frames
@@ -1849,6 +1866,8 @@ void File_Ac3::Core_Frame()
             Element_End0();
         }
     }
+    else
+        Skip_XX(Element_Size-Element_Offset,                        "Unknown");
 
     FILLING_BEGIN();
         if (bsid>0x10)
@@ -2000,9 +2019,32 @@ void File_Ac3::HD()
         Skip_B1(                                                "Unknown");
         Skip_B1(                                                "Unknown");
         Skip_B1(                                                "Unknown");
-        Skip_B1(                                                "Unknown");
-        Skip_B1(                                                "Unknown");
-        Skip_B1(                                                "Unknown");
+        BS_Begin();
+        Skip_S1( 7,                                             "Unknown");
+        bool HasExtend;
+        Get_SB (    HasExtend,                                  "Has Extend");
+        BS_End();
+        if (HasExtend)
+        {
+            unsigned char Extend = 0;
+            unsigned char Unknown = 0;
+            bool HasContent = false;
+            BS_Begin();
+            Get_S1( 4, Extend,                                  "Extend Header");
+            Get_S1( 4, Unknown,                                 "Unknown");
+            if (Unknown)
+                HasContent = true;
+            BS_End();
+            for (Extend = (Extend * 2) + 1; Extend > 0; Extend--)
+            {
+                Get_B1(Unknown,                                 "Unknown");
+                if (Unknown)
+                    HasContent = true;
+            }
+            if (HasContent)
+                HD_HasAtmos=true; //Currently only Atmos is known as having data here
+        }
+
         Element_End0();
 
         FILLING_BEGIN();
@@ -2285,6 +2327,8 @@ bool File_Ac3::FrameSynchPoint_Test()
         {
             int16u frmsiz=LittleEndian2int16u(Buffer+Buffer_Offset+2)&0x07FF;
             Size=2+frmsiz*2;
+
+            //TODO: case with multiple substreams
         }
         if (Size>=6)
         {
@@ -2451,15 +2495,21 @@ size_t File_Ac3::Core_Size_Get()
             if (substreamid!=substreams_Count_Dependant)
                 break; //Problem
 
+            int8u strmtyp = Buffer[Buffer_Offset + Size + 2] >> 6;
+            if (substreamid==0 && strmtyp==0)
+                break; //Next block
+
             frmsiz    =((int16u)(Buffer[(size_t)(Buffer_Offset+Size+2)]&0x07)<<8)
                      | (         Buffer[(size_t)(Buffer_Offset+Size+3)]         );
 
             //Filling
             Size+=2+frmsiz*2;
 
-            int8u strmtyp = Buffer[Buffer_Offset + Size + 2] >> 6;
             if (strmtyp == 0)
+            {
                 substreams_Count_Independant++;
+                substreams_Count_Dependant=0;
+            }
             else
                 substreams_Count_Dependant++;
             substreams_Count++;
