@@ -407,7 +407,10 @@ void File_Pcm::Data_Parse()
         Frame_Count_NotParsedIncluded++;
     if (FrameInfo.DTS!=(int64u)-1 && FrameInfo.DUR!=(int64u)-1)
     {
-        FrameInfo.DTS+=FrameInfo.DUR;
+        if (BitDepth && Channels && SamplingRate)
+            FrameInfo.DTS+=Element_Size*1000000000*8/BitDepth/Channels/SamplingRate;
+        else
+            FrameInfo.DTS+=FrameInfo.DUR;
         FrameInfo.PTS=FrameInfo.DTS;
     }
     if ((!Status[IsAccepted] && Frame_Count>=Frame_Count_Valid) || File_Offset+Buffer_Size>=File_Size)
