@@ -48,10 +48,10 @@ const char* Smpte_St0331_ChannelsPositions(int8u number_channels)
 {
     switch (number_channels)
     {
-        case  0 : return "Front: L R";                                  //2 channels
-        case  1 : return "Front: L C R, LFE";                           //4 channels
-        case  2 : return "Front: L C R, Side: L R, LFE";                //6 channels
-        case  3 : return "Front: L C R, Side: L R, Back: L R, LFE";     //8 channels
+        case  2 : return "Front: L R";                                  //2 channels
+        case  4 : return "Front: L C R, LFE";                           //4 channels
+        case  6 : return "Front: L C R, Side: L R, LFE";                //6 channels
+        case  8 : return "Front: L C R, Side: L R, Back: L R, LFE";     //8 channels
         default : return "";
     }
 }
@@ -61,10 +61,10 @@ const char* Smpte_St0331_ChannelsPositions2(int8u number_channels)
 {
     switch (number_channels)
     {
-        case  0 : return "2/0/0.0";                                     //2 channels
-        case  1 : return "3/0/0.1";                                     //4 channels
-        case  2 : return "3/2/0.1";                                     //6 channels
-        case  3 : return "3/2/2.1";                                     //8 channels
+        case  2 : return "2/0/0.0";                                     //2 channels
+        case  4 : return "3/0/0.1";                                     //4 channels
+        case  6 : return "3/2/0.1";                                     //6 channels
+        case  8 : return "3/2/2.1";                                     //8 channels
         default : return "";
     }
 }
@@ -104,7 +104,9 @@ void File_SmpteSt0331::Streams_Fill()
     Fill(Stream_Audio, 0, Audio_Format, "PCM");
     Fill(Stream_Audio, 0, Audio_Codec, "PCM");
     Fill(Stream_Audio, 0, Audio_SamplingRate, 48000);
-    Fill(Stream_Audio, 0, Audio_BitRate, 8*32*48000);
+    if (QuantizationBits)
+        Fill(Stream_Audio, 0, Audio_BitRate, Channels_Count*QuantizationBits*48000);
+    Fill(Stream_Audio, 0, Audio_BitRate_Encoded, 8*32*48000);
     Fill(Stream_Audio, 0, Audio_BitRate_Mode, "CBR");
 
     Fill(Stream_Audio, 0, Audio_Format_Settings_Endianness, "Little");
@@ -201,7 +203,7 @@ void File_SmpteSt0331::Read_Buffer_Continue()
     FILLING_BEGIN();
     if (!Status[IsAccepted])
     {
-        Accept("AES3");
+        Accept("SMPTE ST 331");
 
         int8u Channels=0;
         for (int8u Pos=0; Pos<8; Pos++)
