@@ -1,4 +1,4 @@
-/*  Copyright (c) 2009-2013 MediaArea.net SARL. All Rights Reserved.
+/*  Copyright (c) MediaArea.net SARL. All Rights Reserved.
  *
  *  Use of this source code is governed by a BSD-style license that can
  *  be found in the License.html file in the root of the source tree.
@@ -22,6 +22,10 @@
 #include "MediaInfo/Setup.h"
 //---------------------------------------------------------------------------
 
+//---------------------------------------------------------------------------
+#if defined(MEDIAINFO_PBCORE_YES)
+//---------------------------------------------------------------------------
+
 //---------------------------------------------------------------------------
 #include "MediaInfo/Export/Export_PBCore2.h"
 #include "MediaInfo/File__Analyse_Automatic.h"
@@ -80,8 +84,6 @@ void PBCore2_Transform(Ztring &ToReturn, MediaInfo_Internal &MI, stream_t Stream
     if (StreamKind==Stream_Menu && MI.Get(Stream_Menu, StreamPos, Menu_Format)!=__T("TimeCode"))
         return;
 
-    ToReturn+=__T("\t<instantiationEssenceTrack>\n");
-
     //essenceTrackType
     Ztring essenceTrackType;
     switch (StreamKind)
@@ -114,6 +116,9 @@ void PBCore2_Transform(Ztring &ToReturn, MediaInfo_Internal &MI, stream_t Stream
                 return; //Not supported
         default:            return; //Not supported
     }
+
+    ToReturn+=__T("\t<instantiationEssenceTrack>\n");
+
     ToReturn+=__T("\t\t<essenceTrackType>");
     ToReturn+=essenceTrackType;
     ToReturn+=__T("</essenceTrackType>\n");
@@ -158,7 +163,8 @@ void PBCore2_Transform(Ztring &ToReturn, MediaInfo_Internal &MI, stream_t Stream
         ToReturn+=__T("\t\t<essenceTrackEncoding");
         if (!MI.Get(StreamKind, StreamPos, __T("CodecID")).empty())
         {
-            ToReturn+=__T(" ref=\"codecid:");
+            ToReturn+=__T(" source=\"codecid\"");
+            ToReturn+=__T(" ref=\"");
             ToReturn+=MI.Get(StreamKind, StreamPos, __T("CodecID"));
             ToReturn+=__T("\"");
         }
@@ -352,8 +358,10 @@ Ztring Export_PBCore2::Transform(MediaInfo_Internal &MI)
     ToReturn+=__T("\t<instantiationIdentifier source=\"File Name\">");
     ToReturn+=MI.Get(Stream_General, 0, General_FileName);
     if (!MI.Get(Stream_General, 0, General_FileExtension).empty())
+    {
         ToReturn+=__T(".");
         ToReturn+=MI.Get(Stream_General, 0, General_FileExtension);
+    }
     ToReturn+=__T("</instantiationIdentifier>\n");
 
     // need to figure out how to get to non-internally-declared-values
@@ -572,3 +580,5 @@ Ztring Export_PBCore2::Transform(MediaInfo_Internal &MI)
 //***************************************************************************
 
 } //NameSpace
+
+#endif
