@@ -70,6 +70,8 @@ enum generic
     Generic_BitRate_Encoded_String,
     Generic_FrameRate,
     Generic_FrameRate_String,
+    Generic_FrameRate_Num,
+    Generic_FrameRate_Den,
     Generic_FrameCount,
     Generic_Source_FrameCount,
     Generic_ColorSpace,
@@ -161,6 +163,8 @@ enum general
     General_Inform,
     General_ID,
     General_ID_String,
+    General_OriginalSourceMedium_ID,
+    General_OriginalSourceMedium_ID_String,
     General_UniqueID,
     General_UniqueID_String,
     General_MenuID,
@@ -222,6 +226,8 @@ enum general
     General_CodecID_Hint,
     General_CodecID_Url,
     General_CodecID_Description,
+    General_CodecID_Version,
+    General_CodecID_Compatible,
     General_Interleaved,
     General_Codec,
     General_Codec_String,
@@ -257,6 +263,8 @@ enum general
     General_OverallBitRate_Maximum_String,
     General_FrameRate,
     General_FrameRate_String,
+    General_FrameRate_Num,
+    General_FrameRate_Den,
     General_FrameCount,
     General_Delay,
     General_Delay_String,
@@ -277,6 +285,13 @@ enum general
     General_StreamSize_String4,
     General_StreamSize_String5,
     General_StreamSize_Proportion,
+    General_StreamSize_Demuxed,
+    General_StreamSize_Demuxed_String,
+    General_StreamSize_Demuxed_String1,
+    General_StreamSize_Demuxed_String2,
+    General_StreamSize_Demuxed_String3,
+    General_StreamSize_Demuxed_String4,
+    General_StreamSize_Demuxed_String5,
     General_HeaderSize,
     General_DataSize,
     General_FooterSize,
@@ -321,6 +336,7 @@ enum general
     General_Track_Sort,
     General_Track_Position,
     General_Track_Position_Total,
+    General_PackageName,
     General_Grouping,
     General_Chapter,
     General_SubTrack,
@@ -474,6 +490,8 @@ enum video
     Video_Inform,
     Video_ID,
     Video_ID_String,
+    Video_OriginalSourceMedium_ID,
+    Video_OriginalSourceMedium_ID_String,
     Video_UniqueID,
     Video_UniqueID_String,
     Video_MenuID,
@@ -604,6 +622,10 @@ enum video
     Video_Height_Original_String,
     Video_Height_CleanAperture,
     Video_Height_CleanAperture_String,
+    Video_Stored_Width,
+    Video_Stored_Height,
+    Video_Sampled_Width,
+    Video_Sampled_Height,
     Video_PixelAspectRatio,
     Video_PixelAspectRatio_String,
     Video_PixelAspectRatio_Original,
@@ -627,14 +649,18 @@ enum video
     Video_FrameRate_Mode_Original_String,
     Video_FrameRate,
     Video_FrameRate_String,
-    Video_FrameRate_Original,
-    Video_FrameRate_Original_String,
+    Video_FrameRate_Num,
+    Video_FrameRate_Den,
     Video_FrameRate_Minimum,
     Video_FrameRate_Minimum_String,
     Video_FrameRate_Nominal,
     Video_FrameRate_Nominal_String,
     Video_FrameRate_Maximum,
     Video_FrameRate_Maximum_String,
+    Video_FrameRate_Original,
+    Video_FrameRate_Original_String,
+    Video_FrameRate_Original_Num,
+    Video_FrameRate_Original_Den,
     Video_FrameCount,
     Video_Source_FrameCount,
     Video_Standard,
@@ -708,6 +734,13 @@ enum video
     Video_StreamSize_String4,
     Video_StreamSize_String5,
     Video_StreamSize_Proportion,
+    Video_StreamSize_Demuxed,
+    Video_StreamSize_Demuxed_String,
+    Video_StreamSize_Demuxed_String1,
+    Video_StreamSize_Demuxed_String2,
+    Video_StreamSize_Demuxed_String3,
+    Video_StreamSize_Demuxed_String4,
+    Video_StreamSize_Demuxed_String5,
     Video_Source_StreamSize,
     Video_Source_StreamSize_String,
     Video_Source_StreamSize_String1,
@@ -756,10 +789,14 @@ enum video
     Video_Language_String3,
     Video_Language_String4,
     Video_Language_More,
+    Video_Disabled,
+    Video_Disabled_String,
     Video_Default,
     Video_Default_String,
     Video_Forced,
     Video_Forced_String,
+    Video_AlternateGroup,
+    Video_AlternateGroup_String,
     Video_Encoded_Date,
     Video_Tagged_Date,
     Video_Encryption,
@@ -790,6 +827,8 @@ enum audio
     Audio_Inform,
     Audio_ID,
     Audio_ID_String,
+    Audio_OriginalSourceMedium_ID,
+    Audio_OriginalSourceMedium_ID_String,
     Audio_UniqueID,
     Audio_UniqueID_String,
     Audio_MenuID,
@@ -909,18 +948,23 @@ enum audio
     Audio_Matrix_ChannelPositions_String2,
     Audio_ChannelLayout,
     Audio_ChannelLayoutID,
+    Audio_SamplesPerFrame,
     Audio_SamplingRate,
     Audio_SamplingRate_String,
     Audio_SamplingCount,
     Audio_Source_SamplingCount,
     Audio_FrameRate,
     Audio_FrameRate_String,
+    Audio_FrameRate_Num,
+    Audio_FrameRate_Den,
     Audio_FrameCount,
     Audio_Source_FrameCount,
     Audio_Resolution,
     Audio_Resolution_String,
     Audio_BitDepth,
     Audio_BitDepth_String,
+    Audio_BitDepth_Detected,
+    Audio_BitDepth_Detected_String,
     Audio_BitDepth_Stored,
     Audio_BitDepth_Stored_String,
     Audio_Compression_Mode,
@@ -972,6 +1016,13 @@ enum audio
     Audio_StreamSize_String4,
     Audio_StreamSize_String5,
     Audio_StreamSize_Proportion,
+    Audio_StreamSize_Demuxed,
+    Audio_StreamSize_Demuxed_String,
+    Audio_StreamSize_Demuxed_String1,
+    Audio_StreamSize_Demuxed_String2,
+    Audio_StreamSize_Demuxed_String3,
+    Audio_StreamSize_Demuxed_String4,
+    Audio_StreamSize_Demuxed_String5,
     Audio_Source_StreamSize,
     Audio_Source_StreamSize_String,
     Audio_Source_StreamSize_String1,
@@ -1025,10 +1076,14 @@ enum audio
     Audio_Language_String3,
     Audio_Language_String4,
     Audio_Language_More,
+    Audio_Disabled,
+    Audio_Disabled_String,
     Audio_Default,
     Audio_Default_String,
     Audio_Forced,
     Audio_Forced_String,
+    Audio_AlternateGroup,
+    Audio_AlternateGroup_String,
     Audio_Encoded_Date,
     Audio_Tagged_Date,
     Audio_Encryption,
@@ -1049,6 +1104,8 @@ enum text
     Text_Inform,
     Text_ID,
     Text_ID_String,
+    Text_OriginalSourceMedium_ID,
+    Text_OriginalSourceMedium_ID_String,
     Text_UniqueID,
     Text_UniqueID_String,
     Text_MenuID,
@@ -1139,6 +1196,8 @@ enum text
     Text_FrameRate_Mode_String,
     Text_FrameRate,
     Text_FrameRate_String,
+    Text_FrameRate_Num,
+    Text_FrameRate_Den,
     Text_FrameRate_Minimum,
     Text_FrameRate_Minimum_String,
     Text_FrameRate_Nominal,
@@ -1148,6 +1207,7 @@ enum text
     Text_FrameRate_Original,
     Text_FrameRate_Original_String,
     Text_FrameCount,
+    Text_ElementCount,
     Text_Source_FrameCount,
     Text_ColorSpace,
     Text_ChromaSubsampling,
@@ -1201,6 +1261,13 @@ enum text
     Text_StreamSize_String4,
     Text_StreamSize_String5,
     Text_StreamSize_Proportion,
+    Text_StreamSize_Demuxed,
+    Text_StreamSize_Demuxed_String,
+    Text_StreamSize_Demuxed_String1,
+    Text_StreamSize_Demuxed_String2,
+    Text_StreamSize_Demuxed_String3,
+    Text_StreamSize_Demuxed_String4,
+    Text_StreamSize_Demuxed_String5,
     Text_Source_StreamSize,
     Text_Source_StreamSize_String,
     Text_Source_StreamSize_String1,
@@ -1247,10 +1314,14 @@ enum text
     Text_Language_String3,
     Text_Language_String4,
     Text_Language_More,
+    Text_Disabled,
+    Text_Disabled_String,
     Text_Default,
     Text_Default_String,
     Text_Forced,
     Text_Forced_String,
+    Text_AlternateGroup,
+    Text_AlternateGroup_String,
     Text_Summary,
     Text_Encoded_Date,
     Text_Tagged_Date,
@@ -1272,6 +1343,8 @@ enum other
     Other_Inform,
     Other_ID,
     Other_ID_String,
+    Other_OriginalSourceMedium_ID,
+    Other_OriginalSourceMedium_ID_String,
     Other_UniqueID,
     Other_UniqueID_String,
     Other_MenuID,
@@ -1304,6 +1377,8 @@ enum other
     Other_Duration_End,
     Other_FrameRate,
     Other_FrameRate_String,
+    Other_FrameRate_Num,
+    Other_FrameRate_Den,
     Other_FrameCount,
     Other_TimeStamp_FirstFrame,
     Other_TimeStamp_FirstFrame_String,
@@ -1324,6 +1399,14 @@ enum other
     Other_Language_String3,
     Other_Language_String4,
     Other_Language_More,
+    Other_Disabled,
+    Other_Disabled_String,
+    Other_Default,
+    Other_Default_String,
+    Other_Forced,
+    Other_Forced_String,
+    Other_AlternateGroup,
+    Other_AlternateGroup_String,
 };
 
 //---------------------------------------------------------------------------
@@ -1341,6 +1424,8 @@ enum image
     Image_Inform,
     Image_ID,
     Image_ID_String,
+    Image_OriginalSourceMedium_ID,
+    Image_OriginalSourceMedium_ID_String,
     Image_UniqueID,
     Image_UniqueID_String,
     Image_MenuID,
@@ -1405,6 +1490,13 @@ enum image
     Image_StreamSize_String4,
     Image_StreamSize_String5,
     Image_StreamSize_Proportion,
+    Image_StreamSize_Demuxed,
+    Image_StreamSize_Demuxed_String,
+    Image_StreamSize_Demuxed_String1,
+    Image_StreamSize_Demuxed_String2,
+    Image_StreamSize_Demuxed_String3,
+    Image_StreamSize_Demuxed_String4,
+    Image_StreamSize_Demuxed_String5,
     Image_Encoded_Library,
     Image_Encoded_Library_String,
     Image_Encoded_Library_Name,
@@ -1418,10 +1510,14 @@ enum image
     Image_Language_String3,
     Image_Language_String4,
     Image_Language_More,
+    Image_Disabled,
+    Image_Disabled_String,
     Image_Default,
     Image_Default_String,
     Image_Forced,
     Image_Forced_String,
+    Image_AlternateGroup,
+    Image_AlternateGroup_String,
     Image_Summary,
     Image_Encoded_Date,
     Image_Tagged_Date,
@@ -1451,6 +1547,8 @@ enum menu
     Menu_Inform,
     Menu_ID,
     Menu_ID_String,
+    Menu_OriginalSourceMedium_ID,
+    Menu_OriginalSourceMedium_ID_String,
     Menu_UniqueID,
     Menu_UniqueID_String,
     Menu_MenuID,
@@ -1517,6 +1615,14 @@ enum menu
     Menu_TimeZones,
     Menu_LawRating,
     Menu_LawRating_Reason,
+    Menu_Disabled,
+    Menu_Disabled_String,
+    Menu_Default,
+    Menu_Default_String,
+    Menu_Forced,
+    Menu_Forced_String,
+    Menu_AlternateGroup,
+    Menu_AlternateGroup_String,
     Menu_Chapters_Pos_Begin,
     Menu_Chapters_Pos_End,
 };
