@@ -175,12 +175,21 @@ void File__Analyze::Get_B4(int32u &Info, const char* Name)
     Info=BigEndian2int32u(Buffer+Buffer_Offset+(size_t)Element_Offset);
     if (Trace_Activated)
     {
-        Ztring Pos1; Pos1.From_Number(Info, 16);
-        Ztring Temp;
-        Temp.resize(8-Pos1.size(), __T('0'));
-        Temp.append(Pos1);
-        Temp.MakeUpperCase();
-        Param(Name, Ztring::ToZtring(Info)+__T(" (0x")+Temp+__T(")"));
+        switch (Config_Trace_Format)
+        {
+            case MediaInfo_Config::Trace_Format_XML         :
+                                                                Param(Name, Ztring::ToZtring(Info));
+                                                                break;
+            default                                         :
+                                                                {
+                                                                Ztring Pos1; Pos1.From_Number(Info, 16);
+                                                                Ztring Temp;
+                                                                Temp.resize(8-Pos1.size(), __T('0'));
+                                                                Temp.append(Pos1);
+                                                                Temp.MakeUpperCase();
+                                                                Param(Name, Ztring::ToZtring(Info)+__T(" (0x")+Temp+__T(")"));
+                                                                }
+        }
     }
     Element_Offset+=4;
 }
@@ -232,6 +241,44 @@ void File__Analyze::Get_B16(int128u &Info, const char* Name)
     Element_Offset+=16;
 }
 
+//---------------------------------------------------------------------------
+// Big Endian - float 16 bits
+// TODO: remove it when Linux version of ZenLib is updated
+float32 BigEndian2float16corrected(const char* Liste)
+{
+    //sign          1 bit
+    //exponent      5 bit
+    //significand  10 bit
+
+    //Retrieving data
+    int16u Integer=BigEndian2int16u(Liste);
+
+    //Retrieving elements
+    bool   Sign    =(Integer&0x8000)?true:false;
+    int32u Exponent=(Integer>>10)&0xFF;
+    int32u Mantissa= Integer&0x03FF;
+
+    //Some computing
+    if (Exponent==0 || Exponent==0xFF)
+        return 0; //These are denormalised numbers, NANs, and other horrible things
+    Exponent-=0x0F; //Bias
+    float64 Answer=(((float64)Mantissa)/8388608+1.0)*std::pow((float64)2, (int)Exponent); //(1+Mantissa) * 2^Exponent
+    if (Sign)
+        Answer=-Answer;
+
+    return (float32)Answer;
+}
+inline float32 BigEndian2float16corrected  (const int8u* List) {return BigEndian2float16corrected   ((const char*)List);}
+
+//---------------------------------------------------------------------------
+void File__Analyze::Get_BF2(float32 &Info, const char* Name)
+{
+    INTEGRITY_SIZE_ATLEAST_INT(2);
+    Info=BigEndian2float16corrected(Buffer+Buffer_Offset+(size_t)Element_Offset);
+    if (Trace_Activated) Param(Name, Info);
+    Element_Offset+=2;
+}
+
 //---------------------------------------------------------------------------
 void File__Analyze::Get_BF4(float32 &Info, const char* Name)
 {
@@ -378,12 +425,21 @@ void File__Analyze::Skip_B4(const char* Name)
     if (Trace_Activated)
     {
         int32u Info=BigEndian2int32u(Buffer+Buffer_Offset+(size_t)Element_Offset);
-        Ztring Pos1; Pos1.From_Number(Info, 16);
-        Ztring Temp;
-        Temp.resize(8-Pos1.size(), __T('0'));
-        Temp.append(Pos1);
-        Temp.MakeUpperCase();
-        Param(Name, Ztring::ToZtring(Info)+__T(" (0x")+Temp+__T(")"));
+        switch (Config_Trace_Format)
+        {
+            case MediaInfo_Config::Trace_Format_XML         :
+                                                                Param(Name, Ztring::ToZtring(Info));
+                                                                break;
+            default                                         :
+                                                                {
+                                                                Ztring Pos1; Pos1.From_Number(Info, 16);
+                                                                Ztring Temp;
+                                                                Temp.resize(8-Pos1.size(), __T('0'));
+                                                                Temp.append(Pos1);
+                                                                Temp.MakeUpperCase();
+                                                                Param(Name, Ztring::ToZtring(Info)+__T(" (0x")+Temp+__T(")"));
+                                                                }
+        }
     }
     Element_Offset+=4;
 }
@@ -1471,8 +1527,8 @@ void File__Analyze::Get_VL_Prepare(vlc_fast &Vlc)
         if (Vlc.Vlc[Pos].bit_increment==255)
             break;
         Increment+=Vlc.Vlc[Pos].bit_increment;
-        size_t Value=Vlc.Vlc[Pos].value<<(Vlc.Size-Increment);
-        size_t ToFill_Size=1<<(Vlc.Size-Increment);
+        size_t Value=((size_t)Vlc.Vlc[Pos].value)<<(Vlc.Size-Increment);
+        size_t ToFill_Size=((size_t)1)<<(Vlc.Size-Increment);
         for (size_t ToFill_Pos=0; ToFill_Pos<ToFill_Size; ToFill_Pos++)
         {
             Vlc.Array[Value+ToFill_Pos]=Pos;
@@ -1980,7 +2036,7 @@ void File__Analyze::Get_Flags (int64u Flags, size_t Order, bool &Info, const cha
         Info=false;
 
     Element_Begin0();
-    if (Trace_Activated) Param(Name, Info?"Yes":"No");
+    if (Trace_Activated && MediaInfoLib::Config.Trace_Format_Get()!=MediaInfoLib::Config.Trace_Format_XML) Param(Name, Info?"Yes":"No");
     Element_End0();
 }
 
@@ -1990,7 +2046,7 @@ void File__Analyze::Get_Flags (int64u ValueToPut, int8u &Info, const char* Name)
     Info=(int8u)ValueToPut;
 
     Element_Begin0();
-    if (Trace_Activated) Param(Name, Info);
+    if (Trace_Activated && MediaInfoLib::Config.Trace_Format_Get()!=MediaInfoLib::Config.Trace_Format_XML) Param(Name, Info);
     Element_End0();
 }
 
@@ -1998,7 +2054,7 @@ void File__Analyze::Get_Flags (int64u ValueToPut, int8u &Info, const char* Name)
 void File__Analyze::Skip_Flags(int64u Flags, size_t Order, const char* Name)
 {
     Element_Begin0();
-    if (Trace_Activated) Param(Name, (Flags&((int64u)1<<Order))?"Yes":"No");
+    if (Trace_Activated && MediaInfoLib::Config.Trace_Format_Get()!=MediaInfoLib::Config.Trace_Format_XML) Param(Name, (Flags&((int64u)1<<Order))?"Yes":"No"); //TODO: support flags in XML trace
     Element_End0();
 }
 
@@ -2006,7 +2062,7 @@ void File__Analyze::Skip_Flags(int64u Flags, size_t Order, const char* Name)
 void File__Analyze::Skip_Flags(int64u ValueToPut, const char* Name)
 {
     Element_Begin0();
-    if (Trace_Activated) Param(Name, ValueToPut);
+    if (Trace_Activated && MediaInfoLib::Config.Trace_Format_Get()!=MediaInfoLib::Config.Trace_Format_XML) Param(Name, ValueToPut);
     Element_End0();
 }
 
@@ -2035,11 +2091,13 @@ void File__Analyze::Get_S1(int8u Bits, int8u &Info, const char* Name)
 {
     INTEGRITY_INT(Bits<=BS->Remain(), "Size is wrong", BS->Offset_Get())
     Info=BS->Get1(Bits);
-    if (Trace_Activated)
-    {
-        Param(Name, Info);
-        Param_Info(__T("(")+Ztring::ToZtring(Bits)+__T(" bits)"));
-    }
+    #if MEDIAINFO_TRACE
+        if (Trace_Activated)
+        {
+            Param(Name, Info);
+            Param_Info(__T("(")+Ztring::ToZtring(Bits)+__T(" bits)"));
+        }
+    #endif //MEDIAINFO_TRACE
 }
 
 //---------------------------------------------------------------------------
@@ -2047,7 +2105,13 @@ void File__Analyze::Get_S2(int8u Bits, int16u &Info, const char* Name)
 {
     INTEGRITY_INT(Bits<=BS->Remain(), "Size is wrong", BS->Offset_Get())
     Info=BS->Get2(Bits);
-    if (Trace_Activated) Param(Name, Info);
+    #if MEDIAINFO_TRACE
+        if (Trace_Activated)
+        {
+            Param(Name, Info);
+            Param_Info(__T("(")+Ztring::ToZtring(Bits)+__T(" bits)"));
+        }
+    #endif //MEDIAINFO_TRACE
 }
 
 //---------------------------------------------------------------------------
@@ -2055,7 +2119,13 @@ void File__Analyze::Get_S3(int8u Bits, int32u &Info, const char* Name)
 {
     INTEGRITY_INT(Bits<=BS->Remain(), "Size is wrong", BS->Offset_Get())
     Info=BS->Get4(Bits);
-    if (Trace_Activated) Param(Name, Info);
+    #if MEDIAINFO_TRACE
+        if (Trace_Activated)
+        {
+            Param(Name, Info);
+            Param_Info(__T("(")+Ztring::ToZtring(Bits)+__T(" bits)"));
+        }
+    #endif //MEDIAINFO_TRACE
 }
 
 //---------------------------------------------------------------------------
@@ -2063,7 +2133,13 @@ void File__Analyze::Get_S4(int8u Bits, int32u &Info, const char* Name)
 {
     INTEGRITY_INT(Bits<=BS->Remain(), "Size is wrong", BS->Offset_Get())
     Info=BS->Get4(Bits);
-    if (Trace_Activated) Param(Name, Info);
+    #if MEDIAINFO_TRACE
+        if (Trace_Activated)
+        {
+            Param(Name, Info);
+            Param_Info(__T("(")+Ztring::ToZtring(Bits)+__T(" bits)"));
+        }
+    #endif //MEDIAINFO_TRACE
 }
 
 //---------------------------------------------------------------------------
@@ -2071,7 +2147,13 @@ void File__Analyze::Get_S5(int8u Bits, int64u &Info, const char* Name)
 {
     INTEGRITY_INT(Bits<=BS->Remain(), "Size is wrong", BS->Offset_Get())
     Info=BS->Get8(Bits);
-    if (Trace_Activated) Param(Name, Info);
+    #if MEDIAINFO_TRACE
+        if (Trace_Activated)
+        {
+            Param(Name, Info);
+            Param_Info(__T("(")+Ztring::ToZtring(Bits)+__T(" bits)"));
+        }
+    #endif //MEDIAINFO_TRACE
 }
 
 //---------------------------------------------------------------------------
@@ -2079,7 +2161,13 @@ void File__Analyze::Get_S6(int8u Bits, int64u &Info, const char* Name)
 {
     INTEGRITY_INT(Bits<=BS->Remain(), "Size is wrong", BS->Offset_Get())
     Info=BS->Get8(Bits);
-    if (Trace_Activated) Param(Name, Info);
+    #if MEDIAINFO_TRACE
+        if (Trace_Activated)
+        {
+            Param(Name, Info);
+            Param_Info(__T("(")+Ztring::ToZtring(Bits)+__T(" bits)"));
+        }
+    #endif //MEDIAINFO_TRACE
 }
 
 //---------------------------------------------------------------------------
@@ -2087,7 +2175,13 @@ void File__Analyze::Get_S7(int8u Bits, int64u &Info, const char* Name)
 {
     INTEGRITY_INT(Bits<=BS->Remain(), "Size is wrong", BS->Offset_Get())
     Info=BS->Get8(Bits);
-    if (Trace_Activated) Param(Name, Info);
+    #if MEDIAINFO_TRACE
+        if (Trace_Activated)
+        {
+            Param(Name, Info);
+            Param_Info(__T("(")+Ztring::ToZtring(Bits)+__T(" bits)"));
+        }
+    #endif //MEDIAINFO_TRACE
 }
 
 //---------------------------------------------------------------------------
@@ -2095,7 +2189,13 @@ void File__Analyze::Get_S8(int8u Bits, int64u &Info, const char* Name)
 {
     INTEGRITY_INT(Bits<=BS->Remain(), "Size is wrong", BS->Offset_Get())
     Info=BS->Get8(Bits);
-    if (Trace_Activated) Param(Name, Info);
+    #if MEDIAINFO_TRACE
+        if (Trace_Activated)
+        {
+            Param(Name, Info);
+            Param_Info(__T("(")+Ztring::ToZtring(Bits)+__T(" bits)"));
+        }
+    #endif //MEDIAINFO_TRACE
 }
 
 //---------------------------------------------------------------------------
@@ -2200,12 +2300,14 @@ void File__Analyze::Skip_SB(              const char* Name)
 void File__Analyze::Skip_S1(int8u Bits, const char* Name)
 {
     INTEGRITY(Bits<=BS->Remain(), "Size is wrong", BS->Offset_Get())
-    if (Trace_Activated)
-    {
-        Param(Name, BS->Get1(Bits));
-        Param_Info(__T("(")+Ztring::ToZtring(Bits)+__T(" bits)"));
-    }
-    else
+    #if MEDIAINFO_TRACE
+        if (Trace_Activated)
+        {
+            Param(Name, BS->Get1(Bits));
+            Param_Info(__T("(")+Ztring::ToZtring(Bits)+__T(" bits)"));
+        }
+        else
+    #endif //MEDIAINFO_TRACE
         BS->Skip(Bits);
 }
 
@@ -2213,9 +2315,14 @@ void File__Analyze::Skip_S1(int8u Bits, const char* Name)
 void File__Analyze::Skip_S2(int8u Bits, const char* Name)
 {
     INTEGRITY(Bits<=BS->Remain(), "Size is wrong", BS->Offset_Get())
-    if (Trace_Activated)
-        Param(Name, BS->Get2(Bits));
-    else
+    #if MEDIAINFO_TRACE
+        if (Trace_Activated)
+        {
+            Param(Name, BS->Get2(Bits));
+            Param_Info(__T("(")+Ztring::ToZtring(Bits)+__T(" bits)"));
+        }
+        else
+    #endif //MEDIAINFO_TRACE
         BS->Skip(Bits);
 }
 
@@ -2223,9 +2330,14 @@ void File__Analyze::Skip_S2(int8u Bits, const char* Name)
 void File__Analyze::Skip_S3(int8u Bits, const char* Name)
 {
     INTEGRITY(Bits<=BS->Remain(), "Size is wrong", BS->Offset_Get())
-    if (Trace_Activated)
-        Param(Name, BS->Get4(Bits));
-    else
+    #if MEDIAINFO_TRACE
+        if (Trace_Activated)
+        {
+            Param(Name, BS->Get4(Bits));
+            Param_Info(__T("(")+Ztring::ToZtring(Bits)+__T(" bits)"));
+        }
+        else
+    #endif //MEDIAINFO_TRACE
         BS->Skip(Bits);
 }
 
@@ -2233,9 +2345,14 @@ void File__Analyze::Skip_S3(int8u Bits, const char* Name)
 void File__Analyze::Skip_S4(int8u Bits, const char* Name)
 {
     INTEGRITY(Bits<=BS->Remain(), "Size is wrong", BS->Offset_Get())
-    if (Trace_Activated)
-        Param(Name, BS->Get4(Bits));
-    else
+    #if MEDIAINFO_TRACE
+        if (Trace_Activated)
+        {
+            Param(Name, BS->Get4(Bits));
+            Param_Info(__T("(")+Ztring::ToZtring(Bits)+__T(" bits)"));
+        }
+        else
+    #endif //MEDIAINFO_TRACE
         BS->Skip(Bits);
 }
 
@@ -2243,9 +2360,14 @@ void File__Analyze::Skip_S4(int8u Bits, const char* Name)
 void File__Analyze::Skip_S5(int8u Bits, const char* Name)
 {
     INTEGRITY(Bits<=BS->Remain(), "Size is wrong", BS->Offset_Get())
-    if (Trace_Activated)
-        Param(Name, BS->Get8(Bits));
-    else
+    #if MEDIAINFO_TRACE
+        if (Trace_Activated)
+        {
+            Param(Name, BS->Get8(Bits));
+            Param_Info(__T("(")+Ztring::ToZtring(Bits)+__T(" bits)"));
+        }
+        else
+    #endif //MEDIAINFO_TRACE
         BS->Skip(Bits);
 }
 
@@ -2253,9 +2375,14 @@ void File__Analyze::Skip_S5(int8u Bits, const char* Name)
 void File__Analyze::Skip_S6(int8u Bits, const char* Name)
 {
     INTEGRITY(Bits<=BS->Remain(), "Size is wrong", BS->Offset_Get())
-    if (Trace_Activated)
-        Param(Name, BS->Get8(Bits));
-    else
+    #if MEDIAINFO_TRACE
+        if (Trace_Activated)
+        {
+            Param(Name, BS->Get8(Bits));
+            Param_Info(__T("(")+Ztring::ToZtring(Bits)+__T(" bits)"));
+        }
+        else
+    #endif //MEDIAINFO_TRACE
         BS->Skip(Bits);
 }
 
@@ -2263,9 +2390,14 @@ void File__Analyze::Skip_S6(int8u Bits, const char* Name)
 void File__Analyze::Skip_S7(int8u Bits, const char* Name)
 {
     INTEGRITY(Bits<=BS->Remain(), "Size is wrong", BS->Offset_Get())
-    if (Trace_Activated)
-        Param(Name, BS->Get8(Bits));
-    else
+    #if MEDIAINFO_TRACE
+        if (Trace_Activated)
+        {
+            Param(Name, BS->Get8(Bits));
+            Param_Info(__T("(")+Ztring::ToZtring(Bits)+__T(" bits)"));
+        }
+        else
+    #endif //MEDIAINFO_TRACE
         BS->Skip(Bits);
 }
 
@@ -2273,9 +2405,14 @@ void File__Analyze::Skip_S7(int8u Bits, const char* Name)
 void File__Analyze::Skip_S8(int8u Bits, const char* Name)
 {
     INTEGRITY(Bits<=BS->Remain(), "Size is wrong", BS->Offset_Get())
-    if (Trace_Activated)
-        Param(Name, BS->Get8(Bits));
-    else
+    #if MEDIAINFO_TRACE
+        if (Trace_Activated)
+        {
+            Param(Name, BS->Get8(Bits));
+            Param_Info(__T("(")+Ztring::ToZtring(Bits)+__T(" bits)"));
+        }
+        else
+    #endif //MEDIAINFO_TRACE
         BS->Skip(Bits);
 }
 
@@ -2354,8 +2491,8 @@ void File__Analyze::Get_T1(size_t Bits, int8u &Info, const char* Name)
     Info=BT->Get1(Bits);
     if (Trace_Activated)
     {
-        Param(Name, Info);
         Param_Info(__T("(")+Ztring::ToZtring(Bits)+__T(" bits)"));
+        Param(Name, Info);
     }
 }
 
@@ -2459,8 +2596,8 @@ void File__Analyze::Skip_T1(size_t Bits, const char* Name)
     INTEGRITY(Bits<=BT->Remain(), "Size is wrong", BT->Offset_Get())
     if (Trace_Activated)
     {
-        Param(Name, BT->Get1(Bits));
         Param_Info(__T("(")+Ztring::ToZtring(Bits)+__T(" bits)"));
+        Param(Name, BT->Get1(Bits));
     }
     else
         BT->Skip1(Bits);
