@@ -60,7 +60,7 @@ void File__Analyze::Streams_Finish_Global()
             Fill(Stream_Video, 0, Video_FrameCount, Frame_Count_NotParsedIncluded);
         else if (Config->File_Names.size()>1)
             Fill(Stream_Video, 0, Video_FrameCount, Config->File_Names.size());
-        #if MEDIAINFO_IBI
+        #if MEDIAINFO_IBIUSAGE
         else
         {
             //External IBI
@@ -83,7 +83,7 @@ void File__Analyze::Streams_Finish_Global()
             if (IbiStream && !IbiStream->Infos.empty() && IbiStream->Infos[IbiStream->Infos.size()-1].IsContinuous && IbiStream->Infos[IbiStream->Infos.size()-1].FrameNumber!=(int64u)-1)
                 Fill(Stream_Video, 0, Video_FrameCount, IbiStream->Infos[IbiStream->Infos.size()-1].FrameNumber);
         }
-        #endif //MEDIAINFO_IBI
+        #endif //MEDIAINFO_IBIUSAGE
     }
 
     Streams_Finish_StreamOnly();
@@ -100,7 +100,7 @@ void File__Analyze::Streams_Finish_Global()
 }
 
 //---------------------------------------------------------------------------
-void File__Analyze::TestContinuousFileNames(size_t CountOfFiles, Ztring FileExtension)
+void File__Analyze::TestContinuousFileNames(size_t CountOfFiles, Ztring FileExtension, bool SkipComputeDelay)
 {
     if (IsSub || !Config->File_TestContinuousFileNames_Get())
         return;
@@ -110,6 +110,7 @@ void File__Analyze::TestContinuousFileNames(size_t CountOfFiles, Ztring FileExte
         return;
 
     //Trying to detect continuous file names (e.g. video stream as an image or HLS)
+    size_t Pos_Base = (size_t)-1;
     bool AlreadyPresent=Config->File_Names.size()==1?true:false;
     FileName FileToTest(Config->File_Names.Read(Config->File_Names.size()-1));
     Ztring FileToTest_Name=FileToTest.Name_Get();
@@ -144,10 +145,35 @@ void File__Analyze::TestContinuousFileNames(size_t CountOfFiles, Ztring FileExte
         //Detecting with a smarter algo (but missing frames are not detected)
         Ztring FileToTest_Name_Begin=FileToTest.Path_Get()+PathSeparator+FileToTest_Name;
         Ztring FileToTest_Name_End=FileToTest_Name_After+__T('.')+(FileExtension.empty()?FileToTest.Extension_Get():FileExtension);
-        size_t Pos_Base = (size_t)Pos;
+        Pos_Base = (size_t)Pos;
         size_t Pos_Add_Max = 1;
         #if MEDIAINFO_ADVANCED
             bool File_IgnoreSequenceFileSize=Config->File_IgnoreSequenceFilesCount_Get(); //TODO: double check if it is expected
+
+            size_t SequenceFileSkipFrames=Config->File_SequenceFilesSkipFrames_Get();
+            if (SequenceFileSkipFrames)
+            {
+                for (;;)
+                {
+                    size_t Pos_Add_Max_Old=Pos_Add_Max;
+                    for (size_t TempPos=Pos_Add_Max; TempPos<=Pos_Add_Max+SequenceFileSkipFrames; TempPos++)
+                    {
+                        Ztring Pos_Ztring; Pos_Ztring.From_Number(Pos_Base+TempPos);
+                        if (Numbers_Size>Pos_Ztring.size())
+                            Pos_Ztring.insert(0, Numbers_Size-Pos_Ztring.size(), __T('0'));
+                        Ztring Next=FileToTest_Name_Begin+Pos_Ztring+FileToTest_Name_End;
+                        if (File::Exists(Next))
+                        {
+                            Pos_Add_Max=TempPos+1;
+                            break;
+                        }
+                    }
+                    if (Pos_Add_Max==Pos_Add_Max_Old)
+                        break;
+                }
+            }
+            else
+            {
         #endif //MEDIAINFO_ADVANCED
         for (;;)
         {
@@ -177,6 +203,10 @@ void File__Analyze::TestContinuousFileNames(size_t CountOfFiles, Ztring FileExte
                 Pos_Add_Max=Pos_Add_Middle;
         }
 
+        #if MEDIAINFO_ADVANCED
+            } //SequenceFileSkipFrames
+        #endif //MEDIAINFO_ADVANCED
+
         size_t Pos_Max = Pos_Base + Pos_Add_Max;
         Config->File_Names.reserve(Pos_Add_Max);
         for (Pos=Pos_Base+1; Pos<Pos_Max; ++Pos)
@@ -194,6 +224,16 @@ void File__Analyze::TestContinuousFileNames(size_t CountOfFiles, Ztring FileExte
     if (Config->File_Names.size()==Pos)
         return;
 
+    Config->File_IsImageSequence=true;
+    Frame_Count_NotParsedIncluded=Pos_Base;
+    #if MEDIAINFO_DEMUX
+        float64 Demux_Rate=Config->Demux_Rate_Get();
+        if (!Demux_Rate)
+            Demux_Rate=24;
+        if (!SkipComputeDelay)
+            Fill(Stream_Video, 0, Video_Delay, float64_int64s(Frame_Count_NotParsedIncluded*1000/Demux_Rate));
+    #endif //MEDIAINFO_DEMUX
+
     #if MEDIAINFO_ADVANCED
         if (!Config->File_IgnoreSequenceFileSize_Get() || Config->File_Names.size()<=1)
     #endif //MEDIAINFO_ADVANCED
@@ -381,16 +421,16 @@ void File__Analyze::Streams_Finish_StreamOnly_Video(size_t Pos)
     //Standard
     if (Retrieve(Stream_Video, Pos, Video_Standard).empty() && (Retrieve(Stream_Video, Pos, Video_Width)==__T("720") || Retrieve(Stream_Video, Pos, Video_Width)==__T("704")))
     {
-             if (Retrieve(Stream_Video, Pos, Video_Height)==__T("576"))
+             if (Retrieve(Stream_Video, Pos, Video_Height)==__T("576") && Retrieve(Stream_Video, Pos, Video_FrameRate)==__T("25.000"))
             Fill(Stream_Video, Pos, Video_Standard, "PAL");
-        else if (Retrieve(Stream_Video, Pos, Video_Height)==__T("486") || Retrieve(Stream_Video, Pos, Video_Height)==__T("480"))
+        else if ((Retrieve(Stream_Video, Pos, Video_Height)==__T("486") || Retrieve(Stream_Video, Pos, Video_Height)==__T("480")) && Retrieve(Stream_Video, Pos, Video_FrameRate)==__T("29.970"))
             Fill(Stream_Video, Pos, Video_Standard, "NTSC");
     }
     if (Retrieve(Stream_Video, Pos, Video_Standard).empty() && Retrieve(Stream_Video, Pos, Video_Width)==__T("352"))
     {
-             if (Retrieve(Stream_Video, Pos, Video_Height)==__T("576") || Retrieve(Stream_Video, Pos, Video_Height)==__T("288"))
+             if ((Retrieve(Stream_Video, Pos, Video_Height)==__T("576") || Retrieve(Stream_Video, Pos, Video_Height)==__T("288")) && Retrieve(Stream_Video, Pos, Video_FrameRate)==__T("25.000"))
             Fill(Stream_Video, Pos, Video_Standard, "PAL");
-        else if (Retrieve(Stream_Video, Pos, Video_Height)==__T("486") || Retrieve(Stream_Video, Pos, Video_Height)==__T("480") || Retrieve(Stream_Video, Pos, Video_Height)==__T("243") || Retrieve(Stream_Video, Pos, Video_Height)==__T("240"))
+        else if ((Retrieve(Stream_Video, Pos, Video_Height)==__T("486") || Retrieve(Stream_Video, Pos, Video_Height)==__T("480") || Retrieve(Stream_Video, Pos, Video_Height)==__T("243") || Retrieve(Stream_Video, Pos, Video_Height)==__T("240")) && Retrieve(Stream_Video, Pos, Video_FrameRate)==__T("29.970"))
             Fill(Stream_Video, Pos, Video_Standard, "NTSC");
     }
 
@@ -402,6 +442,11 @@ void File__Analyze::Streams_Finish_StreamOnly_Video(size_t Pos)
       || Retrieve(Stream_Video, Pos, Video_Format)==__T("EXR")))
             Fill(Stream_Video, Pos, Video_ScanType, "Progressive");
 
+    //Useless chroma subsampling
+    if (Retrieve(Stream_Video, Pos, Video_ColorSpace)==__T("RGB")
+     && Retrieve(Stream_Video, Pos, Video_ChromaSubsampling)==__T("4:4:4"))
+        Clear(Stream_Video, Pos, Video_ChromaSubsampling);
+
     //Commercial name
     #if defined(MEDIAINFO_VC3_YES)
         if (Retrieve(Stream_Video, Pos, Video_Format_Commercial_IfAny).empty() && Retrieve(Stream_Video, Pos, Video_Format)==__T("VC-3"))
@@ -551,6 +596,48 @@ void File__Analyze::Streams_Finish_StreamOnly_Audio(size_t Pos)
             Fill(Stream_Audio, 0, Audio_FrameCount, Frame_Count_NotParsedIncluded);
     }
 
+    //FrameRate same as SampleRate
+    if (Retrieve(Stream_Audio, Pos, Audio_SamplingRate).To_float64() == Retrieve(Stream_Audio, Pos, Audio_FrameRate).To_float64())
+        Clear(Stream_Audio, Pos, Audio_FrameRate);
+
+    //SamplingRate
+    if (Retrieve(Stream_Audio, Pos, Audio_SamplingRate).empty())
+    {
+        float64 BitDepth=Retrieve(Stream_Audio, Pos, Audio_BitDepth).To_float64();
+        float64 Channels=Retrieve(Stream_Audio, Pos, Audio_Channel_s_).To_float64();
+        float64 BitRate=Retrieve(Stream_Audio, Pos, Audio_BitRate).To_float64();
+        if (BitDepth && Channels && BitRate)
+            Fill(Stream_Audio, Pos, Audio_SamplingRate, BitRate/Channels/BitDepth, 0);
+    }
+
+    //SamplesPerFrames
+    if (Retrieve(Stream_Audio, Pos, Audio_SamplesPerFrame).empty())
+    {
+        float64 FrameRate=Retrieve(Stream_Audio, Pos, Audio_FrameRate).To_float64();
+        float64 SamplingRate=0;
+        ZtringList SamplingRates;
+        SamplingRates.Separator_Set(0, " / ");
+        SamplingRates.Write(Retrieve(Stream_Audio, Pos, Audio_SamplingRate));
+        for (size_t i=0; i<SamplingRates.size(); ++i)
+        {
+            SamplingRate = SamplingRates[i].To_float64();
+            if (SamplingRate)
+                break; // Using the first valid one
+        }
+        if (FrameRate && SamplingRate && FrameRate!=SamplingRate)
+        {
+            float64 SamplesPerFrameF=SamplingRate/FrameRate;
+            Ztring SamplesPerFrame;
+            if (SamplesPerFrameF>1601 && SamplesPerFrameF<1602)
+                SamplesPerFrame = __T("1601.6"); // Usually this is 29.970 fps PCM. TODO: check if it is OK in all cases
+            else if (SamplesPerFrameF>800 && SamplesPerFrameF<801)
+                SamplesPerFrame = __T("800.8"); // Usually this is 59.940 fps PCM. TODO: check if it is OK in all cases
+            else
+                SamplesPerFrame.From_Number(SamplesPerFrameF, 0);
+            Fill(Stream_Audio, Pos, Audio_SamplesPerFrame, SamplesPerFrame);
+        }
+    }
+
     //Duration
     if (Retrieve(Stream_Audio, Pos, Audio_Duration).empty() && Retrieve(Stream_Audio, Pos, Audio_SamplingRate).To_int64u()!=0)
     {
@@ -578,8 +665,16 @@ void File__Analyze::Streams_Finish_StreamOnly_Audio(size_t Pos)
 }
 
 //---------------------------------------------------------------------------
-void File__Analyze::Streams_Finish_StreamOnly_Text(size_t UNUSED(Pos))
+void File__Analyze::Streams_Finish_StreamOnly_Text(size_t Pos)
 {
+    //FrameRate from FrameCount and Duration
+    if (Retrieve(Stream_Text, Pos, Text_FrameRate).empty())
+    {
+        int64u FrameCount=Retrieve(Stream_Text, Pos, Text_FrameCount).To_int64u();
+        float64 Duration=Retrieve(Stream_Text, Pos, Text_Duration).To_float64()/1000;
+        if (FrameCount && Duration)
+           Fill(Stream_Text, Pos, Text_FrameRate, FrameCount/Duration, 3);
+    }
 }
 
 //---------------------------------------------------------------------------
@@ -874,7 +969,7 @@ void File__Analyze::Streams_Finish_InterStreams()
     }
 
     //FrameCount if General not filled
-    if (Retrieve(Stream_General, 0, General_FrameCount).empty() && Count_Get(Stream_Video))
+    if (Retrieve(Stream_General, 0, General_FrameCount).empty() && Count_Get(Stream_Video) && Retrieve(Stream_General, 0, "IsTruncated").empty())
     {
         Ztring FrameCount=Retrieve(Stream_Video, 0, Video_FrameCount);
         bool IsOk=true;
@@ -933,6 +1028,20 @@ void File__Analyze::Streams_Finish_HumanReadable_PerStream(stream_t StreamKind,
          && Retrieve(StreamKind, StreamPos, Video_FrameRate_Minimum).To_int32u()==24
          && Retrieve(StreamKind, StreamPos, Video_FrameRate_Maximum).To_int32u()==30)
             Fill(Stream_Video, StreamPos_Last, Video_FrameRate_String, MediaInfoLib::Config.Language_Get(Retrieve(StreamKind, StreamPos, Video_FrameRate)+__T(" (24/30)"), __T(" fps")), true);
+
+        //Special cases - Frame rate
+        if (StreamKind==Stream_Video
+         && Parameter==Video_FrameRate
+         && !Retrieve(StreamKind, StreamPos, Video_FrameRate).empty()
+         && !Retrieve(StreamKind, StreamPos, Video_FrameRate_Num).empty()
+         && !Retrieve(StreamKind, StreamPos, Video_FrameRate_Den).empty())
+            Fill(Stream_Video, StreamPos, Video_FrameRate_String, MediaInfoLib::Config.Language_Get(Retrieve(StreamKind, StreamPos, Video_FrameRate)+__T(" (")+Retrieve(StreamKind, StreamPos, Video_FrameRate_Num)+__T("/")+Retrieve(StreamKind, StreamPos, Video_FrameRate_Den)+__T(")"), __T(" fps")), true);
+        if (StreamKind==Stream_Video
+         && Parameter==Video_FrameRate_Original
+         && !Retrieve(StreamKind, StreamPos, Video_FrameRate_Original).empty()
+         && !Retrieve(StreamKind, StreamPos, Video_FrameRate_Original_Num).empty()
+         && !Retrieve(StreamKind, StreamPos, Video_FrameRate_Original_Den).empty())
+            Fill(Stream_Video, StreamPos, Video_FrameRate_Original_String, MediaInfoLib::Config.Language_Get(Retrieve(StreamKind, StreamPos, Video_FrameRate_Original)+__T(" (")+Retrieve(StreamKind, StreamPos, Video_FrameRate_Original_Num)+__T("/")+Retrieve(StreamKind, StreamPos, Video_FrameRate_Original_Den)+__T(")"), __T(" fps")), true);
     }
 
     //BitRate_Mode / OverallBitRate_Mode
@@ -952,19 +1061,65 @@ void File__Analyze::Streams_Finish_HumanReadable_PerStream(stream_t StreamKind,
         Fill(StreamKind, StreamPos, StreamKind==Stream_General?"OverallBitRate_Mode/String":"BitRate_Mode/String", Translated.find(__T("BitRate_Mode_"))?Translated:Value);
     }
 
-    //Encoded_Library
-    if ((ParameterName==__T("Encoded_Library")
-         || ParameterName==__T("Encoded_Library/Name")
-         || ParameterName==__T("Encoded_Library/Version")
-         || ParameterName==__T("Encoded_Library/Date"))
-        && Retrieve(StreamKind, StreamPos, "Encoded_Library/String").empty())
+    //Encoded_Application
+    if ((   ParameterName==__T("Encoded_Application")
+         || ParameterName==__T("Encoded_Application_CompanyName")
+         || ParameterName==__T("Encoded_Application_Name")
+         || ParameterName==__T("Encoded_Application_Version")
+         || ParameterName==__T("Encoded_Application_Date"))
+        && Retrieve(StreamKind, StreamPos, "Encoded_Application/String").empty())
     {
-        Ztring Name=Retrieve(StreamKind, StreamPos, "Encoded_Library/Name");
-        Ztring Version=Retrieve(StreamKind, StreamPos, "Encoded_Library/Version");
-        Ztring Date=Retrieve(StreamKind, StreamPos, "Encoded_Library/Date");
+        Ztring CompanyName=Retrieve(StreamKind, StreamPos, "Encoded_Application_CompanyName");
+        Ztring Name=Retrieve(StreamKind, StreamPos, "Encoded_Application_Name");
+        Ztring Version=Retrieve(StreamKind, StreamPos, "Encoded_Application_Version");
+        Ztring Date=Retrieve(StreamKind, StreamPos, "Encoded_Application_Date");
         if (!Name.empty())
         {
-            Ztring String=Name;
+            Ztring String;
+            if (!CompanyName.empty())
+            {
+                String+=CompanyName;
+                String+=__T(" ");
+            }
+            String+=Name;
+            if (!Version.empty())
+            {
+                String+=__T(" ");
+                String+=Version;
+            }
+            if (!Date.empty())
+            {
+                String+=__T(" (");
+                String+=Date;
+                String+=__T(")");
+            }
+            Fill(StreamKind, StreamPos, "Encoded_Application/String", String, true);
+        }
+        else
+            Fill(StreamKind, StreamPos, "Encoded_Application/String", Retrieve(StreamKind, StreamPos, "Encoded_Application"), true);
+    }
+
+    //Encoded_Library
+    if ((   ParameterName==__T("Encoded_Library")
+         || ParameterName==__T("Encoded_Library_CompanyName")
+         || ParameterName==__T("Encoded_Library_Name")
+         || ParameterName==__T("Encoded_Library_Version")
+         || ParameterName==__T("Encoded_Library_Date"))
+        && Retrieve(StreamKind, StreamPos, "Encoded_Library/String").empty())
+    {
+        Ztring CompanyName=Retrieve(StreamKind, StreamPos, "Encoded_Library_CompanyName");
+        Ztring Name=Retrieve(StreamKind, StreamPos, "Encoded_Library_Name");
+        Ztring Version=Retrieve(StreamKind, StreamPos, "Encoded_Library_Version");
+        Ztring Date=Retrieve(StreamKind, StreamPos, "Encoded_Library_Date");
+        if (!Name.empty())
+        {
+            Ztring String;
+            if (!CompanyName.empty())
+            {
+                String+=CompanyName;
+                String+=__T(" ");
+            }
+            String+=Name;
             if (!Version.empty())
             {
                 String+=__T(" ");
