@@ -106,6 +106,40 @@ const char* DPX_Descriptors(int8u i)
     return "Reserved for future formats";
 }
 
+//---------------------------------------------------------------------------
+const char* DPX_Descriptors_ColorSpace(int8u i)
+{
+    switch (i)
+    {
+        case   1: return "R";
+        case   2: return "G";
+        case   3: return "B";
+        case   4: return "A";
+        case   6: return "Y";
+        case   7: return "UV";
+        case   8: return "Z";
+        case  50: return "RGB";
+        case  51:
+        case  52: return "RGBA";
+        case 100:
+        case 102:
+        case 103: return "YUV";
+        case 101: return "YUVA";
+        default : return "";
+    }
+}
+
+//---------------------------------------------------------------------------
+const char* DPX_Descriptors_ChromaSubsampling(int8u i)
+{
+    switch (i)
+    {
+        case 100:
+        case 101: return "4:2:2";
+        default : return "";
+    }
+}
+
 //---------------------------------------------------------------------------
 const char* Mpegv_transfer_characteristics(int8u transfer_characteristics);
 const char* DPX_TransferCharacteristic(int8u TransferCharacteristic)
@@ -265,6 +299,66 @@ enum Elements
     Pos_ImageData,
 };
 
+//***************************************************************************
+// Helpers
+//***************************************************************************
+
+//
+string DPX_DateTime2Iso(const string &FromDpx)
+{
+    if (FromDpx.size()<20
+     || FromDpx[ 0]<'0' || FromDpx[ 0]>'9'
+     || FromDpx[ 1]<'0' || FromDpx[ 1]>'9'
+     || FromDpx[ 2]<'0' || FromDpx[ 2]>'9'
+     || FromDpx[ 3]<'0' || FromDpx[ 3]>'9'
+     || FromDpx[ 4] != ':'
+     || FromDpx[ 5]<'0' || FromDpx[ 5]>'9'
+     || FromDpx[ 6]<'0' || FromDpx[ 6]>'9'
+     || FromDpx[ 7] != ':'
+     || FromDpx[ 8]<'0' || FromDpx[ 8]>'9'
+     || FromDpx[ 9]<'0' || FromDpx[ 9]>'9'
+     || FromDpx[10] != ':'
+     || FromDpx[11]<'0' || FromDpx[11]>'9'
+     || FromDpx[12]<'0' || FromDpx[12]>'9'
+     || FromDpx[13] != ':'
+     || FromDpx[14]<'0' || FromDpx[14]>'9'
+     || FromDpx[15]<'0' || FromDpx[15]>'9'
+     || FromDpx[16] != ':'
+     || FromDpx[17]<'0' || FromDpx[17]>'9'
+     || FromDpx[18]<'0' || FromDpx[18]>'9'
+     )
+        return FromDpx; //Invalid, returning the value in the file
+
+    // Date/Time
+    string ToReturn(FromDpx.substr(0, 19));
+    ToReturn[ 4]='-';
+    ToReturn[ 7]='-';
+    ToReturn[10]='T'; // Note: should be 'T' (ISO 8601), TODO: change to 'T' during next API change
+
+    // Time zone
+    if (FromDpx.size()>20)
+    {
+        size_t Offset;
+        if (FromDpx[19]==':') // Note: Cineon and DPX v1 header date/time format is with ":LTZ", DPX v2 date/time format is "LTZ", but both are atually seen in any version. Always testing both.
+            Offset=20;
+        else
+            Offset=19;
+
+        size_t Max=FromDpx.find('\0');
+        if (Max==(size_t)-1)
+            Max=FromDpx.size();
+
+        ToReturn+=FromDpx.substr(Offset, Max-Offset);
+
+        if (ToReturn.size()>22)
+            ToReturn.insert(ToReturn.begin(), ':'); //Hours/Minutes offset sepearator added
+        else if (ToReturn.size()==22 && (ToReturn[19]=='+' || ToReturn[19]=='-'))
+            ToReturn+=":00"; // Minutes offset, default
+    }
+
+    return ToReturn;
+}
+
 //***************************************************************************
 // Constructor/Destructor
 //***************************************************************************
@@ -439,7 +533,7 @@ void File_Dpx::GenericSectionHeader_Cineon()
 
     //Parsing
     Element_Begin1("File information");
-    Ztring CreationDate, CreationTime;
+    string CreationDate, CreationTime;
     string Version;
     int32u Size_Header, Size_Total, Size_Generic, Size_Industry, Size_User;
     Skip_B4(                                                    "Magic number");
@@ -450,8 +544,8 @@ void File_Dpx::GenericSectionHeader_Cineon()
     Get_X4 (Size_Total,                                         "Total image file size");
     Get_String(8, Version,                                      "Version number of header format");
     Skip_UTF8  (100,                                            "FileName");
-    Get_UTF8   (12,  CreationDate,                              "Creation Date");
-    Get_UTF8   (12,  CreationTime,                              "Creation Time");
+    Get_String (12,  CreationDate,                              "Creation Date");
+    Get_String (12,  CreationTime,                              "Creation Time");
     Skip_XX(36,                                                 "Reserved for future use");
     Element_End0();
 
@@ -491,8 +585,8 @@ void File_Dpx::GenericSectionHeader_Cineon()
     Skip_B4(                                                    "X offset");
     Skip_B4(                                                    "Y offset");
     Skip_UTF8  (100,                                            "FileName");
-    Get_UTF8   (12,  CreationDate,                              "Creation Date");
-    Get_UTF8   (12,  CreationTime,                              "Creation Time");
+    Get_String (12,  CreationDate,                              "Creation Date");
+    Get_String (12,  CreationTime,                              "Creation Time");
     Skip_UTF8(64,                                               "Input device");
     Skip_UTF8(32,                                               "Input device model number");
     Skip_UTF8(32,                                               "Input device serial number");
@@ -522,8 +616,8 @@ void File_Dpx::GenericSectionHeader_Cineon()
         //Filling meta
         if (Frame_Count==0)
         {
-            Fill(Stream_General, 0, General_Encoded_Date, CreationDate+__T(' ')+CreationTime); //ToDo: transform it in UTC
-            Fill(StreamKind_Last, StreamPos_Last, "Encoded_Date", CreationDate+__T(' ')+CreationTime); //ToDo: transform it in UTC
+            Fill(Stream_General, 0, General_Encoded_Date, DPX_DateTime2Iso(CreationDate+':'+CreationTime));
+            Fill(StreamKind_Last, StreamPos_Last, "Encoded_Date", DPX_DateTime2Iso(CreationDate+':'+CreationTime));
             Fill(StreamKind_Last, StreamPos_Last, "Format", "Cineom");
             if (Version.size()>2 && Version[0]=='V' && Version[1]>='0' && Version[2]<='9')
                 Version.insert(1, "ersion ");
@@ -653,8 +747,8 @@ void File_Dpx::GenericSectionHeader_Dpx()
         //Filling meta
         if (Frame_Count==0)
         {
-            Fill(Stream_General, 0, General_Encoded_Date, CreationDate); //ToDo: transform it in UTC
-            Fill(StreamKind_Last, StreamPos_Last, "Encoded_Date", CreationDate); //ToDo: transform it in UTC
+            Fill(Stream_General, 0, General_Encoded_Date, DPX_DateTime2Iso(CreationDate));
+            Fill(StreamKind_Last, StreamPos_Last, "Encoded_Date", DPX_DateTime2Iso(CreationDate));
             Fill(Stream_General, 0, General_Encoded_Library, Creator);
             Fill(StreamKind_Last, StreamPos_Last, "Encoded_Library", Creator);
             Fill(Stream_General, 0, "Project", Project); //ToDo: map to a MediaInfo field (which one?)
@@ -679,13 +773,13 @@ void File_Dpx::GenericSectionHeader_Dpx()
 void File_Dpx::GenericSectionHeader_Dpx_ImageElement()
 {
     Element_Begin1("image element");
-    int8u TransferCharacteristic, ColorimetricSpecification, BitDephs;
+    int8u Descriptor, TransferCharacteristic, ColorimetricSpecification, BitDephs;
     Info_B4(DataSign,                                           "Data sign");Param_Info1((DataSign==0?"unsigned":"signed"));
     Skip_B4(                                                    "Reference low data code value");
     Skip_BF4(                                                   "Reference low quantity represented");
     Skip_B4(                                                    "Reference high data code value");
     Skip_BF4(                                                   "Reference high quantity represented");
-    Info_B1(Descriptor,                                         "Descriptor");Param_Info1(DPX_Descriptors(Descriptor));
+    Get_B1 (Descriptor,                                         "Descriptor");Param_Info1(DPX_Descriptors(Descriptor));
     Get_B1 (TransferCharacteristic,                             "Transfer characteristic");Param_Info1(DPX_TransferCharacteristic(TransferCharacteristic));
     Get_B1 (ColorimetricSpecification,                          "Colorimetric specification");Param_Info1(DPX_ColorimetricSpecification(ColorimetricSpecification));
     Get_B1 (BitDephs,                                           "Bit depth");Param_Info1(DPX_ValidBitDephs(BitDephs));
@@ -700,6 +794,8 @@ void File_Dpx::GenericSectionHeader_Dpx_ImageElement()
     FILLING_BEGIN();
         if (Frame_Count==0)
         {
+            Fill(StreamKind_Last, StreamPos_Last, "ColorSpace", DPX_Descriptors_ColorSpace(Descriptor));
+            Fill(StreamKind_Last, StreamPos_Last, "ChromaSubsampling", DPX_Descriptors_ChromaSubsampling(Descriptor));
             Fill(StreamKind_Last, StreamPos_Last, "BitDepth", BitDephs);
             Fill(StreamKind_Last, StreamPos_Last, "colour_description_present", "Yes");
             Fill(StreamKind_Last, StreamPos_Last, "colour_primaries", DPX_TransferCharacteristic(TransferCharacteristic));
@@ -736,6 +832,7 @@ void File_Dpx::IndustrySpecificHeader_Dpx()
     Element_Name("Industry specific header");
 
     //Parsing
+    float32 FrameRate;
     Element_Begin1("Motion-picture film information");
     Skip_String(2,                                              "Film mfg. ID code");
     Skip_String(2,                                              "Film type");
@@ -746,7 +843,7 @@ void File_Dpx::IndustrySpecificHeader_Dpx()
     Skip_B4(                                                    "Frame position in sequence");
     Skip_B4(                                                    "Sequence length (frames)");
     Skip_B4(                                                    "Held count (1 = default)");
-    Skip_BF4(                                                   "Frame rate of original (frames/s)");
+    Get_BF4 (FrameRate,                                         "Frame rate of original (frames/s)");
     Skip_BF4(                                                   "Shutter angle of camera in degrees");
     Skip_UTF8(32,                                               "Frame identification - e.g. keyframe");
     Skip_UTF8(100,                                              "Slate information");
@@ -772,6 +869,11 @@ void File_Dpx::IndustrySpecificHeader_Dpx()
     Skip_BF4(                                                   "Integration time (s)");
     Skip_XX(76,                                                 "Reserved for future use");
     Element_End0();
+
+    FILLING_BEGIN();
+        if (FrameRate)
+            Fill(StreamKind_Last, StreamPos_Last, "FrameRate", FrameRate);
+    FILLING_END();
 }
 
 //---------------------------------------------------------------------------
