@@ -103,9 +103,6 @@ void File_Png::Streams_Accept()
     }
     else
         Stream_Prepare(StreamKind_Last);
-
-    //Configuration
-    Frame_Count_NotParsedIncluded=0;
 }
 
 //***************************************************************************
