@@ -1,22 +1,9 @@
-// MediaInfoList_Internal - A list of MediaInfo
-// Copyright (C) 2002-2012 MediaArea.net SARL, Info@MediaArea.net
-//
-// This library is free software: you can redistribute it and/or modify it
-// under the terms of the GNU Library General Public License as published by
-// the Free Software Foundation, either version 2 of the License, or
-// any later version.
-//
-// This library is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-// GNU Library General Public License for more details.
-//
-// You should have received a copy of the GNU Library General Public License
-// along with this library. If not, see <http://www.gnu.org/licenses/>.
-//
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-// MediaInfoList_Internal
+/*  Copyright (c) MediaArea.net SARL. All Rights Reserved.
+ *
+ *  Use of this source code is governed by a BSD-style license that can
+ *  be found in the License.html file in the root of the source tree.
+ */
+
 //+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 //
 // Give information about a lot of media files
@@ -31,10 +18,6 @@
 //---------------------------------------------------------------------------
 #include "MediaInfo/MediaInfo.h"
 #include "MediaInfo/MediaInfo_Internal.h"
-#include "MediaInfo/MediaInfo_Config_MediaInfo.h"
-#include "ZenLib/Thread.h"
-#include "ZenLib/CriticalSection.h"
-#include <vector>
 #include <queue>
 //---------------------------------------------------------------------------
 
@@ -70,11 +53,11 @@ public :
     char* Output_Buffer_Get (size_t File_Pos, size_t &Output_Buffer_Size);
 
     //Info
-    String        Option (const String &Option, const String &Value=String(__T("")));
+    String      Option (const String &Option, const String &Value=String(__T("")));
     static String Option_Static (const String &Option, const String &Value=String(__T("")));
-    size_t                  State_Get ();
-    size_t                  Count_Get (size_t FilePos, stream_t StreamKind, size_t StreamNumber=(size_t)-1);
-    size_t                  Count_Get ();
+    size_t      State_Get ();
+    size_t      Count_Get (size_t FilePos, stream_t StreamKind, size_t StreamNumber=(size_t)-1);
+    size_t      Count_Get ();
 
 private :
     std::vector<MediaInfo_Internal*> Info;
