@@ -125,7 +125,7 @@ namespace MediaInfoLib
 {
 
 //---------------------------------------------------------------------------
-const Char*  MediaInfo_Version=__T("MediaInfoLib - v0.7.73");
+const Char*  MediaInfo_Version=__T("MediaInfoLib - v0.7.82");
 const Char*  MediaInfo_Url=__T("http://MediaArea.net/MediaInfo");
       Ztring EmptyZtring;       //Use it when we can't return a reference to a true Ztring
 const Ztring EmptyZtring_Const; //Use it when we can't return a reference to a true Ztring, const version
@@ -216,10 +216,12 @@ void MediaInfo_Config::Init()
     ParseSpeed=(float32)0.5;
     Verbosity=(float32)0.5;
     Trace_Level=(float32)0.0;
+    Compat=70778;
     Trace_TimeSection_OnlyFirstOccurrence=false;
     Trace_Format=Trace_Format_Tree;
     Language_Raw=false;
     ReadByHuman=true;
+    Legacy=true;
     LegacyStreamDisplay=true;
     SkipBinaryData=false;
     Demux=0;
@@ -412,6 +414,15 @@ Ztring MediaInfo_Config::Option (const String &Option, const String &Value_Raw)
     {
         return ReadByHuman_Get()?__T("1"):__T("0");
     }
+    else if (Option_Lower==__T("legacy"))
+    {
+        Legacy_Set(Value.To_int8u()?true:false);
+        return Ztring();
+    }
+    else if (Option_Lower==__T("legacy_get"))
+    {
+        return Legacy_Get()?__T("1"):__T("0");
+    }
     else if (Option_Lower==__T("legacystreamdisplay"))
     {
         LegacyStreamDisplay_Set(Value.To_int8u()?true:false);
@@ -560,6 +571,8 @@ Ztring MediaInfo_Config::Option (const String &Option, const String &Value_Raw)
     }
     else if (Option_Lower==__T("details")) //Legacy for trace_level
     {
+        if (Value == __T("0"))
+            Trace_Level=0;
         return MediaInfo_Config::Option(__T("Trace_Level"), Value);
     }
     else if (Option_Lower==__T("details_get")) //Legacy for trace_level
@@ -577,6 +590,13 @@ Ztring MediaInfo_Config::Option (const String &Option, const String &Value_Raw)
     else if (Option_Lower==__T("trace_level"))
     {
         Trace_Level_Set(Value);
+        if (Inform_Get()==__T("MAXML"))
+            Trace_Format_Set(Trace_Format_XML); // All must be XML
+        if (Inform_Get()==__T("XML") || Inform_Get()==__T("MAXML"))
+        {
+            Inform_Set(Ztring());
+            Trace_Format_Set(Trace_Format_XML); // TODO: better coherency in options
+        }
         return Ztring();
     }
     else if (Option_Lower==__T("trace_level_get"))
@@ -608,6 +628,8 @@ Ztring MediaInfo_Config::Option (const String &Option, const String &Value_Raw)
         CriticalSectionLocker CSL(CS);
         if (NewValue_Lower==__T("csv"))
             Trace_Format_Set(Trace_Format_CSV);
+        else if (NewValue_Lower==__T("xml") || NewValue_Lower==__T("MAXML"))
+            Trace_Format_Set(Trace_Format_XML);
         else
             Trace_Format_Set(Trace_Format_Tree);
         return Ztring();
@@ -820,6 +842,22 @@ Ztring MediaInfo_Config::Option (const String &Option, const String &Value_Raw)
     {
         return MpegTs_ForceStreamDisplay_Get()?__T("1"):__T("0");
     }
+    else if (Option_Lower==__T("maxml_streamkinds"))
+    {
+        #if MEDIAINFO_ADVANCED
+            return MAXML_StreamKinds_Get();
+        #else // MEDIAINFO_ADVANCED
+            return __T("advanced features are disabled due to compilation options");
+        #endif // MEDIAINFO_ADVANCED
+    }
+    else if (Option_Lower==__T("maxml_fields"))
+    {
+        #if MEDIAINFO_ADVANCED
+            return MAXML_Fields_Get(Value);
+        #else // MEDIAINFO_ADVANCED
+            return __T("advanced features are disabled due to compilation options");
+        #endif // MEDIAINFO_ADVANCED
+    }
     else if (Option_Lower==__T("custommapping"))
     {
         CustomMapping_Set(Value);
@@ -1103,6 +1141,19 @@ bool MediaInfo_Config::ReadByHuman_Get ()
     return ReadByHuman;
 }
 
+//---------------------------------------------------------------------------
+void MediaInfo_Config::Legacy_Set (bool NewValue)
+{
+    CriticalSectionLocker CSL(CS);
+    Legacy=NewValue;
+}
+
+bool MediaInfo_Config::Legacy_Get ()
+{
+    CriticalSectionLocker CSL(CS);
+    return Legacy;
+}
+
 //---------------------------------------------------------------------------
 void MediaInfo_Config::LegacyStreamDisplay_Set (bool NewValue)
 {
@@ -1164,6 +1215,19 @@ float32 MediaInfo_Config::Trace_Level_Get ()
     return Trace_Level;
 }
 
+//---------------------------------------------------------------------------
+void MediaInfo_Config::Compat_Set (int64u NewValue)
+{
+    CriticalSectionLocker CSL(CS);
+    Compat=NewValue;
+}
+
+int64u MediaInfo_Config::Compat_Get ()
+{
+    CriticalSectionLocker CSL(CS);
+    return Compat;
+}
+
 std::bitset<32> MediaInfo_Config::Trace_Layers_Get ()
 {
     CriticalSectionLocker CSL(CS);
@@ -1427,7 +1491,13 @@ Ztring MediaInfo_Config::Language_Get (const Ztring &Value)
     CriticalSectionLocker CSL(CS);
 
     if (Value.find(__T(" / "))==string::npos)
-        return Language.Get(Value);
+    {
+        if (Value.size()<7 || Value.find(__T("/String"))+7!=Value.size())
+            return Language.Get(Value);
+        Ztring Temp(Value);
+        Temp.resize(Value.size()-7);
+        return Language.Get(Temp);
+    }
 
     ZtringList List;
     List.Separator_Set(0, __T(" / "));
@@ -1444,8 +1514,8 @@ Ztring MediaInfo_Config::Language_Get (const Ztring &Value)
 Ztring MediaInfo_Config::Language_Get (const Ztring &Count, const Ztring &Value, bool ValueIsAlwaysSame)
 {
     //Integrity
-    if (Count.empty())
-        return EmptyString_Get();
+    if (Count.empty() || Count.find_first_not_of(__T("0123456789.+-/*() "))!=string::npos)
+        return Count;
 
     //Different Plurals are available or not?
     if (Language_Get(Value+__T("1")).empty())
@@ -1546,9 +1616,17 @@ void MediaInfo_Config::Inform_Set (const ZtringListList &NewValue)
 {
     if (NewValue.Read(0, 0)==__T("Details"))
         Trace_Level_Set(NewValue.Read(0, 1));
+    else if (Trace_Level_Get() && NewValue.Read(0, 0)==__T("XML"))
+    {
+        Trace_Format_Set(Trace_Format_XML); // TODO: better coherency in options
+        return;
+    }
     else
     {
-        Trace_Level_Set(__T("0"));
+        if (NewValue.Read(0, 0)==__T("MAXML"))
+            Trace_Format_Set(Trace_Format_XML); //All must be XML
+        else
+            Trace_Format_Set(Trace_Format_Tree); // TODO: better coherency in options
 
         CriticalSectionLocker CSL(CS);
 
@@ -1904,7 +1982,7 @@ const ZtringListList &MediaInfo_Config::Info_Get(stream_t KindOfStream)
 //---------------------------------------------------------------------------
 Ztring MediaInfo_Config::Info_Parameters_Get (bool Complete)
 {
-    CriticalSectionLocker CSL(CS);
+    CS.Enter();
 
     //Loading all
     MediaInfo_Config_General(Info[Stream_General]);
@@ -1937,6 +2015,11 @@ Ztring MediaInfo_Config::Info_Parameters_Get (bool Complete)
             }
         ToReturn_Pos++;
     }
+    CS.Leave();
+
+    //Reset of language file
+    Language_Set(Ztring()); //TODO: it is reseted to English, it should actually not modify the language config (MediaInfo_Config_xxx() modifies the language config)
+
     return ToReturn.Read();
 }
 
@@ -2132,6 +2215,77 @@ bool MediaInfo_Config::MpegTs_ForceStreamDisplay_Get ()
     return MpegTs_ForceStreamDisplay;
 }
 
+#if MEDIAINFO_ADVANCED
+Ztring MediaInfo_Config::MAXML_StreamKinds_Get ()
+{
+    ZtringList List;
+    CriticalSectionLocker CSL(CS);
+    for (size_t StreamKind=0; StreamKind<Stream_Max; StreamKind++)
+    {
+        if (Info[StreamKind].empty())
+        {
+            switch (StreamKind)
+            {
+                case Stream_General :   MediaInfo_Config_General(Info[Stream_General]);   Language_Set(Stream_General); break;
+                case Stream_Video :     MediaInfo_Config_Video(Info[Stream_Video]);       Language_Set(Stream_Video); break;
+                case Stream_Audio :     MediaInfo_Config_Audio(Info[Stream_Audio]);       Language_Set(Stream_Audio); break;
+                case Stream_Text :      MediaInfo_Config_Text(Info[Stream_Text]);         Language_Set(Stream_Text); break;
+                case Stream_Other :     MediaInfo_Config_Other(Info[Stream_Other]);       Language_Set(Stream_Other); break;
+                case Stream_Image :     MediaInfo_Config_Image(Info[Stream_Image]);       Language_Set(Stream_Image); break;
+                case Stream_Menu :      MediaInfo_Config_Menu(Info[Stream_Menu]);         Language_Set(Stream_Menu); break;
+                default:;
+            }
+        }
+        List.push_back(Info[StreamKind](__T("StreamKind"), Info_Name, Info_Text));
+    }
+
+    List.Separator_Set(0, __T(","));
+    return List.Read();
+}
+#endif // MEDIAINFO_ADVANCED
+
+#if MEDIAINFO_ADVANCED
+extern Ztring Xml_Name_Escape_0_7_78 (const Ztring &Name);
+Ztring MediaInfo_Config::MAXML_Fields_Get (const Ztring &StreamKind_String)
+{
+    CriticalSectionLocker CSL(CS);
+
+    size_t StreamKind=Stream_General;
+    for (; StreamKind<Stream_Max; StreamKind++)
+    {
+        if (Info[StreamKind].empty())
+        {
+            switch (StreamKind)
+            {
+                case Stream_General :   MediaInfo_Config_General(Info[Stream_General]);   Language_Set(Stream_General); break;
+                case Stream_Video :     MediaInfo_Config_Video(Info[Stream_Video]);       Language_Set(Stream_Video); break;
+                case Stream_Audio :     MediaInfo_Config_Audio(Info[Stream_Audio]);       Language_Set(Stream_Audio); break;
+                case Stream_Text :      MediaInfo_Config_Text(Info[Stream_Text]);         Language_Set(Stream_Text); break;
+                case Stream_Other :     MediaInfo_Config_Other(Info[Stream_Other]);       Language_Set(Stream_Other); break;
+                case Stream_Image :     MediaInfo_Config_Image(Info[Stream_Image]);       Language_Set(Stream_Image); break;
+                case Stream_Menu :      MediaInfo_Config_Menu(Info[Stream_Menu]);         Language_Set(Stream_Menu); break;
+                default:;
+            }
+        }
+        if (StreamKind_String==Info[StreamKind](__T("StreamKind"), Info_Name, Info_Text))
+            break;
+    }
+
+    if (StreamKind>=Stream_Max)
+        return Ztring();
+
+    ZtringList List;
+    for (size_t FieldPos = 0; FieldPos < Info[StreamKind].size(); FieldPos++)
+        if (Info_Options < Info[StreamKind][FieldPos].size()
+         && InfoOption_ShowInXml < Info[StreamKind][FieldPos][Info_Options].size()
+         && Info[StreamKind][FieldPos][Info_Options][InfoOption_ShowInXml]==__T('Y'))
+            List.push_back(Xml_Name_Escape_0_7_78(Info[StreamKind][FieldPos][Info_Name]));
+
+    List.Separator_Set(0, __T(","));
+    return List.Read();
+}
+#endif // MEDIAINFO_ADVANCED
+
 //***************************************************************************
 // SubFile
 //***************************************************************************
