@@ -211,6 +211,7 @@ MediaInfo_Config_MediaInfo::MediaInfo_Config_MediaInfo()
     File_MpegTs_Atsc_transport_stream_id_Trust=true;
     File_MpegTs_RealTime=false;
     File_Mxf_TimeCodeFromMaterialPackage=false;
+    File_Mxf_ParseIndex=false;
     File_Bdmv_ParseTargetedFile=true;
     #if defined(MEDIAINFO_DVDIF_YES)
     File_DvDif_DisableAudioIfIsInContainer=false;
@@ -244,6 +245,13 @@ MediaInfo_Config_MediaInfo::MediaInfo_Config_MediaInfo()
     File_IsGrowing=false;
     File_IsNotGrowingAnymore=false;
     File_IsImageSequence=false;
+    #if defined(MEDIAINFO_EIA608_YES)
+    File_Scte20_IsPresent=false;
+    #endif //defined(MEDIAINFO_EIA608_YES)
+    #if defined(MEDIAINFO_EIA608_YES) || defined(MEDIAINFO_EIA708_YES)
+    File_DtvccTransport_Stream_IsPresent=false;
+    File_DtvccTransport_Descriptor_IsPresent=false;
+    #endif //defined(MEDIAINFO_EIA608_YES) || defined(MEDIAINFO_EIA708_YES)
     File_Current_Offset=0;
     File_Current_Size=(int64u)-1;
     File_IgnoreEditsBefore=0;
@@ -397,12 +405,12 @@ Ztring MediaInfo_Config_MediaInfo::Option (const String &Option, const String &V
     }
     else if (Option_Lower==__T("file_ignoresequencefilescount"))
     {
-        #if MEDIAINFO_MD5
+        #if MEDIAINFO_ADVANCED
             File_IgnoreSequenceFilesCount_Set(!(Value==__T("0") || Value.empty()));
             return Ztring();
-        #else //MEDIAINFO_MD5
+        #else //MEDIAINFO_ADVANCED
             return __T("Disabled due to compilation options");
-        #endif //MEDIAINFO_MD5
+        #endif //MEDIAINFO_ADVANCED
     }
     else if (Option_Lower==__T("file_sequencefilesskipframes") || Option_Lower==__T("file_sequencefileskipframes"))
     {
@@ -415,21 +423,21 @@ Ztring MediaInfo_Config_MediaInfo::Option (const String &Option, const String &V
     }
     else if (Option_Lower==__T("file_defaultframerate"))
     {
-        #if MEDIAINFO_MD5
+        #if MEDIAINFO_ADVANCED
             File_DefaultFrameRate_Set(Ztring(Value).To_float64());
             return Ztring();
-        #else //MEDIAINFO_MD5
+        #else //MEDIAINFO_ADVANCED
             return __T("File_DefaultFrameRate is disabled due to compilation options");
-        #endif //MEDIAINFO_MD5
+        #endif //MEDIAINFO_ADVANCED
     }
     else if (Option_Lower==__T("file_source_list"))
     {
-        #if MEDIAINFO_MD5
+        #if MEDIAINFO_ADVANCED
             File_Source_List_Set(!(Value==__T("0") || Value.empty()));
             return Ztring();
-        #else //MEDIAINFO_MD5
-            return __T("MD5 is disabled due to compilation options");
-        #endif //MEDIAINFO_MD5
+        #else //MEDIAINFO_ADVANCED
+            return __T("File_Source_List_Set is disabled due to compilation options");
+        #endif //MEDIAINFO_ADVANCED
     }
     else if (Option_Lower==__T("file_riskybitrateestimation"))
     {
@@ -471,6 +479,58 @@ Ztring MediaInfo_Config_MediaInfo::Option (const String &Option, const String &V
             return __T("MD5 is disabled due to compilation options");
         #endif //MEDIAINFO_MD5
     }
+    else if (Option_Lower==__T("file_hash"))
+    {
+        #if MEDIAINFO_HASH
+            ZtringList List;
+            List.Separator_Set(0, __T(","));
+            List.Write(Value);
+            ZtringList ToReturn;
+            ToReturn.Separator_Set(0, __T(","));
+            HashWrapper::HashFunctions Functions;
+            for (size_t i=0; i<List.size(); ++i)
+            {
+                Ztring Value(List[i]);
+                Value.MakeLowerCase();
+                bool Found=false;
+                for (size_t j=0; j<HashWrapper::HashFunction_Max; ++j)
+                {
+                    Ztring Name;
+                    Name.From_UTF8(HashWrapper::Name((HashWrapper::HashFunction)j));
+                    Name.MakeLowerCase();
+                    if (Value==Name)
+                    {
+                        Functions.set(j);
+                        Found=true;
+                    }
+                }
+
+                if (!Found)
+                    ToReturn.push_back(List[i]);
+            }
+            File_Hash_Set(Functions);
+            if (ToReturn.empty())
+                return Ztring();
+            else
+                return ToReturn.Read()+__T(" hash functions are unknown or disabled due to compilation options");
+        #else //MEDIAINFO_HASH
+            return __T("Hash functions are disabled due to compilation options");
+        #endif //MEDIAINFO_HASH
+    }
+    else if (Option_Lower==__T("file_hash_get"))
+    {
+        #if MEDIAINFO_HASH
+            ZtringList List;
+            HashWrapper::HashFunctions Functions=File_Hash_Get();
+            for (size_t i=0; i<HashWrapper::HashFunction_Max; ++i)
+                if (Functions[i])
+                    List.push_back(Ztring().From_UTF8(HashWrapper::Name((HashWrapper::HashFunction)i)));
+            List.Separator_Set(0, __T(","));
+            return List.Read();
+        #else //MEDIAINFO_HASH
+            return __T("Hash functions are disabled due to compilation options");
+        #endif //MEDIAINFO_HASH
+    }
     else if (Option_Lower==__T("file_checksidecarfiles"))
     {
         #if defined(MEDIAINFO_REFERENCES_YES)
@@ -899,6 +959,15 @@ Ztring MediaInfo_Config_MediaInfo::Option (const String &Option, const String &V
     {
         return File_Mxf_TimeCodeFromMaterialPackage_Get()?"1":"0";
     }
+    else if (Option_Lower==__T("file_mxf_parseindex"))
+    {
+        File_Mxf_ParseIndex_Set(!(Value==__T("0") || Value.empty()));
+        return __T("");
+    }
+    else if (Option_Lower==__T("file_mxf_parseindex_get"))
+    {
+        return File_Mxf_ParseIndex_Get()?"1":"0";
+    }
     else if (Option_Lower==__T("file_bdmv_parsetargetedfile"))
     {
         File_Bdmv_ParseTargetedFile_Set(!(Value==__T("0") || Value.empty()));
@@ -1252,15 +1321,35 @@ void MediaInfo_Config_MediaInfo::File_Md5_Set (bool NewValue)
 {
     CriticalSectionLocker CSL(CS);
     File_Md5=NewValue;
+    Hash_Functions.set(HashWrapper::MD5, NewValue);
 }
 
 bool MediaInfo_Config_MediaInfo::File_Md5_Get ()
 {
     CriticalSectionLocker CSL(CS);
-    return File_Md5;
+    return Hash_Functions[HashWrapper::MD5];
 }
 #endif //MEDIAINFO_MD5
 
+//---------------------------------------------------------------------------
+#if MEDIAINFO_HASH
+void MediaInfo_Config_MediaInfo::File_Hash_Set (HashWrapper::HashFunctions Funtions)
+{
+    CriticalSectionLocker CSL(CS);
+    Hash_Functions=Funtions;
+    
+    //Legacy
+    if (File_Md5)
+        Hash_Functions.set(HashWrapper::MD5);
+}
+
+HashWrapper::HashFunctions MediaInfo_Config_MediaInfo::File_Hash_Get ()
+{
+    CriticalSectionLocker CSL(CS);
+    return Hash_Functions;
+}
+#endif //MEDIAINFO_HASH
+
 //---------------------------------------------------------------------------
 #if defined(MEDIAINFO_REFERENCES_YES)
 void MediaInfo_Config_MediaInfo::File_CheckSideCarFiles_Set (bool NewValue)
@@ -2525,6 +2614,21 @@ bool MediaInfo_Config_MediaInfo::File_Mxf_TimeCodeFromMaterialPackage_Get ()
     return Temp;
 }
 
+//---------------------------------------------------------------------------
+void MediaInfo_Config_MediaInfo::File_Mxf_ParseIndex_Set (bool NewValue)
+{
+    CriticalSectionLocker CSL(CS);
+    File_Mxf_ParseIndex=NewValue;
+}
+
+bool MediaInfo_Config_MediaInfo::File_Mxf_ParseIndex_Get ()
+{
+    CS.Enter();
+    bool Temp=File_Mxf_ParseIndex;
+    CS.Leave();
+    return Temp;
+}
+
 //---------------------------------------------------------------------------
 void MediaInfo_Config_MediaInfo::File_Bdmv_ParseTargetedFile_Set (bool NewValue)
 {
