@@ -21,6 +21,7 @@
 
 //---------------------------------------------------------------------------
 #include "MediaInfo/MediaInfo_Internal_Const.h"
+#include "MediaInfo/HashWrapper.h" //For MEDIAINFO_HASH
 #if MEDIAINFO_EVENTS
     #include "MediaInfo/MediaInfo_Config.h"
     #include "MediaInfo/MediaInfo_Events.h"
@@ -30,6 +31,7 @@
 #include "ZenLib/Translation.h"
 #include "ZenLib/InfoMap.h"
 using namespace ZenLib;
+using namespace std;
 //---------------------------------------------------------------------------
 
 namespace MediaInfoLib
@@ -120,6 +122,11 @@ public :
         bool          File_IgnoreSequenceFilesCount_Get ();
     #endif //MEDIAINFO_ADVANCED
 
+    #if MEDIAINFO_ADVANCED
+        void          File_SequenceFilesSkipFrames_Set (int64u NewValue);
+        int64u        File_SequenceFilesSkipFrames_Get ();
+    #endif //MEDIAINFO_ADVANCED
+
     #if MEDIAINFO_ADVANCED
         void          File_DefaultFrameRate_Set (float64 NewValue);
         float64       File_DefaultFrameRate_Get ();
@@ -133,6 +140,8 @@ public :
     #if MEDIAINFO_ADVANCED
         void          File_RiskyBitRateEstimation_Set (bool NewValue);
         bool          File_RiskyBitRateEstimation_Get ();
+        void          File_MergeBitRateInfo_Set (bool NewValue);
+        bool          File_MergeBitRateInfo_Get ();
     #endif //MEDIAINFO_ADVANCED
 
     #if MEDIAINFO_DEMUX
@@ -142,6 +151,10 @@ public :
         #endif //MEDIAINFO_ADVANCED
     #endif //MEDIAINFO_DEMUX
 
+    #if MEDIAINFO_HASH
+        void         File_Hash_Set (HashWrapper::HashFunctions Funtions);
+        HashWrapper::HashFunctions File_Hash_Get ();
+    #endif //MEDIAINFO_HASH
     #if MEDIAINFO_MD5
         void          File_Md5_Set (bool NewValue);
         bool          File_Md5_Get ();
@@ -269,14 +282,16 @@ public :
     int8u         Demux_InitData_Get ();
     #endif //MEDIAINFO_DEMUX
 
-    #if MEDIAINFO_IBI
+    #if MEDIAINFO_IBIUSAGE
     void          Ibi_Set (const Ztring &NewValue);
     std::string   Ibi_Get ();
-    void          Ibi_Create_Set (bool NewValue);
-    bool          Ibi_Create_Get ();
     void          Ibi_UseIbiInfoIfAvailable_Set (bool NewValue);
     bool          Ibi_UseIbiInfoIfAvailable_Get ();
-    #endif //MEDIAINFO_IBI
+    #endif //MEDIAINFO_IBIUSAGE
+    #if MEDIAINFO_IBIUSAGE
+    void          Ibi_Create_Set (bool NewValue);
+    bool          Ibi_Create_Get ();
+    #endif //MEDIAINFO_IBIUSAGE
 
     //Specific
     void          File_MpegTs_ForceMenu_Set (bool NewValue);
@@ -287,6 +302,10 @@ public :
     bool          File_MpegTs_Atsc_transport_stream_id_Trust_Get ();
     void          File_MpegTs_RealTime_Set (bool NewValue);
     bool          File_MpegTs_RealTime_Get ();
+    void          File_Mxf_TimeCodeFromMaterialPackage_Set (bool NewValue);
+    bool          File_Mxf_TimeCodeFromMaterialPackage_Get ();
+    void          File_Mxf_ParseIndex_Set (bool NewValue);
+    bool          File_Mxf_ParseIndex_Get ();
     void          File_Bdmv_ParseTargetedFile_Set (bool NewValue);
     bool          File_Bdmv_ParseTargetedFile_Get ();
     #if defined(MEDIAINFO_DVDIF_YES)
@@ -339,11 +358,19 @@ public :
     bool          File_Buffer_Repeat_IsSupported;
     bool          File_IsGrowing;
     bool          File_IsNotGrowingAnymore;
+    bool          File_IsImageSequence;
+    #if defined(MEDIAINFO_EIA608_YES)
+    bool          File_Scte20_IsPresent;
+    #endif //defined(MEDIAINFO_EIA608_YES)
+    #if defined(MEDIAINFO_EIA608_YES) || defined(MEDIAINFO_EIA708_YES)
+    bool          File_DtvccTransport_Stream_IsPresent;
+    bool          File_DtvccTransport_Descriptor_IsPresent;
+    #endif //defined(MEDIAINFO_EIA608_YES) || defined(MEDIAINFO_EIA708_YES)
     int64u        File_Current_Offset;
     int64u        File_Current_Size;
-    int64u        File_IgnoreFramesBefore;
-    int64u        File_IgnoreFramesAfter;
-    float64       File_IgnoreFramesRate;
+    int64u        File_IgnoreEditsBefore;
+    int64u        File_IgnoreEditsAfter;
+    float64       File_EditRate;
     int64u        File_Size;
     float32       ParseSpeed;
     #if MEDIAINFO_EVENTS
@@ -379,13 +406,18 @@ private :
     #if MEDIAINFO_ADVANCED
         bool                File_IgnoreSequenceFileSize;
         bool                File_IgnoreSequenceFilesCount;
+        int64u              File_SequenceFilesSkipFrames;
         float64             File_DefaultFrameRate;
         bool                File_Source_List;
         bool                File_RiskyBitRateEstimation;
+        bool                File_MergeBitRateInfo;
         #if MEDIAINFO_DEMUX
             bool                File_Demux_Unpacketize_StreamLayoutChange_Skip;
         #endif //MEDIAINFO_DEMUX
     #endif //MEDIAINFO_ADVANCED
+    #if MEDIAINFO_HASH
+        HashWrapper::HashFunctions Hash_Functions;
+    #endif //MEDIAINFO_HASH
     #if MEDIAINFO_MD5
         bool                File_Md5;
     #endif //MEDIAINFO_MD5
@@ -470,17 +502,21 @@ private :
     int8u                   Demux_InitData;
     #endif //MEDIAINFO_DEMUX
 
-    #if MEDIAINFO_IBI
+    #if MEDIAINFO_IBIUSAGE
     std::string             Ibi;
-    bool                    Ibi_Create;
     bool                    Ibi_UseIbiInfoIfAvailable;
-    #endif //MEDIAINFO_IBI
+    #endif //MEDIAINFO_IBIUSAGE
+    #if MEDIAINFO_IBIUSAGE
+    bool                    Ibi_Create;
+    #endif //MEDIAINFO_IBIUSAGE
 
     //Specific
     bool                    File_MpegTs_ForceMenu;
     bool                    File_MpegTs_stream_type_Trust;
     bool                    File_MpegTs_Atsc_transport_stream_id_Trust;
     bool                    File_MpegTs_RealTime;
+    bool                    File_Mxf_TimeCodeFromMaterialPackage;
+    bool                    File_Mxf_ParseIndex;
     bool                    File_Bdmv_ParseTargetedFile;
     #if defined(MEDIAINFO_DVDIF_YES)
     bool                    File_DvDif_DisableAudioIfIsInContainer;
