@@ -27,6 +27,9 @@
 #if defined(MEDIAINFO_EBUCORE_YES)
     #include "MediaInfo/Export/Export_EbuCore.h"
 #endif //defined(MEDIAINFO_EBUCORE_YES)
+#if defined(MEDIAINFO_FIMS_YES)
+    #include "MediaInfo/Export/Export_Fims.h"
+#endif //defined(MEDIAINFO_EBUCORE_YES)
 #if defined(MEDIAINFO_MPEG7_YES)
     #include "MediaInfo/Export/Export_Mpeg7.h"
 #endif //defined(MEDIAINFO_MPEG7_YES)
@@ -45,6 +48,41 @@
 namespace MediaInfoLib
 {
 
+//---------------------------------------------------------------------------
+#if defined(MEDIAINFO_XML_YES)
+Ztring Xml_Name_Escape_0_7_78 (const Ztring &Name)
+{
+    Ztring ToReturn(Name);
+
+    if (ToReturn.operator()(0)>='0' && ToReturn.operator()(0)<='9')
+        ToReturn.insert(0, 1, __T('_'));
+    ToReturn.FindAndReplace(__T(" "), __T("_"), 0, Ztring_Recursive);
+    ToReturn.FindAndReplace(__T("/"), __T("_"), 0, Ztring_Recursive);
+    ToReturn.FindAndReplace(__T("("), Ztring(), 0, Ztring_Recursive);
+    ToReturn.FindAndReplace(__T(")"), Ztring(), 0, Ztring_Recursive);
+    ToReturn.FindAndReplace(__T("*"), __T("_"), 0, Ztring_Recursive);
+    ToReturn.FindAndReplace(__T(","), __T("_"), 0, Ztring_Recursive);
+    ToReturn.FindAndReplace(__T(":"), __T("_"), 0, Ztring_Recursive);
+    ToReturn.FindAndReplace(__T("@"), __T("_"), 0, Ztring_Recursive);
+    ToReturn.FindAndReplace(__T("."), __T("_"), 0, Ztring_Recursive);
+    size_t ToReturn_Pos=0;
+    while (ToReturn_Pos<ToReturn.size())
+    {
+        if (!(ToReturn[ToReturn_Pos]>=__T('A') && ToReturn[ToReturn_Pos]<=__T('Z'))
+         && !(ToReturn[ToReturn_Pos]>=__T('a') && ToReturn[ToReturn_Pos]<=__T('z'))
+         && !(ToReturn[ToReturn_Pos]>=__T('0') && ToReturn[ToReturn_Pos]<=__T('9'))
+         && !(ToReturn[ToReturn_Pos]==__T('_')))
+            ToReturn.erase(ToReturn_Pos, 1);
+        else
+            ToReturn_Pos++;
+    }
+    if (ToReturn.empty())
+        ToReturn="Unknown";
+
+    return ToReturn;
+}
+#endif //defined(MEDIAINFO_XML_YES)
+
 //---------------------------------------------------------------------------
 extern MediaInfo_Config Config;
 //---------------------------------------------------------------------------
@@ -58,16 +96,14 @@ Ztring MediaInfo_Internal::Inform()
     CS.Leave();
 
     #if MEDIAINFO_TRACE
-        if (MediaInfoLib::Config.Trace_Level_Get() || MediaInfoLib::Config.Inform_Get()==__T("Details"))
+        if (MediaInfoLib::Config.Inform_Get()!=__T("MAXML") && (MediaInfoLib::Config.Trace_Level_Get() || MediaInfoLib::Config.Inform_Get()==__T("Details")))
         {
             if (!Details.empty())
-            {
-                Ztring Content=Details;
-
                 return Details;
-            }
             else if (Info)
                 return Info->Details_Get();
+            else
+                return Ztring();
         }
     #endif //MEDIAINFO_TRACE
 
@@ -77,6 +113,14 @@ Ztring MediaInfo_Internal::Inform()
         if (MediaInfoLib::Config.Inform_Get()==__T("EBUCore") || MediaInfoLib::Config.Inform_Get()==__T("EBUCore_1.5"))
             return Export_EbuCore().Transform(*this);
     #endif //defined(MEDIAINFO_EBUCORE_YES)
+    #if defined(MEDIAINFO_EBUCORE_YES)
+        if (MediaInfoLib::Config.Inform_Get()==__T("FIMS_1.1"))
+            return Export_Fims().Transform(*this, Export_Fims::Version_1_1);
+        if (MediaInfoLib::Config.Inform_Get()==__T("FIMS_1.2") || MediaInfoLib::Config.Inform_Get()==__T("FIMS"))
+            return Export_Fims().Transform(*this, Export_Fims::Version_1_2);
+        if (MediaInfoLib::Config.Inform_Get()==__T("FIMS_1.3"))
+            return Export_Fims().Transform(*this, Export_Fims::Version_1_3);
+    #endif //defined(MEDIAINFO_FIMS_YES)
     #if defined(MEDIAINFO_MPEG7_YES)
         if (MediaInfoLib::Config.Inform_Get()==__T("MPEG-7"))
             return Export_Mpeg7().Transform(*this);
@@ -199,16 +243,39 @@ Ztring MediaInfo_Internal::Inform()
     Ztring Retour;
     bool HTML=false;
     bool XML=false;
+    bool XML_0_7_78_MA=false;
+    bool XML_0_7_78_MI=false;
     bool CSV=false;
+    #if defined(MEDIAINFO_HTML_YES)
     if (MediaInfoLib::Config.Inform_Get()==__T("HTML"))
         HTML=true;
+    #endif //defined(MEDIAINFO_HTML_YES)
+    #if defined(MEDIAINFO_XML_YES)
     if (MediaInfoLib::Config.Inform_Get()==__T("XML"))
         XML=true;
+    if (MediaInfoLib::Config.Inform_Get()==__T("MAXML"))
+        XML_0_7_78_MA=true;
+    if (MediaInfoLib::Config.Inform_Get()==__T("MIXML"))
+        XML_0_7_78_MI=true;
+    #endif //defined(MEDIAINFO_XML_YES)
+    #if defined(MEDIAINFO_CSV_YES)
     if (MediaInfoLib::Config.Inform_Get()==__T("CSV"))
         CSV=true;
+    #endif //defined(MEDIAINFO_CSV_YES)
 
-    if (HTML) Retour+=__T("<html>\n\n<head>\n<META http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\" /></head>\n<body>\n");
-    if (XML)  Retour+=__T("<File>\n");
+    if (HTML)
+        Retour+=__T("<html>\n\n<head>\n<META http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\" /></head>\n<body>\n");
+    #if defined(MEDIAINFO_XML_YES)
+    if (XML_0_7_78_MA || XML_0_7_78_MI)
+    {
+        size_t Modified;
+        Retour+=__T("<media ref=\"")+MediaInfo_Internal::Xml_Content_Escape(Get(Stream_General, 0, General_CompleteName), Modified)+__T("\">\n");
+    }
+    if (XML_0_7_78_MA)
+        Retour+=__T("<MediaInfo xmlns=\"https://mediaarea.net/mediainfo\" version=\"2.0beta1\">\n");
+    if (XML)
+        Retour+=__T("<File>\n");
+    #endif //defined(MEDIAINFO_XML_YES)
 
     for (size_t StreamKind=(size_t)Stream_General; StreamKind<Stream_Max; StreamKind++)
     {
@@ -217,10 +284,10 @@ Ztring MediaInfo_Internal::Inform()
         {
             //Pour chaque stream
             if (HTML) Retour+=__T("<table width=\"100%\" border=\"0\" cellpadding=\"1\" cellspacing=\"2\" style=\"border:1px solid Navy\">\n<tr>\n    <td width=\"150\"><h2>");
-            if (XML) Retour+=__T("<track type=\"");
+            if (XML || XML_0_7_78_MA || XML_0_7_78_MI) Retour+=__T("<track type=\"");
             Ztring A=Get((stream_t)StreamKind, StreamPos, __T("StreamKind/String"));
             Ztring B=Get((stream_t)StreamKind, StreamPos, __T("StreamKindPos"));
-            if (!XML && !B.empty())
+            if (!XML && !XML_0_7_78_MA && !XML_0_7_78_MI && !B.empty())
             {
                 if (CSV)
                     A+=__T(",");
@@ -229,29 +296,29 @@ Ztring MediaInfo_Internal::Inform()
                 A+=B;
             }
             Retour+=A;
-            if (XML)
+            if (XML || XML_0_7_78_MA || XML_0_7_78_MI)
             {
                 Retour+=__T("\"");
                 if (!B.empty())
                 {
-                    Retour+=__T(" streamid=\"");
+                    Retour+=__T(" typeorder=\"");
                     Retour+=B;
                     Retour+=__T("\"");
                 }
             }
             if (HTML) Retour+=__T("</h2></td>\n  </tr>");
-            if (XML) Retour+=__T(">");
+            if (XML || XML_0_7_78_MA || XML_0_7_78_MI) Retour+=__T(">");
             Retour+=MediaInfoLib::Config.LineSeparator_Get();
             Retour+=Inform((stream_t)StreamKind, StreamPos, false);
             Retour.FindAndReplace(__T("\\"), __T("|SC1|"), 0, Ztring_Recursive);
             if (HTML) Retour+=__T("</table>\n<br />");
-            if (XML) Retour+=__T("</track>\n");
+            if (XML || XML_0_7_78_MA || XML_0_7_78_MI) Retour+=__T("</track>\n");
             Retour+=MediaInfoLib::Config.LineSeparator_Get();
         }
     }
 
     if (HTML) Retour+=__T("\n</body>\n</html>\n");
-    if (XML)  Retour+=__T("</File>\n");
+    if (XML_0_7_78_MA)  Retour+=__T("</MediaInfo>\n");
 
     Retour.FindAndReplace(__T("\\r\\n"), __T("\n"), 0, Ztring_Recursive);
     Retour.FindAndReplace(__T("\\r"), __T("\n"), 0, Ztring_Recursive);
@@ -271,6 +338,27 @@ Ztring MediaInfo_Internal::Inform()
     Retour.FindAndReplace(__T("|SC8|"), __T(")"), 0, Ztring_Recursive);
     Retour.FindAndReplace(__T("|SC9|"), __T("),"), 0, Ztring_Recursive);
 
+    #if MEDIAINFO_TRACE
+        if (XML_0_7_78_MA)
+        {
+            if (MediaInfoLib::Config.Trace_Level_Get() || MediaInfoLib::Config.Inform_Get()==__T("Details"))
+            {
+                Retour+=__T("<MediaTrace xmlns=\"https://mediaarea.net/mediatrace\" version=\"0.1\">\n");
+                if (!Details.empty())
+                    Retour+=Details;
+                else if (Info)
+                    Retour+=Info->Details_Get();
+                Retour+=__T("\n");
+                Retour+=__T("</MediaTrace>\n");
+            }
+        }
+    #endif //MEDIAINFO_TRACE
+
+    if (XML_0_7_78_MA || XML_0_7_78_MI)
+        Retour+=__T("</media>\n");
+    if (XML)
+        Retour+=__T("</File>\n");
+
     return Retour;
 
     #else //defined(MEDIAINFO_TEXT_YES) || defined(MEDIAINFO_HTML_YES) || defined(MEDIAINFO_XML_YES) || defined(MEDIAINFO_CSV_YES)
@@ -302,6 +390,9 @@ Ztring MediaInfo_Internal::Inform (stream_t StreamKind, size_t StreamPos, bool I
         #endif //defined(MEDIAINFO_HTML_YES)
         #if defined(MEDIAINFO_XML_YES)
         bool XML=MediaInfoLib::Config.Inform_Get()==__T("XML")?true:false;
+        bool XML_0_7_78=(MediaInfoLib::Config.Inform_Get()==__T("MAXML") || MediaInfoLib::Config.Inform_Get()==__T("MIXML"))?true:false;
+        if (XML_0_7_78)
+            XML=true;
         #endif //defined(MEDIAINFO_XML_YES)
         #if defined(MEDIAINFO_CSV_YES)
         bool CSV=MediaInfoLib::Config.Inform_Get()==__T("CSV")?true:false;
@@ -322,15 +413,47 @@ Ztring MediaInfo_Internal::Inform (stream_t StreamKind, size_t StreamPos, bool I
         #endif //defined(MEDIAINFO_CSV_YES)
         #endif //defined(MEDIAINFO_TEXT_YES) && (defined(MEDIAINFO_HTML_YES) || defined(MEDIAINFO_XML_YES) || defined(MEDIAINFO_CSV_YES))
         size_t Size=Count_Get(StreamKind, StreamPos);
+        bool IsExtra=false;
         for (size_t Champ_Pos=0; Champ_Pos<Size; Champ_Pos++)
         {
             //Pour chaque champ
             //Ztring A=Get((stream_t)4, 2, 0, Info_Measure_Text); // TODO Bug sinon? voir Ztring
             Ztring A=Get((stream_t)StreamKind, StreamPos, Champ_Pos, Info_Measure_Text); // TODO Bug sinon? voir Ztring
-            if ((MediaInfoLib::Config.Complete_Get() || Get((stream_t)StreamKind, StreamPos, Champ_Pos, Info_Options)[InfoOption_ShowInInform]==__T('Y')) && !Get((stream_t)StreamKind, StreamPos, Champ_Pos, Info_Text).empty())
+            bool Shouldshow=false;
+            #if defined(MEDIAINFO_XML_YES)
+            if (XML_0_7_78)
             {
+                if (Champ_Pos>=Stream[StreamKind][StreamPos].size())
+                    Shouldshow=true;
+                else
+                {
+                Ztring Options=Get((stream_t)StreamKind, StreamPos, Champ_Pos, Info_Options);
+                if (InfoOption_ShowInXml<Options.size() && Options[InfoOption_ShowInXml]==__T('Y'))
+                    Shouldshow=true;
+                }
+            }
+            else
+            #endif //defined(MEDIAINFO_XML_YES
+            if ((MediaInfoLib::Config.Complete_Get() || Get((stream_t)StreamKind, StreamPos, Champ_Pos, Info_Options)[InfoOption_ShowInInform]==__T('Y')))
+                Shouldshow=true;
+            if (Shouldshow && !Get((stream_t)StreamKind, StreamPos, Champ_Pos, Info_Text).empty())
+            {
+                #if defined(MEDIAINFO_XML_YES)
+                //Extra
+                if (XML_0_7_78 && !IsExtra && Champ_Pos>=Stream[StreamKind][StreamPos].size())
+                {
+                     Retour+=__T("<extra>\n");
+                     IsExtra=true;
+                }
+                #endif //defined(MEDIAINFO_XML_YES
+
                 Ztring Nom=Get((stream_t)StreamKind, StreamPos, Champ_Pos, Info_Name_Text);
+                #if defined(MEDIAINFO_XML_YES)
+                if (Nom.empty() || XML_0_7_78)
+                #else
                 if (Nom.empty())
+                #endif //defined(MEDIAINFO_XML_YES
+
                     Nom=Get((stream_t)StreamKind, StreamPos, Champ_Pos, Info_Name); //Texte n'existe pas
                 #if defined(MEDIAINFO_TEXT_YES) && (defined(MEDIAINFO_HTML_YES) || defined(MEDIAINFO_XML_YES) || defined(MEDIAINFO_CSV_YES))
                 if (Text)
@@ -342,6 +465,17 @@ Ztring MediaInfo_Internal::Inform (stream_t StreamKind, size_t StreamPos, bool I
                      Nom.resize(Nom_Size, ' ');
                 }
                 Ztring Valeur=Get((stream_t)StreamKind, StreamPos, Champ_Pos, Info_Text);
+                #if defined(MEDIAINFO_XML_YES)
+                    if (XML_0_7_78 && MediaInfoLib::Config.Info_Get(StreamKind).Read(Champ_Pos, Info_Measure)==__T(" ms"))
+                    {
+                        size_t Decimal = Valeur.find(__T('.'));
+                        size_t Precision=3;
+                        if (Decimal != (size_t)-1)
+                            Precision+=Valeur.size()-Decimal-1;
+                        float64 Ms=Valeur.To_float64();
+                        Valeur.From_Number(Ms/1000, Precision);
+                    }
+                #endif // defined(MEDIAINFO_XML_YES)
                 Valeur.FindAndReplace(__T("\\"), __T("|SC1|"), 0, Ztring_Recursive);
                 #if defined(MEDIAINFO_HTML_YES)
                 if (HTML)
@@ -356,9 +490,19 @@ Ztring MediaInfo_Internal::Inform (stream_t StreamKind, size_t StreamPos, bool I
                 #if defined(MEDIAINFO_XML_YES)
                 if (XML)
                 {
-                    Nom=Xml_Name_Escape(Nom);
+                    if (XML_0_7_78)
+                        Nom=Xml_Name_Escape_0_7_78(Nom);
+                    else
+                        Nom=Xml_Name_Escape(Nom);
                     size_t Modified;
                     Xml_Content_Escape_Modifying(Valeur, Modified);
+                    if (XML_0_7_78 && Nom.size()>8 && Nom.rfind(__T("_Version"))==Nom.size()-8 && Valeur.size()>8 && Valeur.rfind(__T("Version "), 0)==0)
+                    {
+                        Valeur.erase(0, 8); // Remove useless "Version "
+                        size_t SlashPos = Valeur.find(__T(" / "));
+                        if (SlashPos!=string::npos)
+                            Valeur.erase(SlashPos);
+                    }
 
                     Retour+=__T("<");
                     Retour+=Nom;
@@ -390,6 +534,12 @@ Ztring MediaInfo_Internal::Inform (stream_t StreamKind, size_t StreamPos, bool I
             }
         }
 
+        //Extra
+        if (IsExtra)
+        {
+            Retour+=__T("</extra>\n");
+        }
+
         Retour.FindAndReplace(__T("\\r\\n"), __T("\n"), 0, Ztring_Recursive);
         Retour.FindAndReplace(__T("\\r"), __T("\n"), 0, Ztring_Recursive);
         Retour.FindAndReplace(__T("\\n"), __T("\n"), 0, Ztring_Recursive);
@@ -673,6 +823,9 @@ Ztring &MediaInfo_Internal::Xml_Content_Escape_Modifying (Ztring &Content, size_
                             Content.insert(Pos+1, __T("gt;"));
                             Pos+=3;
                             break;
+            case __T('\r'):
+            case __T('\n'):
+                            break;
             default:
                         if (Content[Pos]<0x20)
                         {
