@@ -116,6 +116,7 @@ private :
     friend class File_DcpCpl;//Theses classes need access to internal structure for optimization. There is recursivity with theses formats
     friend class File_DcpPkl;//Theses classes need access to internal structure for optimization. There is recursivity with theses formats
     friend class File__ReferenceFilesHelper; //Theses classes need access to internal structure for optimization. There is recursivity with theses formats
+    friend class resource;//Theses classes need access to internal structure for optimization. There is recursivity with theses formats
     friend class Reader_File; //For Info member
 
     //Parsing handles
@@ -151,9 +152,9 @@ public :
     #endif //!defined(MEDIAINFO_READER_NO)
     MediaInfo_Config_MediaInfo Config;
 
-    Ztring Xml_Name_Escape(const Ztring &Name);
-    Ztring Xml_Content_Escape(const Ztring &Content, size_t &Modified);
-    Ztring &Xml_Content_Escape_Modifying(Ztring &Content, size_t &Modified);
+    static Ztring Xml_Name_Escape(const Ztring &Name);
+    static Ztring Xml_Content_Escape(const Ztring &Content, size_t &Modified);
+    static Ztring &Xml_Content_Escape_Modifying(Ztring &Content, size_t &Modified);
 
 private :
     //Threading
