@@ -22,12 +22,11 @@
 
 //---------------------------------------------------------------------------
 #include "MediaInfo/Multiple/File_DcpCpl.h"
+#include "MediaInfo/Multiple/File_DcpAm.h"
 #include "MediaInfo/MediaInfo.h"
-#include "MediaInfo/MediaInfo_Internal.h"
 #include "MediaInfo/Multiple/File__ReferenceFilesHelper.h"
-#include "MediaInfo/Multiple/File_DcpPkl.h"
-#include "MediaInfo/Multiple/File_Mxf.h"
 #include "ZenLib/Dir.h"
+#include "ZenLib/File.h"
 #include "ZenLib/FileName.h"
 #include "tinyxml2.h"
 #include <list>
@@ -38,84 +37,6 @@ using namespace std;
 namespace MediaInfoLib
 {
 
-//***************************************************************************
-// Infos
-//***************************************************************************
-
-struct DcpCpl_info
-{
-    Ztring FileName;
-    File__ReferenceFilesHelper::references::iterator Reference;
-};
-
-//---------------------------------------------------------------------------
-extern void DcpCpl_MergeFromPkl(File__ReferenceFilesHelper* FromCpl, File__ReferenceFilesHelper* FromPkl)
-{
-    map<Ztring, DcpCpl_info> Map;
-    list<File__ReferenceFilesHelper::references::iterator> List;
-    ZtringList ExtraFiles_Name;
-    for (File__ReferenceFilesHelper::references::iterator Reference=FromPkl->References.begin(); Reference!=FromPkl->References.end(); ++Reference)
-    {
-        map<string, Ztring>::iterator UniqueID=Reference->Infos.find("UniqueID");
-        for (size_t Pos=0; Pos<Reference->FileNames.size(); Pos++)
-            if (UniqueID!=Reference->Infos.end())
-            {
-                Map[UniqueID->second].FileName=Reference->FileNames[Pos];
-                Map[UniqueID->second].Reference=Reference;
-            }
-        List.push_back(Reference);
-    }
-
-    for (size_t References_Pos=0; References_Pos<FromCpl->References.size(); ++References_Pos)
-    {
-        for (size_t Pos=0; Pos<FromCpl->References[References_Pos].FileNames.size(); ++Pos)
-        {
-            map<Ztring, DcpCpl_info>::iterator Map_Item=Map.find(FromCpl->References[References_Pos].FileNames[Pos]);
-            if (Map_Item!=Map.end())
-            {
-                FromCpl->References[References_Pos].FileNames[Pos]=Map_Item->second.FileName;
-                FromCpl->References[References_Pos].Infos=Map_Item->second.Reference->Infos;
-                for (list<File__ReferenceFilesHelper::references::iterator>::iterator Reference2=List.begin(); Reference2!=List.end(); ++Reference2)
-                    if (*Reference2==Map_Item->second.Reference)
-                    {
-                        List.erase(Reference2);
-                        break;
-                    }
-            }
-            else
-            {
-                FromCpl->References[References_Pos].FileNames.erase(FromCpl->References[References_Pos].FileNames.begin()+Pos);
-                Pos--;
-            }
-        }
-        for (size_t Pos=0; Pos<FromCpl->References[References_Pos].CompleteDuration.size(); ++Pos)
-        {
-            map<Ztring, DcpCpl_info>::iterator Map_Item=Map.find(FromCpl->References[References_Pos].CompleteDuration[Pos].FileName);
-            if (Map_Item!=Map.end())
-            {
-                FromCpl->References[References_Pos].CompleteDuration[Pos].FileName=Map_Item->second.FileName;
-                FromCpl->References[References_Pos].Infos=Map_Item->second.Reference->Infos;
-                for (list<File__ReferenceFilesHelper::references::iterator>::iterator Reference2=List.begin(); Reference2!=List.end(); ++Reference2)
-                    if (*Reference2==Map_Item->second.Reference)
-                    {
-                        List.erase(Reference2);
-                        break;
-                    }
-            }
-            else
-            {
-                FromCpl->References[References_Pos].CompleteDuration.erase(FromCpl->References[References_Pos].CompleteDuration.begin()+Pos);
-                Pos--;
-            }
-        }
-        if (FromCpl->References[References_Pos].FileNames.empty() && FromCpl->References[References_Pos].CompleteDuration.empty())
-        {
-            FromCpl->References.erase(FromCpl->References.begin()+References_Pos);
-            References_Pos--;
-        }
-    }
-}
-
 //***************************************************************************
 // Constructor/Destructor
 //***************************************************************************
@@ -149,7 +70,7 @@ File_DcpCpl::~File_DcpCpl()
 //---------------------------------------------------------------------------
 void File_DcpCpl::Streams_Finish()
 {
-    if (Config->File_IsReferenced_Get() || ReferenceFiles==NULL)
+    if (ReferenceFiles==NULL)
         return;
 
     ReferenceFiles->ParseReferences();
@@ -163,10 +84,10 @@ void File_DcpCpl::Streams_Finish()
 #if MEDIAINFO_SEEK
 size_t File_DcpCpl::Read_Buffer_Seek (size_t Method, int64u Value, int64u ID)
 {
-    if (Config->File_IsReferenced_Get() || ReferenceFiles==NULL)
+    if (ReferenceFiles==NULL)
         return 0;
 
-    return ReferenceFiles->Read_Buffer_Seek(Method, Value, ID);
+    return ReferenceFiles->Seek(Method, Value, ID);
 }
 #endif //MEDIAINFO_SEEK
 
@@ -222,11 +143,11 @@ bool File_DcpCpl::FileHeader_Begin()
         //CompositionTimecode
         if (IsImf && (!strcmp(CompositionPlaylist_Item->Value(), "CompositionTimecode") || !strcmp(CompositionPlaylist_Item->Value(), "cpl:CompositionTimecode")))
         {
-            File__ReferenceFilesHelper::reference ReferenceFile;
-            ReferenceFile.StreamKind=Stream_Other;
-            ReferenceFile.Infos["Type"]=__T("Time code");
-            ReferenceFile.Infos["Format"]=__T("CPL TC");
-            ReferenceFile.Infos["TimeCode_Settings"]=__T("Striped");
+            sequence* Sequence=new sequence;
+            Sequence->StreamKind=Stream_Other;
+            Sequence->Infos["Type"]=__T("Time code");
+            Sequence->Infos["Format"]=__T("CPL TC");
+            Sequence->Infos["TimeCode_Striped"]=__T("Yes");
             bool IsDropFrame=false;
 
             for (XMLElement* CompositionTimecode_Item=CompositionPlaylist_Item->FirstChildElement(); CompositionTimecode_Item; CompositionTimecode_Item=CompositionTimecode_Item->NextSiblingElement())
@@ -240,28 +161,27 @@ bool File_DcpCpl::FileHeader_Begin()
 
                 //TimecodeRate
                 if (!strcmp(CompositionTimecode_Item->Value(), "TimecodeRate") || !strcmp(CompositionTimecode_Item->Value(), "cpl:TimecodeRate"))
-                    ReferenceFile.Infos["FrameRate"].From_UTF8(CompositionTimecode_Item->GetText());
+                    Sequence->Infos["FrameRate"].From_UTF8(CompositionTimecode_Item->GetText());
 
                 //TimecodeStartAddress
                 if (!strcmp(CompositionTimecode_Item->Value(), "TimecodeStartAddress") || !strcmp(CompositionTimecode_Item->Value(), "cpl:TimecodeStartAddress"))
-                    ReferenceFile.Infos["TimeCode_FirstFrame"].From_UTF8(CompositionTimecode_Item->GetText());
+                    Sequence->Infos["TimeCode_FirstFrame"].From_UTF8(CompositionTimecode_Item->GetText());
             }
 
             //Adaptation
             if (IsDropFrame)
             {
-                std::map<string, Ztring>::iterator Info=ReferenceFile.Infos.find("TimeCode_FirstFrame");
-                if (Info!=ReferenceFile.Infos.end() && Info->second.size()>=11 && Info->second[8]!=__T(';'))
+                std::map<string, Ztring>::iterator Info=Sequence->Infos.find("TimeCode_FirstFrame");
+                if (Info!=Sequence->Infos.end() && Info->second.size()>=11 && Info->second[8]!=__T(';'))
                     Info->second[8]=__T(';');
             }
 
-            ReferenceFile.StreamID=ReferenceFiles->References.size()+1;
-            ReferenceFiles->References.push_back(ReferenceFile);
+            Sequence->StreamID=ReferenceFiles->Sequences_Size()+1;
+            ReferenceFiles->AddSequence(Sequence);
 
-            //TODO: put this code in File__ReferenceFilesHelper so we can demux time code with the other streams
             Stream_Prepare(Stream_Other);
-            Fill(Stream_Other, StreamPos_Last, Other_ID, ReferenceFile.StreamID);
-            for (std::map<string, Ztring>::iterator Info=ReferenceFile.Infos.begin(); Info!=ReferenceFile.Infos.end(); ++Info)
+            Fill(Stream_Other, StreamPos_Last, Other_ID, Sequence->StreamID);
+            for (std::map<string, Ztring>::iterator Info=Sequence->Infos.begin(); Info!=Sequence->Infos.end(); ++Info)
                 Fill(Stream_Other, StreamPos_Last, Info->first.c_str(), Info->second);
         }
 
@@ -287,15 +207,15 @@ bool File_DcpCpl::FileHeader_Begin()
                                 //if ((IsDcp && (!strcmp(AssetList_Item->Value(), "MainPicture") || !strcmp(AssetList_Item->Value(), "MainSound")))
                                 // || (IsImf && (!strcmp(AssetList_Item->Value(), "cc:MainImageSequence") || !strcmp(AssetList_Item->Value(), "cc:MainImage"))))
                                 {
-                                    File__ReferenceFilesHelper::reference ReferenceFile;
+                                    sequence* Sequence=new sequence;
                                     Ztring Asset_Id;
 
                                     if ((IsDcp && !strcmp(AssetList_Item->Value(), "MainPicture"))
                                      || (IsImf && !strcmp(AssetList_Item->Value(), "cc:MainImageSequence")))
-                                        ReferenceFile.StreamKind=Stream_Video;
+                                        Sequence->StreamKind=Stream_Video;
                                     if ((IsDcp && !strcmp(AssetList_Item->Value(), "MainSound"))
                                      || (IsImf && !strcmp(AssetList_Item->Value(), "cc:MainAudioSequence")))
-                                        ReferenceFile.StreamKind=Stream_Audio;
+                                        Sequence->StreamKind=Stream_Audio;
 
                                     for (XMLElement* File_Item=AssetList_Item->FirstChildElement(); File_Item; File_Item=File_Item->NextSiblingElement())
                                     {
@@ -313,26 +233,30 @@ bool File_DcpCpl::FileHeader_Begin()
                                                 {
                                                     Ztring Resource_Id;
 
-                                                    File__ReferenceFilesHelper::reference::completeduration Resource;
+                                                    resource* Resource=new resource;
                                                     for (XMLElement* Resource_Item=ResourceList_Item->FirstChildElement(); Resource_Item; Resource_Item=Resource_Item->NextSiblingElement())
                                                     {
                                                         //EditRate
                                                         if (!strcmp(Resource_Item->Value(), "EditRate"))
                                                         {
                                                             const char* EditRate=Resource_Item->GetText();
-                                                            Resource.IgnoreFramesRate=atof(EditRate);
+                                                            Resource->EditRate=atof(EditRate);
                                                             const char* EditRate2=strchr(EditRate, ' ');
                                                             if (EditRate2!=NULL)
                                                             {
                                                                 float64 EditRate2f=atof(EditRate2);
                                                                 if (EditRate2f)
-                                                                    Resource.IgnoreFramesRate/=EditRate2f;
+                                                                    Resource->EditRate/=EditRate2f;
                                                             }
                                                         }
 
                                                         //EntryPoint
                                                         if (!strcmp(Resource_Item->Value(), "EntryPoint"))
-                                                            Resource.IgnoreFramesBefore=atoi(Resource_Item->GetText());
+                                                        {
+                                                            Resource->IgnoreEditsBefore=atoi(Resource_Item->GetText());
+                                                            if (Resource->IgnoreEditsAfter!=(int64u)-1)
+                                                                Resource->IgnoreEditsAfter+=Resource->IgnoreEditsBefore;
+                                                        }
 
                                                         //Id
                                                         if (!strcmp(File_Item->Value(), "Id") && Resource_Id.empty())
@@ -340,29 +264,29 @@ bool File_DcpCpl::FileHeader_Begin()
 
                                                         //SourceDuration
                                                         if (!strcmp(Resource_Item->Value(), "SourceDuration"))
-                                                            Resource.IgnoreFramesAfterDuration=atoi(Resource_Item->GetText());
+                                                            Resource->IgnoreEditsAfter=Resource->IgnoreEditsBefore+atoi(Resource_Item->GetText());
 
                                                         //TrackFileId
                                                         if (!strcmp(Resource_Item->Value(), "TrackFileId"))
-                                                            Resource.FileName.From_UTF8(Resource_Item->GetText());
+                                                            Resource->FileNames.push_back(Ztring().From_UTF8(Resource_Item->GetText()));
                                                     }
 
-                                                    if (Resource.FileName.empty())
-                                                        Resource.FileName=Resource_Id;
-                                                    ReferenceFile.CompleteDuration.push_back(Resource);
+                                                    if (Resource->FileNames.empty())
+                                                        Resource->FileNames.push_back(Resource_Id);
+                                                    Sequence->AddResource(Resource);
                                                 }
                                             }
                                         }
                                     }
 
-                                    if (ReferenceFile.CompleteDuration.empty())
+                                    if (Sequence->Resources.empty())
                                     {
-                                        File__ReferenceFilesHelper::reference::completeduration Resource;
-                                        Resource.FileName=Asset_Id;
-                                        ReferenceFile.CompleteDuration.push_back(Resource);
+                                        resource* Resource=new resource;
+                                        Resource->FileNames.push_back(Asset_Id);
+                                        Sequence->AddResource(Resource);
                                     }
-                                    ReferenceFile.StreamID=ReferenceFiles->References.size()+1;
-                                    ReferenceFiles->References.push_back(ReferenceFile);
+                                    Sequence->StreamID=ReferenceFiles->Sequences_Size()+1;
+                                    ReferenceFiles->AddSequence(Sequence);
                                 }
                             }
                         }
@@ -375,32 +299,34 @@ bool File_DcpCpl::FileHeader_Begin()
     Element_Offset=File_Size;
 
     //Getting files names
-    if (!Config->File_IsReferenced_Get())
+    FileName Directory(File_Name);
+    Ztring Assetmap_FileName=Directory.Path_Get()+PathSeparator+__T("ASSETMAP.xml");
+    bool IsOk=false;
+    if (File::Exists(Assetmap_FileName))
+        IsOk=true;
+    else
     {
-        FileName Directory(File_Name);
-        ZtringList List;
-        if (IsImf)
-            List=Dir::GetAllFileNames(Directory.Path_Get()+PathSeparator+__T("PKL_*.xml"), Dir::Include_Files);
-        if (IsDcp || List.empty())
-            List=Dir::GetAllFileNames(Directory.Path_Get()+PathSeparator+__T("*_pkl.xml"), Dir::Include_Files);
-        for (size_t Pos=0; Pos<List.size(); Pos++)
+        Assetmap_FileName.resize(Assetmap_FileName.size()-4); //Old fashion, without ".xml"
+        if (File::Exists(Assetmap_FileName))
+            IsOk=true;
+    }
+    if (IsOk)
+    {
+        MediaInfo_Internal MI;
+        MI.Option(__T("File_KeepInfo"), __T("1"));
+        Ztring ParseSpeed_Save=MI.Option(__T("ParseSpeed_Get"), __T(""));
+        Ztring Demux_Save=MI.Option(__T("Demux_Get"), __T(""));
+        MI.Option(__T("ParseSpeed"), __T("0"));
+        MI.Option(__T("Demux"), Ztring());
+        MI.Option(__T("File_IsReferenced"), __T("1"));
+        size_t MiOpenResult=MI.Open(Assetmap_FileName);
+        MI.Option(__T("ParseSpeed"), ParseSpeed_Save); //This is a global value, need to reset it. TODO: local value
+        MI.Option(__T("Demux"), Demux_Save); //This is a global value, need to reset it. TODO: local value
+        if (MiOpenResult
+            && (MI.Get(Stream_General, 0, General_Format)==__T("DCP AM")
+            || MI.Get(Stream_General, 0, General_Format)==__T("IMF AM")))
         {
-            MediaInfo_Internal MI;
-            MI.Option(__T("File_KeepInfo"), __T("1"));
-            Ztring ParseSpeed_Save=MI.Option(__T("ParseSpeed_Get"), __T(""));
-            Ztring Demux_Save=MI.Option(__T("Demux_Get"), __T(""));
-            MI.Option(__T("ParseSpeed"), __T("0"));
-            MI.Option(__T("Demux"), Ztring());
-            MI.Option(__T("File_IsReferenced"), __T("1"));
-            size_t MiOpenResult=MI.Open(List[Pos]);
-            MI.Option(__T("ParseSpeed"), ParseSpeed_Save); //This is a global value, need to reset it. TODO: local value
-            MI.Option(__T("Demux"), Demux_Save); //This is a global value, need to reset it. TODO: local value
-            if (MiOpenResult
-             && (MI.Get(Stream_General, 0, General_Format)==__T("DCP PKL")
-              || MI.Get(Stream_General, 0, General_Format)==__T("IMF PKL")))
-            {
-                DcpCpl_MergeFromPkl(ReferenceFiles, ((File_DcpCpl*)MI.Info)->ReferenceFiles);
-            }
+            MergeFromAm(((File_DcpAm*)MI.Info)->Streams);
         }
     }
 
@@ -410,7 +336,18 @@ bool File_DcpCpl::FileHeader_Begin()
     return true;
 }
 
+//***************************************************************************
+// Infos
+//***************************************************************************
+
+//---------------------------------------------------------------------------
+void File_DcpCpl::MergeFromAm (File_DcpPkl::streams &StreamsToMerge)
+{
+    for (File_DcpPkl::streams::iterator StreamToMerge=StreamsToMerge.begin(); StreamToMerge!=StreamsToMerge.end(); ++StreamToMerge)
+        if (!StreamToMerge->ChunkList.empty()) // Note: ChunkLists with more than 1 file are not yet supported)
+            ReferenceFiles->UpdateFileName(Ztring().From_UTF8(StreamToMerge->Id), Ztring().From_UTF8(StreamToMerge->ChunkList[0].Path));
+}
+
 } //NameSpace
 
 #endif //MEDIAINFO_DCP_YES
-
