@@ -744,11 +744,11 @@ void File_DvDif::Synched_Test_Reset()
 void File_DvDif::Synched_Init()
 {
     //FrameInfo
-    if (FrameInfo.DTS==(int64u)-1)
+    if (!IsSub && FrameInfo.DTS==(int64u)-1)
         FrameInfo.DTS=0; //No DTS in container
-    if (FrameInfo.PTS==(int64u)-1)
+    if (!IsSub && FrameInfo.PTS==(int64u)-1)
         FrameInfo.PTS=0; //No PTS in container
-    if (Frame_Count_NotParsedIncluded==(int64u)-1)
+    if (!IsSub && Frame_Count_NotParsedIncluded==(int64u)-1)
         Frame_Count_NotParsedIncluded=0; //No Frame_Count_NotParsedIncluded in the container
 }
 
@@ -1552,14 +1552,14 @@ void File_DvDif::video_source()
 
     BS_Begin();
     //PC1
-    Skip_S1(4,                                                  "TVCH (tens of units, 09)");
-    Skip_S1(4,                                                  "TVCH (units, 09)");
+    Skip_S1(4,                                                  "TVCH (tens of units, 0-9)");
+    Skip_S1(4,                                                  "TVCH (units, 0-9)");
 
     //PC2
     Skip_SB(                                                    "B/W - Black and White"); //0=Black and White, 1=Color
     Skip_SB(                                                    "EN - Color Frames is not valid");
     Skip_S1(2,                                                  "CLF - Color frames id");
-    Skip_S1(4,                                                  "TVCH (hundreds of units, 09)");
+    Skip_S1(4,                                                  "TVCH (hundreds of units, 0-9)");
 
     //PC3
     Skip_S1(2,                                                  "SRC");
