@@ -739,6 +739,15 @@ bool File_Flv::Synched_Test()
      && Buffer[Buffer_Offset+3]<PreviousTagSize_Add11
      && File_Offset+Buffer_Offset>9)
     {
+        if (Searching_Duration)
+        {
+            //Error during parsing, stopping
+            Finish();
+            Searching_Duration=false;
+            GoTo(File_Size);
+            return true;
+        }
+
         Synched=false;
         return true;
     }
@@ -849,7 +858,7 @@ void File_Flv::Data_Parse()
                             {
                                 Searching_Duration=false;
                                 Open_Buffer_Unsynch(); //There is a problem, trying to sync
-                                PreviousTagSize=65536;
+                                PreviousTagSize=1024*1024;
                             }
                             GoTo(File_Size-PreviousTagSize-8, "FLV");
                             return;
@@ -865,7 +874,7 @@ void File_Flv::Data_Parse()
     {
         if ((((Count_Get(Stream_Video)==0 || Stream[Stream_Video].TimeStamp!=(int32u)-1)
            && (Count_Get(Stream_Audio)==0 || Stream[Stream_Audio].TimeStamp!=(int32u)-1))
-          || (File_Size>65536*2 && File_Offset+Buffer_Offset-Header_Size-PreviousTagSize-4<File_Size-65536))
+          || (File_Size>1024*1024*2 && File_Offset+Buffer_Offset-Header_Size-PreviousTagSize-4<File_Size-1024*1024))
          && Config->ParseSpeed<1)
             Finish();
         else if (Element_Code==0xFA) //RM metadata have a malformed PreviousTagSize, always
@@ -873,13 +882,13 @@ void File_Flv::Data_Parse()
             //Trying to sync
             Searching_Duration=false;
             Open_Buffer_Unsynch(); //There is a problem, trying to sync
-            GoToFromEnd(Header_Size+Element_Size+65536);
+            GoToFromEnd(Header_Size+Element_Size+1024*1024);
             return;
         }
         else
             GoTo(File_Offset+Buffer_Offset-Header_Size-PreviousTagSize-4);
     }
-    else if (!video_stream_Count && !audio_stream_Count && video_stream_FrameRate_Detected && File_Offset+65536*2<File_Size && MediaInfoLib::Config.ParseSpeed_Get()<1) //All streams are parsed
+    else if (!Status[IsFilled] && !video_stream_Count && !audio_stream_Count && video_stream_FrameRate_Detected && File_Offset+1024*1024*2<File_Size && MediaInfoLib::Config.ParseSpeed_Get()<1) //All streams are parsed
     {
         Fill();
 
@@ -1381,9 +1390,14 @@ void File_Flv::audio_AAC()
         case 1 :
                 //Parsing
                 Demux(Buffer+Buffer_Offset+(size_t)Element_Offset, (size_t)(Element_Size-Element_Offset), ContentType_MainStream);
-                Open_Buffer_Continue(Stream[Stream_Audio].Parser);
+                if (Stream[Stream_Audio].Parser)
+                {
+                    Open_Buffer_Continue(Stream[Stream_Audio].Parser);
 
-                Stream[Stream_Audio].Parser->Open_Buffer_Unsynch();
+                    Stream[Stream_Audio].Parser->Open_Buffer_Unsynch();
+                }
+                else
+                    Skip_XX(Element_Size-Element_Offset,        "Decoder config is missing");
                 audio_stream_Count=false; //No need of more
                 break;
         default: Skip_XX(Element_Size-Element_Offset,           "Unknown");
