@@ -1,21 +1,8 @@
-// File_Mk - Info for Ibi files
-// Copyright (C) 2011-2012 MediaArea.net SARL, Info@MediaArea.net
-//
-// This library is free software: you can redistribute it and/or modify it
-// under the terms of the GNU Library General Public License as published by
-// the Free Software Foundation, either version 2 of the License, or
-// any later version.
-//
-// This library is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-// GNU Library General Public License for more details.
-//
-// You should have received a copy of the GNU Library General Public License
-// along with this library. If not, see <http://www.gnu.org/licenses/>.
-//
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+/*  Copyright (c) MediaArea.net SARL. All Rights Reserved.
+ *
+ *  Use of this source code is governed by a BSD-style license that can
+ *  be found in the License.html file in the root of the source tree.
+ */
 
 //---------------------------------------------------------------------------
 // Pre-compilation
@@ -56,18 +43,22 @@ File_Ibi::File_Ibi()
     #endif //MEDIAINFO_DEMUX
     DataMustAlwaysBeComplete=false;
 
-    //In
-    Ibi=NULL;
+    #if MEDIAINFO_IBIUSAGE
+        //In
+        Ibi=NULL;
 
-    //Temp
-    Ibi_MustDelete=false;
+        //Temp
+        Ibi_MustDelete=false;
+    #endif //MEDIAINFO_IBIUSAGE
 }
 
 //---------------------------------------------------------------------------
 File_Ibi::~File_Ibi()
 {
-    if (Ibi_MustDelete)
-        delete Ibi; //Ibi=NULL;
+    #if MEDIAINFO_IBIUSAGE
+        if (Ibi_MustDelete)
+            delete Ibi; //Ibi=NULL;
+    #endif //MEDIAINFO_IBIUSAGE
 }
 
 //***************************************************************************
@@ -75,6 +66,7 @@ File_Ibi::~File_Ibi()
 //***************************************************************************
 
 //---------------------------------------------------------------------------
+#if MEDIAINFO_IBIUSAGE
 const Ztring &File_Ibi::Get (stream_t /*StreamKind*/, size_t /*StreamNumber*/, const Ztring &Parameter, info_t /*KindOfInfo*/, info_t /*KindOfSearch*/)
 {
     ibi::streams::iterator IbiStream_Temp=Ibi->Streams.begin(); //TODO: management of multiple streams
@@ -96,6 +88,7 @@ const Ztring &File_Ibi::Get (stream_t /*StreamKind*/, size_t /*StreamNumber*/, c
     Get_Temp.clear();
     return Get_Temp;
 }
+#endif //MEDIAINFO_IBIUSAGE
 
 //***************************************************************************
 // Streams management
@@ -106,24 +99,29 @@ void File_Ibi::Streams_Accept()
 {
     Fill(Stream_General, 0, General_Format, "Ibi");
 
-    if (Ibi==NULL)
-    {
-        Ibi=new ibi();
-        Ibi_MustDelete=true;
-    }
+    #if MEDIAINFO_IBIUSAGE
+        if (Ibi==NULL)
+        {
+            Ibi=new ibi();
+            Ibi_MustDelete=true;
+        }
+    #endif //MEDIAINFO_IBIUSAGE
 }
 
 //---------------------------------------------------------------------------
+#if MEDIAINFO_IBIUSAGE
 void File_Ibi::Streams_Finish()
 {
     Config->File_KeepInfo_Set(true); //In order to let Get() available
 
-    for (ibi::streams::iterator IbiStream_Temp=Ibi->Streams.begin(); IbiStream_Temp!=Ibi->Streams.end(); IbiStream_Temp++)
-    {
-        Stream_Prepare(Stream_Video);
-        Fill(Stream_Video, StreamPos_Last, General_ID, IbiStream_Temp->first);
-    }
+    if (Count_Get(Stream_Video)==0) //If not yet done by Inform part
+        for (ibi::streams::iterator IbiStream_Temp=Ibi->Streams.begin(); IbiStream_Temp!=Ibi->Streams.end(); ++IbiStream_Temp)
+        {
+            Stream_Prepare(Stream_Video);
+            Fill(Stream_Video, StreamPos_Last, General_ID, IbiStream_Temp->first);
+        }
 }
+#endif //MEDIAINFO_IBIUSAGE
 
 //***************************************************************************
 // Buffer
@@ -137,9 +135,25 @@ void File_Ibi::Header_Parse()
     Peek_B1(Null);
     if (Null==0x00)
     {
-        Skip_B1(                                                "Zero byte");
+        if (Buffer_Offset_Temp==0)
+            Buffer_Offset_Temp=Buffer_Offset+1;
+
+        while (Buffer_Offset_Temp<Buffer_Size)
+        {
+            if (Buffer[Buffer_Offset_Temp])
+                break;
+            Buffer_Offset_Temp++;
+        }
+        if (Buffer_Offset_Temp>=Buffer_Size)
+        {
+            Element_WaitForMoreData();
+            return;
+        }
+
         Header_Fill_Code((int32u)-1); //Should be (int64u)-1 but Borland C++ does not like this
-        Header_Fill_Size(1);
+        Header_Fill_Size(Buffer_Offset_Temp-Buffer_Offset);
+        Buffer_Offset_Temp=0;
+
         return;
     }
 
@@ -172,12 +186,20 @@ namespace Elements
     const int64u Ebml_DocTypeReadVersion=0x285;
 
     //Segment
-    const int64u Stream=0x01;
-    const int64u Stream_Header=0x01;
-    const int64u Stream_ByteOffset=0x02;
-    const int64u Stream_FrameNumber=0x03;
-    const int64u Stream_Dts=0x04;
-    const int64u CompressedIndex=0x02;
+    const int64u Stream=1;
+    const int64u Stream_Header=1;
+    const int64u Stream_ByteOffset=2;
+    const int64u Stream_FrameNumber=3;
+    const int64u Stream_Dts=4;
+    const int64u CompressedIndex=2;
+    const int64u WritingApplication=3;
+    const int64u WritingApplication_Name=1;
+    const int64u WritingApplication_Version=2;
+    const int64u InformData=4;
+    const int64u SourceInfo=5;
+    const int64u SourceInfo_IndexCreationDate=1;
+    const int64u SourceInfo_SourceModificationDate=2;
+    const int64u SourceInfo_SourceSize=3;
 }
 
 //---------------------------------------------------------------------------
@@ -235,8 +257,18 @@ void File_Ibi::Data_Parse()
             ATOM(Stream_Dts)
         ATOM_END_MK
     ATOM(CompressedIndex)
-    DATA_DEFAULT
-        Finish("Ibi");
+    LIST(WritingApplication)
+        ATOM_BEGIN
+            ATOM(WritingApplication_Name)
+            ATOM(WritingApplication_Version)
+        ATOM_END_MK
+    LIST(SourceInfo)
+        ATOM_BEGIN
+            ATOM(SourceInfo_IndexCreationDate)
+            ATOM(SourceInfo_SourceModificationDate)
+            ATOM(SourceInfo_SourceSize)
+        ATOM_END_MK
+    ATOM(InformData)
     DATA_END_DEFAULT
 }
 
@@ -329,8 +361,6 @@ void File_Ibi::Ebml_DocType()
             Reject("Ibi");
             return;
         }
-
-        Buffer_MaximumSize=8*1024*1024;
     FILLING_END();
 }
 
@@ -366,6 +396,7 @@ void File_Ibi::Stream_Header()
     Get_EB (ID_Current,                                         "ID");
 
     FILLING_BEGIN();
+        #if MEDIAINFO_IBIUSAGE
         if (Ibi)
         {
             //Filling information for ID after data
@@ -376,6 +407,10 @@ void File_Ibi::Stream_Header()
                 Ibi->Streams.erase(IbiStream_Temp);
             }
         }
+        #else //MEDIAINFO_IBIUSAGE
+            Stream_Prepare(Stream_Video);
+            Fill(Stream_Video, StreamPos_Last, General_ID, ID_Current);
+        #endif //MEDIAINFO_IBIUSAGE
     FILLING_END();
 }
 
@@ -384,16 +419,21 @@ void File_Ibi::Stream_ByteOffset()
     Element_Name("Byte Offset");
 
     //Parsing
+    #if MEDIAINFO_IBIUSAGE
     size_t Pos=0;
+    #endif //MEDIAINFO_IBIUSAGE
     int64u Offset=0;
     while (Element_Offset<Element_Size)
     {
         int64u Item;
         Get_EB (Item,                                           "Item");
         Offset+=Item;
+        #if MEDIAINFO_IBIUSAGE
         Param_Info1(Pos);
+        #endif //MEDIAINFO_IBIUSAGE
         Param_Info1(Ztring::ToZtring(Offset)+__T(" (0x")+Ztring::ToZtring(Offset, 16)+__T(')'));
 
+        #if MEDIAINFO_IBIUSAGE
         FILLING_BEGIN();
             if (Ibi)
             {
@@ -409,6 +449,7 @@ void File_Ibi::Stream_ByteOffset()
                 Pos++;
             }
         FILLING_END();
+        #endif //MEDIAINFO_IBIUSAGE
     }
 }
 
@@ -417,16 +458,21 @@ void File_Ibi::Stream_FrameNumber()
     Element_Name("Frame Number");
 
     //Parsing
+    #if MEDIAINFO_IBIUSAGE
     size_t Pos=0;
+    #endif //MEDIAINFO_IBIUSAGE
     int64u Offset=0;
     while (Element_Offset<Element_Size)
     {
         int64u Item;
         Get_EB (Item,                                           "Item");
         Offset+=Item;
+        #if MEDIAINFO_IBIUSAGE
         Param_Info1(Pos);
+        #endif //MEDIAINFO_IBIUSAGE
         Param_Info1(Ztring::ToZtring(Offset)+__T(" (0x")+Ztring::ToZtring(Offset, 16)+__T(')'));
 
+        #if MEDIAINFO_IBIUSAGE
         FILLING_BEGIN();
             if (Ibi)
             {
@@ -442,6 +488,7 @@ void File_Ibi::Stream_FrameNumber()
                 Pos++;
             }
         FILLING_END();
+        #endif //MEDIAINFO_IBIUSAGE
     }
 }
 
@@ -452,11 +499,14 @@ void File_Ibi::Stream_Dts()
     //Parsing
     int64u Item;
     Get_EB (Item,                                               "DtsFrequencyNumerator");
+    #if MEDIAINFO_IBIUSAGE
     FILLING_BEGIN();
         if (Ibi)
             Ibi->Streams[ID_Current]->DtsFrequencyNumerator=Item;
     FILLING_END();
+    #endif //MEDIAINFO_IBIUSAGE
     Get_EB (Item,                                               "DtsFrequencyDenominator");
+    #if MEDIAINFO_IBIUSAGE
     FILLING_BEGIN();
         if (Ibi)
         {
@@ -467,17 +517,23 @@ void File_Ibi::Stream_Dts()
                 std::swap(Ibi->Streams[ID_Current]->DtsFrequencyNumerator, Ibi->Streams[ID_Current]->DtsFrequencyDenominator);
         }
     FILLING_END();
+    #endif //MEDIAINFO_IBIUSAGE
 
+    #if MEDIAINFO_IBIUSAGE
     size_t Pos=0;
+    #endif //MEDIAINFO_IBIUSAGE
     int64u Offset=0;
     while (Element_Offset<Element_Size)
     {
         int64u Item;
         Get_EB (Item,                                           "Item");
         Offset+=Item;
+        #if MEDIAINFO_IBIUSAGE
         Param_Info1(Pos);
+        #endif //MEDIAINFO_IBIUSAGE
         Param_Info1(Ztring::ToZtring(Offset)+__T(" (0x")+Ztring::ToZtring(Offset, 16)+__T(')'));
 
+        #if MEDIAINFO_IBIUSAGE
         FILLING_BEGIN();
             if (Ibi)
             {
@@ -493,11 +549,18 @@ void File_Ibi::Stream_Dts()
                 Pos++;
             }
         FILLING_END();
+        #endif //MEDIAINFO_IBIUSAGE
     }
 }
 
 void File_Ibi::CompressedIndex()
 {
+    if (!Status[IsAccepted])
+    {
+        Reject("Ibi");
+        return;
+    }
+
     Element_Name("Compressed Index");
     int64u UncompressedSize;
     Get_EB (UncompressedSize,                                   "Uncompressed size");
@@ -507,7 +570,17 @@ void File_Ibi::CompressedIndex()
     unsigned long Dest_Size=(unsigned long)UncompressedSize;
 
     //Uncompressing
-    int8u* Dest=new int8u[Dest_Size];
+    int8u* Dest;
+    try
+    {
+        Dest=new int8u[Dest_Size];
+    }
+    catch (...)
+    {
+        //Memory error
+        Reject();
+        return;
+    }
     if (uncompress((Bytef*)Dest, &Dest_Size, (const Bytef*)Buffer+Buffer_Offset+(size_t)Element_Offset, Source_Size)<0)
     {
         Skip_XX(Element_Size-Element_Offset,                    "Problem during the decompression");
@@ -550,7 +623,9 @@ void File_Ibi::CompressedIndex()
     Element_Level--;
 
     //Parsing
-    Open_Buffer_Continue(Dest, Dest_Size);
+    Buffer=Dest;
+    Buffer_Size=Dest_Size;
+    while (Open_Buffer_Continue_Loop());
     delete[] Dest; //Dest=NULL;
 
     //Resetting file size
@@ -579,6 +654,113 @@ void File_Ibi::CompressedIndex()
     Buffer_Offset_Temp=Buffer_Offset_Temp_Sav;
 }
 
+//---------------------------------------------------------------------------
+void File_Ibi::WritingApplication()
+{
+    Element_Name("WritingApplication");
+}
+
+//---------------------------------------------------------------------------
+void File_Ibi::WritingApplication_Name()
+{
+    Element_Name("Name");
+
+    //Parsing
+    Skip_UTF8(Element_Size,                                     "Data");
+}
+
+//---------------------------------------------------------------------------
+void File_Ibi::WritingApplication_Version()
+{
+    Element_Name("Version");
+
+    //Parsing
+    Skip_UTF8(Element_Size,                                     "Data");
+}
+
+//---------------------------------------------------------------------------
+void File_Ibi::SourceInfo()
+{
+    Element_Name("Source Information");
+}
+
+//---------------------------------------------------------------------------
+void File_Ibi::SourceInfo_IndexCreationDate()
+{
+    Element_Name("Index Creation Date");
+
+    //Parsing
+    Skip_B8(                                                    "Data");
+}
+
+//---------------------------------------------------------------------------
+void File_Ibi::SourceInfo_SourceModificationDate()
+{
+    Element_Name("Source Modification Date");
+
+    //Parsing
+    Skip_B8(                                                    "Data");
+}
+
+//---------------------------------------------------------------------------
+void File_Ibi::SourceInfo_SourceSize()
+{
+    Element_Name("Source Size");
+
+    //Parsing
+    Skip_B8(                                                    "Data");
+}
+
+//---------------------------------------------------------------------------
+void File_Ibi::InformData()
+{
+    Element_Name("InformData");
+
+    //Parsing
+    Ztring InformData_FromFile;
+    Get_UTF8 (Element_Size, InformData_FromFile,                "Data");
+
+    //Filling
+    #if MEDIAINFO_IBIUSAGE
+    if (Config->Ibi_UseIbiInfoIfAvailable_Get())
+    {
+        ZtringListList Fields(InformData_FromFile);
+        for (size_t Pos=0; Pos<Fields.size(); Pos++)
+        {
+            if (Pos==0 || Fields[Pos].size()<2)
+            {
+                if (Pos)
+                    Pos++;
+                if (Pos>Fields.size() || Fields[Pos].size()<1)
+                    break; //End or problem
+
+                if (Fields[Pos][0]==__T("General"))
+                    ; //Nothing to do
+                else if (Fields[Pos][0]==__T("Video"))
+                    Stream_Prepare(Stream_Video);
+                else if (Fields[Pos][0]==__T("Audio"))
+                    Stream_Prepare(Stream_Audio);
+                else if (Fields[Pos][0]==__T("Text"))
+                    Stream_Prepare(Stream_Text);
+                else if (Fields[Pos][0]==__T("Other"))
+                    Stream_Prepare(Stream_Other);
+                else if (Fields[Pos][0]==__T("Image"))
+                    Stream_Prepare(Stream_Image);
+                else if (Fields[Pos][0]==__T("Menu"))
+                    Stream_Prepare(Stream_Menu);
+                else
+                    break; //Problem
+                Pos++;
+            }
+
+            Fill(StreamKind_Last, StreamPos_Last, Fields[Pos][0].To_UTF8().c_str(), Fields[Pos][1], true);
+            if (Info_Options<Fields[Pos].size())
+                (*Stream_More)[StreamKind_Last][StreamPos_Last](Fields[Pos][0].To_UTF8().c_str(), Info_Options)=Fields[Pos][Info_Options];
+        }
+    }
+    #endif //MEDIAINFO_IBIUSAGE
+}
+
 //***************************************************************************
 // Data
 //***************************************************************************
@@ -761,5 +943,4 @@ int128u File_Ibi::UInteger16_Get()
 
 } //NameSpace
 
-#endif //MEDIAINFO_IBI_YES
-
+#endif //MEDIAINFO_IBI
