@@ -1,20 +1,9 @@
-// File_Ibi_Creation - Creation of Ibi files
-// Copyright (C) 2011-2012 MediaArea.net SARL, Info@MediaArea.net
-//
-// This library is free software: you can redistribute it and/or modify it
-// under the terms of the GNU Library General Public License as published by
-// the Free Software Foundation, either version 2 of the License, or
-// any later version.
-//
-// This library is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-// GNU Library General Public License for more details.
-//
-// You should have received a copy of the GNU Library General Public License
-// along with this library. If not, see <http://www.gnu.org/licenses/>.
-//
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+/*  Copyright (c) MediaArea.net SARL. All Rights Reserved.
+ *
+ *  Use of this source code is governed by a BSD-style license that can
+ *  be found in the License.html file in the root of the source tree.
+ */
+
 //+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 //
 // Information about Ibi files
@@ -28,8 +17,8 @@
 
 //---------------------------------------------------------------------------
 #include "ZenLib/Ztring.h"
-#include <map>
 #include <vector>
+#include <map>
 using namespace ZenLib;
 //---------------------------------------------------------------------------
 
@@ -83,13 +72,20 @@ struct ibi
     typedef std::map<int64u, stream*>   streams;
     streams                             Streams;
 
+    Ztring                              Inform_Data;
+    Ztring                              FileName;
+
     //Constructor/Destructor
     ibi();
     ~ibi();
 };
 
 //***************************************************************************
-// File_Ibi_Creation class
+/*  Copyright (c) MediaArea.net SARL. All Rights Reserved.
+ *
+ *  Use of this source code is governed by a BSD-style license that can
+ *  be found in the License.html file in the root of the source tree.
+ */
 //***************************************************************************
 
 class File_Ibi_Creation
