@@ -223,6 +223,7 @@ private :
     {
         std::vector<int64u>     TimeCodes;
         int64u                  TimeCode_Start;
+        int64u                  TrackUID;
         File__Analyze*          Parser;
         stream_t                StreamKind;
         size_t                  StreamPos;
@@ -241,10 +242,15 @@ private :
         std::map<std::string, Ztring> Infos;
         int64u                  TrackDefaultDuration;
         std::map<int64u, int64u> Segment_Cluster_BlockGroup_BlockDuration_Counts;
+        int64u                  PixelCropBottom;
+        int64u                  PixelCropLeft;
+        int64u                  PixelCropRight;
+        int64u                  PixelCropTop;
 
         stream()
         {
             TimeCode_Start=(int64u)-1;
+            TrackUID=(int64u)-1;
             Parser=NULL;
             StreamKind=Stream_Max;
             StreamPos=0;
@@ -261,6 +267,10 @@ private :
             ContentCompSettings_Buffer_Size=0;
             ContentCompSettings_Buffer=NULL;
             TrackDefaultDuration=0;
+            PixelCropBottom=0;
+            PixelCropLeft=0;
+            PixelCropRight=0;
+            PixelCropTop=0;
         }
 
         ~stream()
@@ -296,7 +306,7 @@ private :
     int64u   TrackType;
 
     //Temp
-    std::vector<Ztring> AttachedFiles;
+    int8u   InvalidByteMax;
     int64u  Format_Version;
     int64u  TimecodeScale;
     float64 Duration;
@@ -305,7 +315,24 @@ private :
     int64u  TrackVideoDisplayHeight;
     int32u  AvgBytesPerSec;
     int64u  Segment_Cluster_TimeCode_Value;
-    bool    Cluster_AlreadyParsed;
+    size_t  Segment_Info_Count;
+    size_t  Segment_Tracks_Count;
+    size_t  Segment_Cluster_Count;
+    typedef std::map<Ztring, Ztring> tagspertrack;
+    typedef std::map<int64u, tagspertrack> tags;
+    tags    Segment_Tags_Tag_Items;
+    int64u  Segment_Tags_Tag_Targets_TrackUID_Value;
+    bool    CurrentAttachmentIsCover;
+    bool    CoverIsSetFromAttachment;
+    struct crc32
+    {
+        int64u  Pos;
+        int64u  From;
+        int64u  UpTo;
+        int32u  Computed;
+        int32u  Expected;
+    };
+    std::vector<crc32> CRC32Compute;
 
     //Chapters
     struct chapterdisplay
@@ -335,10 +362,16 @@ private :
     int64u              Segment_Offset_End;
     std::vector<int64u> Segment_Seeks;
     size_t              Segment_Seeks_Pos;
-    int64u              Segment_Tag_TrackUID;
     std::vector<Ztring> Segment_Tag_SimpleTag_TagNames;
     int64u Segment_Cluster_BlockGroup_BlockDuration_Value;
     int64u Segment_Cluster_BlockGroup_BlockDuration_TrackNumber;
+
+    //Helpers
+    void JumpTo(int64u GoTo);
+    void TestMultipleInstances(size_t* Instances=NULL);
+    void CRC32_Check();
+    void CRC32_Compute(int32u &CRC32, int32u Init, const int8u* Buffer_Begin, const int8u* Buffer_End);
+    void CRC32_Compute(int32u &CRC32, const int8u* Buffer_Begin, const int8u* Buffer_End);
 };
 
 } //NameSpace
