@@ -215,6 +215,7 @@ private :
     void moov_trak_tapt_prof();
     void moov_trak_tapt_enof();
     void moov_trak_tkhd();
+    void moov_trak_txas();
     void moov_trak_tref();
     void moov_trak_tref_chap();
     void moov_trak_tref_clcp();
@@ -260,6 +261,7 @@ private :
     void moov_udta_meta_ilst_xxxx_data();
     void moov_udta_meta_ilst_xxxx_mean();
     void moov_udta_meta_ilst_xxxx_name();
+    void moov_udta_meta_uuid();
     void moov_udta_ndrm();
     void moov_udta_nsav();
     void moov_udta_rtng();
@@ -362,8 +364,8 @@ private :
         int32u                  hdlr_Manufacturer;
         struct edts_struct
         {
-            int32u  Duration;
-            int32u  Delay;
+            int64u  Duration;
+            int64u  Delay;
             int32u  Rate;
         };
         std::vector<edts_struct> edts;
@@ -406,6 +408,20 @@ private :
         bool                    IsPriorityStream;
         bool                    IsFilled;
         bool                    IsChapter;
+        bool                    IsEnabled;
+        bool                    IsExcluded;
+        bool                    HasForcedSamples;
+        bool                    AllForcedSamples;
+        std::vector<int32u>     CC;
+        std::vector<int32u>     CCFor;
+        std::vector<int32u>     FallBackTo;
+        std::vector<int32u>     FallBackFrom;
+        std::vector<int32u>     Subtitle;
+        std::vector<int32u>     SubtitleFor;
+        std::vector<int32u>     Forced;
+        std::vector<int32u>     ForcedFor;
+        std::vector<int32u>     Chapters;
+        std::vector<int32u>     ChaptersFor;
         float32                 CleanAperture_Width;
         float32                 CleanAperture_Height;
         float32                 CleanAperture_PixelAspectRatio;
@@ -463,6 +479,9 @@ private :
             IsPriorityStream=false;
             IsFilled=false;
             IsChapter=false;
+            IsExcluded=false;
+            HasForcedSamples=false;
+            AllForcedSamples=false;
             CleanAperture_Width=0;
             CleanAperture_Height=0;
             CleanAperture_PixelAspectRatio=0;
