@@ -72,6 +72,9 @@ private :
     //Buffer - Global
     void Read_Buffer_Continue();
     void Read_Buffer_AfterParsing ();
+    #if MEDIAINFO_ADVANCED2
+    void Read_Buffer_SegmentChange();
+    #endif //MEDIAINFO_ADVANCED2
     void Read_Buffer_Unsynched();
     #if MEDIAINFO_SEEK
     size_t Read_Buffer_Seek (size_t Method, int64u Value, int64u ID);
@@ -103,6 +106,7 @@ private :
     #endif
     int64u MpegTs_JumpTo_Begin;
     int64u MpegTs_JumpTo_End;
+    int64u MpegTs_ScanUpTo;
     int64u Begin_MaxDuration; //in 27 MHz
     int64u Buffer_TotalBytes_LastSynched;
     bool   ForceStreamDisplay;
