@@ -265,7 +265,7 @@ struct complete_stream
 
         //ATSC
         int16u source_id; //Global
-        int16u source_id_IsValid;
+        bool   source_id_IsValid;
 
         transport_stream()
         {
@@ -316,6 +316,13 @@ struct complete_stream
         struct teletext
         {
             std::map<std::string, Ztring>           Infos;
+            stream_t                                StreamKind;
+            size_t                                  StreamPos;
+
+            teletext()
+                : StreamKind(Stream_Max)
+                , StreamPos((size_t)-1)
+            {}
         };
         std::map<int16u, teletext>                  Teletexts; //Key is teletext_magazine_number
         #if MEDIAINFO_TRACE
@@ -376,12 +383,12 @@ struct complete_stream
         bool                                        IsUpdated_Info;
         bool                                        CA_system_ID_MustSkipSlices;
         bool                                        EBP_IsPresent;
-        size_t                                      IsScrambled;
+        size_t                                      Scrambled_Count;
         int16u                                      CA_system_ID;
         int16u                                      SubStream_pid;
-        #if MEDIAINFO_IBI
+        #if MEDIAINFO_IBIUSAGE
             int64u                                  Ibi_SynchronizationOffset_BeginOfFrame;
-        #endif //MEDIAINFO_IBI
+        #endif //MEDIAINFO_IBIUSAGE
         #if defined(MEDIAINFO_EIA608_YES) || defined(MEDIAINFO_EIA708_YES)
             File__Analyze::servicedescriptors ServiceDescriptors;
             bool                              ServiceDescriptors_IsPresent;
@@ -443,14 +450,14 @@ struct complete_stream
             IsRegistered=false;
             IsUpdated_IsRegistered=false;
             IsUpdated_Info=false;
-            IsScrambled=false;
+            Scrambled_Count=0;
             CA_system_ID_MustSkipSlices=false;
             CA_system_ID=0x0000;
             EBP_IsPresent=false;
             SubStream_pid=0x0000;
-            #if MEDIAINFO_IBI
+            #if MEDIAINFO_IBIUSAGE
                 Ibi_SynchronizationOffset_BeginOfFrame=(int64u)-1;
-            #endif //MEDIAINFO_IBI
+            #endif //MEDIAINFO_IBIUSAGE
             #if defined(MEDIAINFO_EIA608_YES) || defined(MEDIAINFO_EIA708_YES)
                 ServiceDescriptors_IsPresent=false;
             #endif
