@@ -21,8 +21,11 @@
     #include <MediaInfo/Multiple/File_Ancillary.h>
 #endif //defined(MEDIAINFO_ANCILLARY_YES)
 #include "MediaInfo/MediaInfo_Internal.h"
+#include "MediaInfo/TimeCode.h"
 #include <vector>
 #include <set>
+#include <bitset>
+using namespace std;
 //---------------------------------------------------------------------------
 
 namespace MediaInfoLib
@@ -76,6 +79,7 @@ protected :
     void Streams_Finish_Track_ForTimeCode (const int128u TrackUID, bool IsSourcePackage);
     void Streams_Finish_Track_ForAS11 (const int128u TrackUID);
     void Streams_Finish_Essence (int32u EssenceUID, int128u TrackUID);
+    void Streams_Finish_Essence_FillID (int32u EssenceUID, int128u TrackUID);
     void Streams_Finish_Descriptor (const int128u DescriptorUID, const int128u PackageUID);
     void Streams_Finish_Locator (const int128u DescriptorUID, const int128u LocatorUID);
     void Streams_Finish_Component (const int128u ComponentUID, float64 EditRate, int32u TrackID, int64u Origin);
@@ -133,7 +137,7 @@ protected :
     void LensUnitMetadata();
     void CameraUnitMetadata();
     void UserDefinedAcquisitionMetadata();
-    void Filler53();
+    void DMFiller();
     void Sequence();
     void SourceClip();
     void TimecodeComponent();
@@ -408,23 +412,48 @@ protected :
     void WaveAudioDescriptor_PeakEnvelopeTimestamp();           //3D30
     void WaveAudioDescriptor_PeakEnvelopeData();                //3D31
     void WaveAudioDescriptor_ChannelAssignment();               //3D31
+    void LensUnitMetadata_IrisFNumber();                        //8000
+    void LensUnitMetadata_FocusPositionFromImagePlane();        //8001
+    void LensUnitMetadata_FocusPositionFromFrontLensVertex();   //8002
+    void LensUnitMetadata_MacroSetting();                       //8003
+    void LensUnitMetadata_LensZoom35mmStillCameraEquivalent();  //8004
+    void LensUnitMetadata_LensZoomActualFocalLength();          //8005
+    void LensUnitMetadata_OpticalExtenderMagnification();       //8006
+    void LensUnitMetadata_LensAttributes();                     //8007
     void CameraUnitMetadata_CaptureGammaEquation();             //3210
+    void CameraUnitMetadata_AutoExposureMode();                 //8100
+    void CameraUnitMetadata_AutoFocusSensingAreaSetting();      //8101
+    void CameraUnitMetadata_ColorCorrectionFilterWheelSetting();//8102
     void CameraUnitMetadata_NeutralDensityFilterWheelSetting(); //8103
+    void CameraUnitMetadata_ImageSensorDimensionEffectiveWidth();//8104
+    void CameraUnitMetadata_ImageSensorDimensionEffectiveHeight();//8105
     void CameraUnitMetadata_CaptureFrameRate();                 //8106
     void CameraUnitMetadata_ImageSensorReadoutMode();           //8107
     void CameraUnitMetadata_ShutterSpeed_Angle();               //8108
+    void CameraUnitMetadata_ShutterSpeed_Time();                //8109
+    void CameraUnitMetadata_CameraMasterGainAdjustment();       //810A
     void CameraUnitMetadata_ISOSensitivity();                   //810B
+    void CameraUnitMetadata_ElectricalExtenderMagnification();  //810C
+    void CameraUnitMetadata_AutoWhiteBalanceMode();             //810D
     void CameraUnitMetadata_WhiteBalance();                     //800E
+    void CameraUnitMetadata_CameraMasterBlackLevel();           //810F
+    void CameraUnitMetadata_CameraKneePoint();                  //8110
+    void CameraUnitMetadata_CameraKneeSlope();                  //8111
+    void CameraUnitMetadata_CameraLuminanceDynamicRange();      //8112
+    void CameraUnitMetadata_CameraSettingFileURI();             //8113
     void CameraUnitMetadata_CameraAttributes();                 //8114
     void CameraUnitMetadata_ExposureIndexofPhotoMeter();        //8115
-    void CameraUnitMetadata_GammaforCDL();                      //8116
-    void CameraUnitMetadata_ASCCDLV1_2();                       //8117
+    void CameraUnitMetadata_GammaForCDL();                      //8116
+    void CameraUnitMetadata_ASC_CDL_V12();                      //8117
     void UserDefinedAcquisitionMetadata_UdamSetIdentifier();    //E000
     void UserDefinedAcquisitionMetadata_Sony_8007();
     void UserDefinedAcquisitionMetadata_Sony_E101();
     void UserDefinedAcquisitionMetadata_Sony_E102();
     void UserDefinedAcquisitionMetadata_Sony_E103();
     void UserDefinedAcquisitionMetadata_Sony_E104();
+    void UserDefinedAcquisitionMetadata_Sony_E105();
+    void UserDefinedAcquisitionMetadata_Sony_E106();
+    void UserDefinedAcquisitionMetadata_Sony_E107();
     void UserDefinedAcquisitionMetadata_Sony_E109();
     void UserDefinedAcquisitionMetadata_Sony_E10B();
     void UserDefinedAcquisitionMetadata_Sony_E201();
@@ -559,6 +588,7 @@ protected :
     bool   IsParsingEnd;
     bool   IsCheckingRandomAccessTable;
     bool   IsCheckingFooterPartitionAddress;
+    bool   IsSearchingFooterPartitionAddress;
     bool   FooterPartitionAddress_Jumped;
     bool   PartitionPack_Parsed;
     size_t IdIsAlwaysSame_Offset;
@@ -697,6 +727,7 @@ protected :
     };
     typedef std::map<int32u, essence> essences; //Key is TrackNumber
     essences Essences;
+    bitset<Stream_Max+1> StreamPos_StartAtZero; //information about the base of StreamPos (0 or 1, 1 is found in 1 file) TODO: per Essence code (last 4 bytes of the Essence header 0xTTXXTTXX)
 
     //Descriptor
     struct descriptor
@@ -1070,18 +1101,20 @@ protected :
         inline void Locators_CleanUp() {}
         inline void Locators_Test() {}
     #endif //defined(MEDIAINFO_REFERENCES_YES)
+    void NextRandomIndexMetadata();
     void TryToFinish();
 
     //Temp
     int128u EssenceContainer_FromPartitionMetadata;
     int64u PartitionMetadata_PreviousPartition;
     int64u PartitionMetadata_FooterPartition;
+    int64u RandomIndexMetadatas_MaxOffset;
     mxftimecode MxfTimeCodeForDelay;
     mxftimecode MxfTimeCodeMaterial;
     float64 DTS_Delay; //In seconds
-    bool   StreamPos_StartAtOne; //information about the base of StreamPos (0 or 1, 1 is found in 1 file)
-    string SDTI_TimeCode_StartTimecode;
-    int64u SDTI_TimeCode_StartTimecode_ms;
+    TimeCode            SDTI_TimeCode_StartTimecode;
+    size_t              SDTI_TimeCode_RepetitionCount;
+    TimeCode            SDTI_TimeCode_Previous;
     int64u SDTI_SizePerFrame;
     bool   SDTI_IsPresent; //Used to test if SDTI packet is used for Index StreamOffset calculation
     bool   SDTI_IsInIndexStreamOffset; //Used to test if SDTI packet is used for Index StreamOffset calculation
@@ -1089,6 +1122,7 @@ protected :
     int64u SystemScheme1_TimeCodeArray_StartTimecode_ms;
     int64u SystemScheme1_FrameRateFromDescriptor;
     bool   Essences_FirstEssence_Parsed;
+    bool   MayHaveCaptionsInStream;
     bool   StereoscopicPictureSubDescriptor_IsPresent;
     bool   UserDefinedAcquisitionMetadata_UdamSetIdentifier_IsSony;
     int32u Essences_UsedForFrameCount;
@@ -1151,6 +1185,52 @@ protected :
     //Config
     bool                            TimeCodeFromMaterialPackage;
 
+    //CameraUnitMetadata
+    struct acquisitionmetadata
+    {
+        string Value;
+        size_t FrameCount;
+
+        acquisitionmetadata(const string &Value_)
+            : Value(Value_)
+            , FrameCount(1)
+        {}
+    };
+    typedef std::vector<acquisitionmetadata> acquisitionmetadatalist;
+    vector<acquisitionmetadatalist*> AcquisitionMetadataLists;
+    void AcquisitionMetadata_Add(size_t Id, string Value)
+    {
+        if (!AcquisitionMetadataLists[Id])
+        {
+            AcquisitionMetadataLists[Id]=new acquisitionmetadatalist;
+            AcquisitionMetadataLists[Id]->push_back(acquisitionmetadata(Value));
+            return;
+        }
+        if ((*AcquisitionMetadataLists[Id])[AcquisitionMetadataLists[Id]->size()-1].Value == Value)
+        {
+            (*AcquisitionMetadataLists[Id])[AcquisitionMetadataLists[Id]->size()-1].FrameCount++;
+            return;
+        }
+        AcquisitionMetadataLists[Id]->push_back(acquisitionmetadata(Value));
+    }
+    vector<acquisitionmetadatalist*> AcquisitionMetadata_Sony_E201_Lists;
+    void AcquisitionMetadata_Sony_E201_Add(size_t Id, string Value)
+    {
+        if (!AcquisitionMetadata_Sony_E201_Lists[Id])
+        {
+            AcquisitionMetadata_Sony_E201_Lists[Id]=new acquisitionmetadatalist;
+            AcquisitionMetadata_Sony_E201_Lists[Id]->push_back(acquisitionmetadata(Value));
+            return;
+        }
+        if ((*AcquisitionMetadata_Sony_E201_Lists[Id])[AcquisitionMetadata_Sony_E201_Lists[Id]->size()-1].Value == Value)
+        {
+            (*AcquisitionMetadata_Sony_E201_Lists[Id])[AcquisitionMetadata_Sony_E201_Lists[Id]->size()-1].FrameCount++;
+            return;
+        }
+        AcquisitionMetadata_Sony_E201_Lists[Id]->push_back(acquisitionmetadata(Value));
+    }
+    int8u AcquisitionMetadata_Sony_CalibrationType;
+
     //Demux
     #if MEDIAINFO_DEMUX
         bool Demux_HeaderParsed;
