@@ -308,7 +308,7 @@ void File_Riff::Streams_Finish ()
             }
 
             //Hack - SMPTE ST 337, RIFF channels count is wrong
-            if (StreamKind_Last==Stream_Audio && Retrieve(Stream_Audio, StreamPos_Last, Audio_MuxingMode)==__T("AES3") && Temp->second.Parsers[0]->Get(Stream_Audio, 0, Audio_Channel_s_).empty())
+            if (StreamKind_Last==Stream_Audio && Retrieve(Stream_Audio, StreamPos_Last, Audio_MuxingMode)==__T("SMPTE ST 337") && Temp->second.Parsers[0]->Get(Stream_Audio, 0, Audio_Channel_s_).empty())
                 Clear(Stream_Audio, StreamPos_Last, Audio_Channel_s_);
 
             //Alignment
@@ -586,7 +586,7 @@ void File_Riff::Read_Buffer_Init()
     #if MEDIAINFO_DEMUX
          Demux_UnpacketizeContainer=Config->Demux_Unpacketize_Get();
          Demux_Rate=Config->Demux_Rate_Get();
-         if (Demux_Rate==0)
+         if (Demux_UnpacketizeContainer && Demux_Rate==0)
              Demux_Rate=25; //Default value
     #endif //MEDIAINFO_DEMUX
 
@@ -724,8 +724,10 @@ bool File_Riff::Header_Begin()
             return false;
 
         // Fake header
-        Element_Begin0();
-        Element_Begin0();
+        Element_Begin1("...Continued"); //TODO: better method
+        Element_ThisIsAList();
+        Element_Begin1("...Continued");
+        Element_ThisIsAList();
         if (Buffer_DataToParse_End)
             Header_Fill_Size(Buffer_DataToParse_End-(File_Offset+Buffer_Offset));
         else
@@ -987,14 +989,14 @@ bool File_Riff::BookMark_Needed()
     Stream_Structure_Temp=Stream_Structure.begin();
     if (!Stream_Structure.empty())
     {
-        #if MEDIAINFO_MD5
-            if (Config->File_Md5_Get())
+        #if MEDIAINFO_HASH
+            if (Config->File_Hash_Get().to_ulong())
             {
                 GoTo(0);
-                Md5_ParseUpTo=Stream_Structure_Temp->first;
+                Hash_ParseUpTo=Stream_Structure_Temp->first;
             }
             else
-        #endif //MEDIAINFO_MD5
+        #endif //MEDIAINFO_HASH
                 GoTo(Stream_Structure_Temp->first);
     }
     NeedOldIndex=false;
