@@ -37,6 +37,12 @@
     #include "curl/curl.h"
 #endif
 #include <ctime>
+#include <algorithm> //For Url
+#define MEDIAINFO_HMAC 1
+#if MEDIAINFO_HMAC
+    #include "hmac.h"
+    #include "base64.h"
+#endif //MEDIAINFO_HMAC
 #include "ZenLib/File.h"
 using namespace ZenLib;
 using namespace std;
@@ -48,6 +54,76 @@ using namespace std;
 namespace MediaInfoLib
 {
 
+//***************************************************************************
+// Helpers
+//***************************************************************************
+
+namespace Http
+{
+    //Helpers
+    void CutHead(std::string &Input, std::string &Output, std::string Delimiter)
+    {
+        // Remove the delimiter and everything that precedes
+        size_t Delimiter_Pos = Input.find(Delimiter);
+        if (Delimiter_Pos != std::string::npos)
+        {
+            size_t Begin    = Delimiter_Pos + Delimiter.size();
+            Output          = Input.substr(0, Delimiter_Pos);
+            Input           = Input.substr(Begin, Input.size() - Begin);
+        }
+    }
+    void CutTail(std::string &Input, std::string &Output, const std::string &Delimiter, bool KeepDelimiter=false)
+    {
+        // Remove the delimiter and everything that follows
+        size_t Delimiter_Pos = Input.find(Delimiter);
+        if (Delimiter_Pos != std::string::npos)
+        {
+            size_t Begin    = Delimiter_Pos;
+            if (!KeepDelimiter)
+                Begin+=Delimiter.size();
+            size_t End      = Input.size() - Begin;
+            Output          = Input.substr(Begin, End);
+            Input           = Input.substr(0, Delimiter_Pos);
+        }
+    }
+
+    class Url
+    {
+    public:
+        Url(const std::string &In)
+            : Host(In)
+        {
+            CutHead (Host,  Protocol,   "://"   );
+            CutTail (Host,  Search,     "?"     );
+            CutHead (Host,  User,       "@"     );
+            CutTail (Host,  Path,       "/",    true);
+            CutTail (User,  Password,   ":"     );
+            CutTail (Host,  Port,       ":"     );
+
+            std::transform(Protocol.begin(), Protocol.end(), Protocol.begin(), ::tolower);
+        }
+
+        // Members
+        std::string Protocol;
+        std::string User;
+        std::string Password;
+        std::string Host;
+        std::string Port;
+        std::string Path;
+        std::string Search;
+    };
+}
+
+Ztring Reader_libcurl_FileNameWithoutPassword(const Ztring &FileName)
+{
+    Ztring FileName_Modified(FileName);
+    size_t Begin=FileName_Modified.find(__T(':'), 6);
+    size_t End=FileName_Modified.find(__T('@'));
+    if (Begin!=string::npos && End!=string::npos && Begin<End)
+        FileName_Modified.erase(Begin, End-Begin);
+    return FileName_Modified;
+}
+
 //***************************************************************************
 // libcurl stuff
 //***************************************************************************
@@ -60,7 +136,7 @@ struct Reader_libcurl::curl_data
     char                ErrorBuffer[CURL_ERROR_SIZE];
     #if MEDIAINFO_NEXTPACKET
         CURLM*          CurlM;
-    #endif MEDIAINFO_NEXTPACKET
+    #endif //MEDIAINFO_NEXTPACKET
     struct curl_slist*  HttpHeader;
     std::bitset<32>     Status;
     String              File_Name;
@@ -80,7 +156,7 @@ struct Reader_libcurl::curl_data
     bool                Init_NotAFile;
     #if MEDIAINFO_NEXTPACKET
         bool            NextPacket;
-    #endif MEDIAINFO_NEXTPACKET
+    #endif //MEDIAINFO_NEXTPACKET
     time_t              Time_Max;
     #ifdef MEDIAINFO_DEBUG
         int64u          Debug_BytesRead_Total;
@@ -98,7 +174,7 @@ struct Reader_libcurl::curl_data
         ErrorBuffer[0]='\0';
         #if MEDIAINFO_NEXTPACKET
             CurlM=NULL;
-        #endif MEDIAINFO_NEXTPACKET
+        #endif //MEDIAINFO_NEXTPACKET
         HttpHeader=NULL;
         Ssl_IgnoreSecurity=false;
         Ssh_IgnoreSecurity=false;
@@ -106,7 +182,7 @@ struct Reader_libcurl::curl_data
         Init_NotAFile=false;
         #if MEDIAINFO_NEXTPACKET
             NextPacket=false;
-        #endif MEDIAINFO_NEXTPACKET
+        #endif //MEDIAINFO_NEXTPACKET
         Time_Max=0;
         #ifdef MEDIAINFO_DEBUG
             Debug_BytesRead_Total=0;
@@ -130,6 +206,16 @@ size_t libcurl_WriteData_CallBack(void *ptr, size_t size, size_t nmemb, void *da
     //Init
     if (!((Reader_libcurl::curl_data*)data)->Init_AlreadyDone)
     {
+        Http::Url File_URL=Http::Url(Ztring(((Reader_libcurl::curl_data*)data)->File_Name).To_UTF8());
+        if (File_URL.Protocol=="http" || File_URL.Protocol=="https")
+        {
+            long http_code = 0;
+            if (curl_easy_getinfo (((Reader_libcurl::curl_data*)data)->Curl, CURLINFO_RESPONSE_CODE, &http_code)!=CURLE_OK || http_code != 200)
+            {
+                MediaInfoLib::Config.Log_Send(0xC0, 0xFF, 0, Reader_libcurl_FileNameWithoutPassword(((Reader_libcurl::curl_data*)data)->File_Name)+__T(", ")+Ztring().From_UTF8(string((char*)ptr, size*nmemb)));
+                return size*nmemb;
+            }
+        }
         double File_SizeD;
         CURLcode Result=curl_easy_getinfo(((Reader_libcurl::curl_data*)data)->Curl, CURLINFO_CONTENT_LENGTH_DOWNLOAD, &File_SizeD);
         if (Result==CURLE_OK && File_SizeD==0)
@@ -184,16 +270,6 @@ size_t libcurl_WriteData_CallBack(void *ptr, size_t size, size_t nmemb, void *da
     return size*nmemb;
 }
 
-Ztring Reader_libcurl_FileNameWithoutPassword(const Ztring &FileName)
-{
-    Ztring FileName_Modified(FileName);
-    size_t Begin=FileName_Modified.find(__T(':'), 6);
-    size_t End=FileName_Modified.find(__T('@'));
-    if (Begin!=string::npos && End!=string::npos && Begin<End)
-        FileName_Modified.erase(Begin, End-Begin);
-    return FileName_Modified;
-}
-
 bool Reader_libcurl_HomeIsSet()
 {
     return getenv("HOME")?true:false;
@@ -406,7 +482,6 @@ size_t Reader_libcurl::Format_Test_PerParser(MediaInfo_Internal* MI, const Strin
     #endif //MEDIAINFO_NEXTPACKET
     Curl_Data->MI=MI;
     Curl_Data->File_Name=File_Name;
-    string FileName_String=Ztring(Curl_Data->File_Name).To_UTF8();
     if (MI->Config.File_TimeToLive_Get())
         Curl_Data->Time_Max=time(0)+(time_t)MI->Config.File_TimeToLive_Get();
     if (!MI->Config.File_Curl_Get(__T("UserAgent")).empty())
@@ -418,23 +493,67 @@ size_t Reader_libcurl::Format_Test_PerParser(MediaInfo_Internal* MI, const Strin
         ZtringList HttpHeaderStrings; HttpHeaderStrings.Separator_Set(0, EOL); //End of line is set depending of the platform: \n on Linux, \r on Mac, or \r\n on Windows
         HttpHeaderStrings.Write(MI->Config.File_Curl_Get(__T("HttpHeader")));
         for (size_t Pos=0; Pos<HttpHeaderStrings.size(); Pos++)
-            curl_slist_append(Curl_Data->HttpHeader, HttpHeaderStrings[Pos].To_Local().c_str());
-        curl_easy_setopt(Curl_Data->Curl, CURLOPT_HTTPHEADER, Curl_Data->HttpHeader);
+            Curl_Data->HttpHeader=curl_slist_append(Curl_Data->HttpHeader, HttpHeaderStrings[Pos].To_Local().c_str());
     }
-    curl_easy_setopt(Curl_Data->Curl, CURLOPT_URL, FileName_String.c_str());
-    curl_easy_setopt(Curl_Data->Curl, CURLOPT_FOLLOWLOCATION, 1);
-    curl_easy_setopt(Curl_Data->Curl, CURLOPT_MAXREDIRS, 3);
-    curl_easy_setopt(Curl_Data->Curl, CURLOPT_WRITEFUNCTION, &libcurl_WriteData_CallBack);
-    curl_easy_setopt(Curl_Data->Curl, CURLOPT_WRITEDATA, Curl_Data);
-    curl_easy_setopt(Curl_Data->Curl, CURLOPT_ERRORBUFFER, Curl_Data->ErrorBuffer);
-    size_t Protocol_Limit=File_Name.find(__T(":"));
-    if (Protocol_Limit!=string::npos)
+    Http::Url File_URL=Http::Url(Ztring(File_Name).To_UTF8());
+    if (!File_URL.Protocol.empty())
     {
-        Ztring Protocol=File_Name;
-        Protocol.resize(Protocol_Limit);
-        Protocol.MakeLowerCase();
+        // Amazon S3 specific credentials
+        if ((File_URL.Protocol=="http" || File_URL.Protocol=="https") && !File_URL.User.empty() && !File_URL.Password.empty())
+        {
+            //Exploding the path
+            const string Amazon_AWS_Host(".amazonaws.com");
+            const size_t Amazon_AWS_Host_Size=14;
+            size_t Amazon_Host_Pos=File_URL.Host.find(Amazon_AWS_Host);
+            if (Amazon_Host_Pos+Amazon_AWS_Host_Size==File_URL.Host.size())
+            {
+                string Amazon_S3_Bucket;
+                string Amazon_S3_CanonicalizedResource;
 
-        if (Protocol==__T("sftp") || Protocol==__T("scp"))
+                string Amazon_S3_Host(File_URL.Host, 0, File_URL.Host.size()-Amazon_AWS_Host_Size);
+                size_t Amazon_S3_Host_Pos=Amazon_S3_Host.find('.');
+                if (Amazon_S3_Host_Pos!=(size_t)-1)
+                {
+                    //Virtual-hostedstyle URL
+                    Amazon_S3_Bucket=Amazon_S3_Host.substr(0, Amazon_S3_Host_Pos);
+                    Amazon_S3_Host.erase(0, Amazon_S3_Host_Pos+1);
+                    Amazon_S3_CanonicalizedResource=File_URL.Path.substr(1);
+                }
+                else
+                {
+                    //Path-style URL
+                    size_t Bucket_Size=File_URL.Path.find('/', 1);
+                    if (Bucket_Size!=(size_t)-1)
+                    {
+                        Amazon_S3_Bucket=File_URL.Path.substr(1, Bucket_Size-1);
+                        Amazon_S3_CanonicalizedResource=File_URL.Path.substr(Bucket_Size+1);
+                    }
+                }
+                size_t Region_Pos=Amazon_S3_Host.find('-');
+                if (Region_Pos!=(size_t)-1)
+                    Amazon_S3_Host.erase(Region_Pos);
+                if (Amazon_S3_Host=="s3")
+                {
+                    // Amazon S3, computing the Authorization value
+                    // See http://docs.aws.amazon.com/AmazonS3/latest/dev/RESTAuthentication.html
+                    Ztring File_Name2(Curl_Data->File_Name);
+                    File_Name2.FindAndReplace(Ztring().From_UTF8(File_URL.User+':'+File_URL.Password+'@'), Ztring());
+                    Curl_Data->File_Name=File_Name2;
+                    char Amazon_S3_Date_Buffer[100];
+                    time_t Amazon_S3_Date_Time=time(0);
+                    strftime(Amazon_S3_Date_Buffer, sizeof(Amazon_S3_Date_Buffer), "%a, %d %b %Y %H:%M:%S +0000", gmtime(&Amazon_S3_Date_Time));
+                    string Amazon_S3_Date(Amazon_S3_Date_Buffer);
+                    string Amazon_S3_ToSign = "GET\n\n\n"+Amazon_S3_Date+"\n/"+Amazon_S3_Bucket+"/"+Amazon_S3_CanonicalizedResource;
+                    string Hmac_Result; Hmac_Result.resize(HASH_OUTPUT_SIZE);
+                    hmac_sha((int8u*)File_URL.Password.c_str(), (unsigned long)File_URL.Password.size(), (int8u*)Amazon_S3_ToSign.c_str(), (unsigned long)Amazon_S3_ToSign.size(), (int8u*)Hmac_Result.c_str(), HASH_OUTPUT_SIZE);
+                    string Amazon_S3_Authorization="AWS "+File_URL.User+":"+Base64::encode(Hmac_Result);
+                    Curl_Data->HttpHeader=curl_slist_append(Curl_Data->HttpHeader, ("Date: "+Amazon_S3_Date).c_str());
+                    Curl_Data->HttpHeader=curl_slist_append(Curl_Data->HttpHeader, ("Authorization: "+Amazon_S3_Authorization).c_str());
+                }
+            }
+        }
+
+        if (File_URL.Protocol=="sftp" || File_URL.Protocol=="scp")
         {
             if (!Curl_Data->Ssh_PublicKeyFileName.empty())
             {
@@ -443,14 +562,14 @@ size_t Reader_libcurl::Format_Test_PerParser(MediaInfo_Internal* MI, const Strin
                 {
                     #if MEDIAINFO_EVENTS
                         if (Result==CURLE_UNKNOWN_TELNET_OPTION)
-                            MediaInfoLib::Config.Log_Send(0xC0, 0xFF, 0xF1010101, Reader_libcurl_FileNameWithoutPassword(File_Name)+__T(", The Curl library you use has no support for secure connections."));
+                            MediaInfoLib::Config.Log_Send(0xC0, 0xFF, 0xF1010101, Reader_libcurl_FileNameWithoutPassword(Curl_Data->File_Name)+__T(", The Curl library you use has no support for secure connections."));
                         else
                         {
                             Ztring MessageString;
                             MessageString.From_Local(Curl_Data->ErrorBuffer);
                             if (MessageString.empty())
                                 MessageString.From_Local(curl_easy_strerror(Result));
-                            MediaInfoLib::Config.Log_Send(0xC0, 0xFF, 0, Reader_libcurl_FileNameWithoutPassword(File_Name)+__T(", ")+MessageString);
+                            MediaInfoLib::Config.Log_Send(0xC0, 0xFF, 0, Reader_libcurl_FileNameWithoutPassword(Curl_Data->File_Name)+__T(", ")+MessageString);
                         }
                         Curl_Data->ErrorBuffer[0]='\0';
                     #endif //MEDIAINFO_EVENTS
@@ -465,14 +584,14 @@ size_t Reader_libcurl::Format_Test_PerParser(MediaInfo_Internal* MI, const Strin
                 {
                     #if MEDIAINFO_EVENTS
                         if (Result==CURLE_UNKNOWN_TELNET_OPTION)
-                            MediaInfoLib::Config.Log_Send(0xC0, 0xFF, 0xF1010101, Reader_libcurl_FileNameWithoutPassword(File_Name)+__T(", The Curl library you use has no support for secure connections."));
+                            MediaInfoLib::Config.Log_Send(0xC0, 0xFF, 0xF1010101, Reader_libcurl_FileNameWithoutPassword(Curl_Data->File_Name)+__T(", The Curl library you use has no support for secure connections."));
                         else
                         {
                             Ztring MessageString;
                             MessageString.From_Local(Curl_Data->ErrorBuffer);
                             if (MessageString.empty())
                                 MessageString.From_Local(curl_easy_strerror(Result));
-                            MediaInfoLib::Config.Log_Send(0xC0, 0xFF, 0, Reader_libcurl_FileNameWithoutPassword(File_Name)+__T(", ")+MessageString);
+                            MediaInfoLib::Config.Log_Send(0xC0, 0xFF, 0, Reader_libcurl_FileNameWithoutPassword(Curl_Data->File_Name)+__T(", ")+MessageString);
                         }
                         Curl_Data->ErrorBuffer[0]='\0';
                     #endif //MEDIAINFO_EVENTS
@@ -482,19 +601,30 @@ size_t Reader_libcurl::Format_Test_PerParser(MediaInfo_Internal* MI, const Strin
 
             if (!Curl_Data->Ssh_IgnoreSecurity)
             {
+                #if !defined(MEDIAINFO_LIBCURL_DLL_RUNTIME)
+                    #if LIBCURL_VERSION_NUM >= 0x071306
+                        #define MEDIAINFO_LIBCURL_CURLOPT_SSH_KNOWNHOSTS
+                    #endif
+                #else
+                    #define MEDIAINFO_LIBCURL_CURLOPT_SSH_KNOWNHOSTS
+                #endif
+                #ifdef MEDIAINFO_LIBCURL_CURLOPT_SSH_KNOWNHOSTS
                 CURLcode Result=curl_easy_setopt(Curl_Data->Curl, CURLOPT_SSH_KNOWNHOSTS, Curl_Data->Ssh_KnownHostsFileName.c_str());
+                #else //MEDIAINFO_LIBCURL_CURLOPT_SSH_KNOWNHOSTS
+                const CURLcode Result=CURLE_UNKNOWN_TELNET_OPTION;
+                #endif //MEDIAINFO_LIBCURL_CURLOPT_SSH_KNOWNHOSTS
                 if (Result)
                 {
                     #if MEDIAINFO_EVENTS
                         if (Result==CURLE_UNKNOWN_TELNET_OPTION)
-                            MediaInfoLib::Config.Log_Send(0xC0, 0xFF, 0xF1010102, Reader_libcurl_FileNameWithoutPassword(File_Name)+__T(", The Curl library you use has no support for known_host security file, transfer would not be secure."));
+                            MediaInfoLib::Config.Log_Send(0xC0, 0xFF, 0xF1010102, Reader_libcurl_FileNameWithoutPassword(Curl_Data->File_Name)+__T(", The Curl library you use has no support for known_host security file, transfer would not be secure."));
                         else
                         {
                             Ztring MessageString;
                             MessageString.From_Local(Curl_Data->ErrorBuffer);
                             if (MessageString.empty())
                                 MessageString.From_Local(curl_easy_strerror(Result));
-                            MediaInfoLib::Config.Log_Send(0xC0, 0xFF, 0, Reader_libcurl_FileNameWithoutPassword(File_Name)+__T(", ")+MessageString);
+                            MediaInfoLib::Config.Log_Send(0xC0, 0xFF, 0, Reader_libcurl_FileNameWithoutPassword(Curl_Data->File_Name)+__T(", ")+MessageString);
                         }
                         Curl_Data->ErrorBuffer[0]='\0';
                     #endif //MEDIAINFO_EVENTS
@@ -503,7 +633,7 @@ size_t Reader_libcurl::Format_Test_PerParser(MediaInfo_Internal* MI, const Strin
             }
         }
 
-        if (Protocol==__T("ftps"))
+        if (File_URL.Protocol=="https" || File_URL.Protocol=="ftps")
         {
             if (!Curl_Data->Ssl_CertificateFileName.empty())
             {
@@ -516,7 +646,7 @@ size_t Reader_libcurl::Format_Test_PerParser(MediaInfo_Internal* MI, const Strin
                         if (MessageString.empty())
                             MessageString.From_Local(curl_easy_strerror(Result));
                         Curl_Data->ErrorBuffer[0]='\0';
-                        MediaInfoLib::Config.Log_Send(0xC0, 0xFF, 0, Reader_libcurl_FileNameWithoutPassword(File_Name)+__T(", ")+MessageString);
+                        MediaInfoLib::Config.Log_Send(0xC0, 0xFF, 0, Reader_libcurl_FileNameWithoutPassword(Curl_Data->File_Name)+__T(", ")+MessageString);
                     #endif //MEDIAINFO_EVENTS
                     return 0;
                 }
@@ -533,7 +663,7 @@ size_t Reader_libcurl::Format_Test_PerParser(MediaInfo_Internal* MI, const Strin
                         if (MessageString.empty())
                             MessageString.From_Local(curl_easy_strerror(Result));
                         Curl_Data->ErrorBuffer[0]='\0';
-                        MediaInfoLib::Config.Log_Send(0xC0, 0xFF, 0, Reader_libcurl_FileNameWithoutPassword(File_Name)+__T(", ")+MessageString);
+                        MediaInfoLib::Config.Log_Send(0xC0, 0xFF, 0, Reader_libcurl_FileNameWithoutPassword(Curl_Data->File_Name)+__T(", ")+MessageString);
                     #endif //MEDIAINFO_EVENTS
                     return 0;
                 }
@@ -550,7 +680,7 @@ size_t Reader_libcurl::Format_Test_PerParser(MediaInfo_Internal* MI, const Strin
                         if (MessageString.empty())
                             MessageString.From_Local(curl_easy_strerror(Result));
                         Curl_Data->ErrorBuffer[0]='\0';
-                        MediaInfoLib::Config.Log_Send(0xC0, 0xFF, 0, Reader_libcurl_FileNameWithoutPassword(File_Name)+__T(", ")+MessageString);
+                        MediaInfoLib::Config.Log_Send(0xC0, 0xFF, 0, Reader_libcurl_FileNameWithoutPassword(Curl_Data->File_Name)+__T(", ")+MessageString);
                     #endif //MEDIAINFO_EVENTS
                     return 0;
                 }
@@ -567,7 +697,7 @@ size_t Reader_libcurl::Format_Test_PerParser(MediaInfo_Internal* MI, const Strin
                         if (MessageString.empty())
                             MessageString.From_Local(curl_easy_strerror(Result));
                         Curl_Data->ErrorBuffer[0]='\0';
-                        MediaInfoLib::Config.Log_Send(0xC0, 0xFF, 0, Reader_libcurl_FileNameWithoutPassword(File_Name)+__T(", ")+MessageString);
+                        MediaInfoLib::Config.Log_Send(0xC0, 0xFF, 0, Reader_libcurl_FileNameWithoutPassword(Curl_Data->File_Name)+__T(", ")+MessageString);
                     #endif //MEDIAINFO_EVENTS
                     return 0;
                 }
@@ -584,7 +714,7 @@ size_t Reader_libcurl::Format_Test_PerParser(MediaInfo_Internal* MI, const Strin
                         if (MessageString.empty())
                             MessageString.From_Local(curl_easy_strerror(Result));
                         Curl_Data->ErrorBuffer[0]='\0';
-                        MediaInfoLib::Config.Log_Send(0xC0, 0xFF, 0, Reader_libcurl_FileNameWithoutPassword(File_Name)+__T(", ")+MessageString);
+                        MediaInfoLib::Config.Log_Send(0xC0, 0xFF, 0, Reader_libcurl_FileNameWithoutPassword(Curl_Data->File_Name)+__T(", ")+MessageString);
                     #endif //MEDIAINFO_EVENTS
                     return 0;
                 }
@@ -601,7 +731,7 @@ size_t Reader_libcurl::Format_Test_PerParser(MediaInfo_Internal* MI, const Strin
                         if (MessageString.empty())
                             MessageString.From_Local(curl_easy_strerror(Result));
                         Curl_Data->ErrorBuffer[0]='\0';
-                        MediaInfoLib::Config.Log_Send(0xC0, 0xFF, 0, Reader_libcurl_FileNameWithoutPassword(File_Name)+__T(", ")+MessageString);
+                        MediaInfoLib::Config.Log_Send(0xC0, 0xFF, 0, Reader_libcurl_FileNameWithoutPassword(Curl_Data->File_Name)+__T(", ")+MessageString);
                     #endif //MEDIAINFO_EVENTS
                     return 0;
                 }
@@ -618,7 +748,7 @@ size_t Reader_libcurl::Format_Test_PerParser(MediaInfo_Internal* MI, const Strin
                         if (MessageString.empty())
                             MessageString.From_Local(curl_easy_strerror(Result));
                         Curl_Data->ErrorBuffer[0]='\0';
-                        MediaInfoLib::Config.Log_Send(0xC0, 0xFF, 0, Reader_libcurl_FileNameWithoutPassword(File_Name)+__T(", ")+MessageString);
+                        MediaInfoLib::Config.Log_Send(0xC0, 0xFF, 0, Reader_libcurl_FileNameWithoutPassword(Curl_Data->File_Name)+__T(", ")+MessageString);
                     #endif //MEDIAINFO_EVENTS
                     return 0;
                 }
@@ -635,7 +765,7 @@ size_t Reader_libcurl::Format_Test_PerParser(MediaInfo_Internal* MI, const Strin
                         if (MessageString.empty())
                             MessageString.From_Local(curl_easy_strerror(Result));
                         Curl_Data->ErrorBuffer[0]='\0';
-                        MediaInfoLib::Config.Log_Send(0xC0, 0xFF, 0, Reader_libcurl_FileNameWithoutPassword(File_Name)+__T(", ")+MessageString);
+                        MediaInfoLib::Config.Log_Send(0xC0, 0xFF, 0, Reader_libcurl_FileNameWithoutPassword(Curl_Data->File_Name)+__T(", ")+MessageString);
                     #endif //MEDIAINFO_EVENTS
                     return 0;
                 }
@@ -649,13 +779,21 @@ size_t Reader_libcurl::Format_Test_PerParser(MediaInfo_Internal* MI, const Strin
                         if (MessageString.empty())
                             MessageString.From_Local(curl_easy_strerror(Result));
                         Curl_Data->ErrorBuffer[0]='\0';
-                        MediaInfoLib::Config.Log_Send(0xC0, 0xFF, 0, Reader_libcurl_FileNameWithoutPassword(File_Name)+__T(", ")+MessageString);
+                        MediaInfoLib::Config.Log_Send(0xC0, 0xFF, 0, Reader_libcurl_FileNameWithoutPassword(Curl_Data->File_Name)+__T(", ")+MessageString);
                     #endif //MEDIAINFO_EVENTS
                     return 0;
                 }
             }
         }
     }
+    string FileName_String=Ztring(Curl_Data->File_Name).To_UTF8();
+    curl_easy_setopt(Curl_Data->Curl, CURLOPT_URL, FileName_String.c_str());
+    curl_easy_setopt(Curl_Data->Curl, CURLOPT_FOLLOWLOCATION, 1);
+    curl_easy_setopt(Curl_Data->Curl, CURLOPT_MAXREDIRS, 3);
+    curl_easy_setopt(Curl_Data->Curl, CURLOPT_WRITEFUNCTION, &libcurl_WriteData_CallBack);
+    curl_easy_setopt(Curl_Data->Curl, CURLOPT_WRITEDATA, Curl_Data);
+    curl_easy_setopt(Curl_Data->Curl, CURLOPT_ERRORBUFFER, Curl_Data->ErrorBuffer);
+    curl_easy_setopt(Curl_Data->Curl, CURLOPT_HTTPHEADER, Curl_Data->HttpHeader);
 
     //Test the format with buffer
     return Format_Test_PerParser_Continue(MI);
