@@ -113,9 +113,18 @@
     #if !defined (MEDIAINFO_MD5_NO) && !defined (MEDIAINFO_MD5_YES)
         #define MEDIAINFO_MD5_NO
     #endif
+    #if !defined (MEDIAINFO_SHA1_NO) && !defined (MEDIAINFO_SHA1_YES)
+        #define MEDIAINFO_SHA1_NO
+    #endif
+    #if !defined (MEDIAINFO_SHA2_NO) && !defined (MEDIAINFO_SHA2_YES)
+        #define MEDIAINFO_SHA2_NO
+    #endif
     #if !defined (MEDIAINFO_AES_NO) && !defined (MEDIAINFO_AES_YES)
         #define MEDIAINFO_AES_NO
     #endif
+    #if !defined (MEDIAINFO_EXPORT_NO) && !defined (MEDIAINFO_EXPORT_YES)
+        #define MEDIAINFO_EXPORT_NO
+    #endif
 #endif
 
 //---------------------------------------------------------------------------
@@ -230,6 +239,26 @@
         #define MEDIAINFO_MD5 1
     #endif
 #endif
+#if !defined(MEDIAINFO_SHA1)
+    #if defined(MEDIAINFO_SHA1_NO) && defined(MEDIAINFO_SHA1_YES)
+        #undef MEDIAINFO_SHA1_NO //MEDIAINFO_SHA1_YES has priority
+    #endif
+    #if defined(MEDIAINFO_SHA1_NO)
+        #define MEDIAINFO_SHA1 0
+    #else
+        #define MEDIAINFO_SHA1 1
+    #endif
+#endif
+#if !defined(MEDIAINFO_SHA2)
+    #if defined(MEDIAINFO_SHA2_NO) && defined(MEDIAINFO_SHA2_YES)
+        #undef MEDIAINFO_SHA2_NO //MEDIAINFO_SHA2_YES has priority
+    #endif
+    #if defined(MEDIAINFO_SHA2_NO)
+        #define MEDIAINFO_SHA2 0
+    #else
+        #define MEDIAINFO_SHA2 1
+    #endif
+#endif
 #if !defined(MEDIAINFO_DEMUX)
     #if !defined(MEDIAINFO_DEMUX_NO) && !defined(MEDIAINFO_DEMUX_YES) && !MEDIAINFO_EVENTS
         #define MEDIAINFO_DEMUX_NO //MEDIAINFO_DEMUX is disabled by default if MEDIAINFO_EVENTS is set to 0
@@ -256,6 +285,20 @@
         #define MEDIAINFO_IBI 1
     #endif
 #endif
+#if !defined(MEDIAINFO_IBIUSAGE)
+    #if defined(MEDIAINFO_IBIUSAGE_NO) && defined(MEDIAINFO_IBIUSAGE_YES)
+        #undef MEDIAINFO_IBIUSAGE_NO //MEDIAINFO_IBIUSAGE_YES has priority
+    #endif
+    #if defined(MEDIAINFO_IBIUSAGE_NO)
+        #define MEDIAINFO_IBIUSAGE 0
+    #else
+        #if MEDIAINFO_ADVANCED2
+            #define MEDIAINFO_IBIUSAGE 1
+        #else //MEDIAINFO_ADVANCED2
+            #define MEDIAINFO_IBIUSAGE 0
+        #endif //MEDIAINFO_ADVANCED2
+    #endif
+#endif
 #if !defined(MEDIAINFO_READTHREAD)
     #if defined(MEDIAINFO_READTHREAD_NO) && defined(MEDIAINFO_READTHREAD_YES)
         #undef MEDIAINFO_READTHREAD_NO //MEDIAINFO_READTHREAD_YES has priority
@@ -288,6 +331,39 @@
     #endif //WINDOWS
 #endif
 
+//---------------------------------------------------------------------------
+// Export
+#if !defined(MEDIAINFO_EXPORT_NO) && !defined(MEDIAINFO_TEXT_NO) && !defined(MEDIAINFO_TEXT_YES)
+    #define MEDIAINFO_TEXT_YES
+#endif
+#if !defined(MEDIAINFO_EXPORT_NO) && !defined(MEDIAINFO_HTML_NO) && !defined(MEDIAINFO_HTML_YES)
+    #define MEDIAINFO_HTML_YES
+#endif
+#if !defined(MEDIAINFO_EXPORT_NO) && !defined(MEDIAINFO_XML_NO) && !defined(MEDIAINFO_XML_YES)
+    #define MEDIAINFO_XML_YES
+#endif
+#if !defined(MEDIAINFO_EXPORT_NO) && !defined(MEDIAINFO_CSV_NO) && !defined(MEDIAINFO_CSV_YES)
+    #define MEDIAINFO_CSV_YES
+#endif
+#if !defined(MEDIAINFO_EXPORT_NO) && !defined(MEDIAINFO_CUSTOM_NO) && !defined(MEDIAINFO_CUSTOM_YES)
+    #define MEDIAINFO_CUSTOM_YES
+#endif
+#if !defined(MEDIAINFO_EXPORT_NO) && !defined(MEDIAINFO_EBUCORE_NO) && !defined(MEDIAINFO_EBUCORE_YES)
+    #define MEDIAINFO_EBUCORE_YES
+#endif
+#if !defined(MEDIAINFO_EXPORT_NO) && !defined(MEDIAINFO_FIMS_NO) && !defined(MEDIAINFO_FIMS_YES)
+    #define MEDIAINFO_FIMS_YES
+#endif
+#if !defined(MEDIAINFO_EXPORT_NO) && !defined(MEDIAINFO_MPEG7_NO) && !defined(MEDIAINFO_MPEG7_YES)
+    #define MEDIAINFO_MPEG7_YES
+#endif
+#if !defined(MEDIAINFO_EXPORT_NO) && !defined(MEDIAINFO_PBCORE_NO) && !defined(MEDIAINFO_PBCORE_YES)
+    #define MEDIAINFO_PBCORE_YES
+#endif
+#if !defined(MEDIAINFO_EXPORT_NO) && !defined(MEDIAINFO_REVTMD_NO) && !defined(MEDIAINFO_REVTMD_YES)
+    #define MEDIAINFO_REVTMD_YES
+#endif
+
 //---------------------------------------------------------------------------
 // All in one for no parsers
 #if defined(MEDIAINFO_ALL_NO) && !defined(MEDIAINFO_MULTI_NO)
@@ -542,6 +618,9 @@
 #if !defined(MEDIAINFO_AUDIO_NO) && !defined(MEDIAINFO_AU_NO) && !defined(MEDIAINFO_AU_YES)
     #define MEDIAINFO_AU_YES
 #endif
+#if !defined(MEDIAINFO_AUDIO_NO) && !defined(MEDIAINFO_CAF_NO) && !defined(MEDIAINFO_CAF_YES)
+    #define MEDIAINFO_CAF_YES
+#endif
 #if !defined(MEDIAINFO_AUDIO_NO) && !defined(MEDIAINFO_CELT_NO) && !defined(MEDIAINFO_CELT_YES)
     #define MEDIAINFO_CELT_YES
 #endif
@@ -698,6 +777,9 @@
 #if !defined(MEDIAINFO_IMAGE_NO) && !defined(MEDIAINFO_BMP_NO) && !defined(MEDIAINFO_BMP_YES)
     #define MEDIAINFO_BMP_YES
 #endif
+#if !defined(MEDIAINFO_IMAGE_NO) && !defined(MEDIAINFO_BPG_NO) && !defined(MEDIAINFO_BPG_YES)
+    #define MEDIAINFO_BPG_YES
+#endif
 #if !defined(MEDIAINFO_IMAGE_NO) && !defined(MEDIAINFO_DDS_NO) && !defined(MEDIAINFO_DDS_YES)
     #define MEDIAINFO_DDS_YES
 #endif
