@@ -143,6 +143,7 @@ private :
             int16u  sar_height;
             int8u   aspect_ratio_idc;
             int8u   video_format;
+            int8u   video_full_range_flag;
             int8u   colour_primaries;
             int8u   transfer_characteristics;
             int8u   matrix_coefficients;
@@ -153,7 +154,7 @@ private :
             bool    fixed_frame_rate_flag;
             bool    pic_struct_present_flag;
 
-            vui_parameters_struct(xxl* NAL_, xxl* VCL_, bitstream_restriction_struct* bitstream_restriction_, int32u num_units_in_tick_, int32u time_scale_, int16u  sar_width_, int16u  sar_height_, int8u aspect_ratio_idc_, int8u video_format_, int8u colour_primaries_, int8u transfer_characteristics_, int8u matrix_coefficients_, bool aspect_ratio_info_present_flag_, bool video_signal_type_present_flag_, bool colour_description_present_flag_, bool timing_info_present_flag_, bool fixed_frame_rate_flag_, bool pic_struct_present_flag_)
+            vui_parameters_struct(xxl* NAL_, xxl* VCL_, bitstream_restriction_struct* bitstream_restriction_, int32u num_units_in_tick_, int32u time_scale_, int16u  sar_width_, int16u  sar_height_, int8u aspect_ratio_idc_, int8u video_format_, int8u video_full_range_flag_, int8u colour_primaries_, int8u transfer_characteristics_, int8u matrix_coefficients_, bool aspect_ratio_info_present_flag_, bool video_signal_type_present_flag_, bool colour_description_present_flag_, bool timing_info_present_flag_, bool fixed_frame_rate_flag_, bool pic_struct_present_flag_)
                 :
                 NAL(NAL_),
                 VCL(VCL_),
@@ -164,6 +165,7 @@ private :
                 sar_height(sar_height_),
                 aspect_ratio_idc(aspect_ratio_idc_),
                 video_format(video_format_),
+                video_full_range_flag(video_full_range_flag_),
                 colour_primaries(colour_primaries_),
                 transfer_characteristics(transfer_characteristics_),
                 matrix_coefficients(matrix_coefficients_),
@@ -409,9 +411,10 @@ private :
     void slice_layer_extension(bool svc_extension_flag);
 
     //Packets - SubElements
-    bool seq_parameter_set_data(vector<seq_parameter_set_struct*> &Data, int32u &Data_id);
+    seq_parameter_set_struct* seq_parameter_set_data(int32u &Data_id);
+    void seq_parameter_set_data_Add(vector<seq_parameter_set_struct*> &Data, const int32u Data_id, seq_parameter_set_struct* Data_Item_New);
     void seq_parameter_set_svc_extension();
-    void seq_parameter_set_mvc_extension(int32u subset_seq_parameter_sets_id);
+    void seq_parameter_set_mvc_extension(seq_parameter_set_struct* Data_Item);
     void scaling_list(int32u ScalingList_Size);
     void vui_parameters(seq_parameter_set_struct::vui_parameters_struct* &vui_parameters_Item);
     void svc_vui_parameters_extension();
@@ -542,6 +545,10 @@ private :
     int8u                               nal_ref_idc;
     int8u                               FrameRate_Divider;
     bool                                FirstPFrameInGop_IsParsed;
+    #if MEDIAINFO_ADVANCED2
+        std::vector<std::string>        Dump_SPS;
+        std::vector<std::string>        Dump_PPS;
+    #endif //MEDIAINFO_ADVANCED2
 
     //Helpers
     string                              GOP_Detect                              (string PictureTypes);
