@@ -175,6 +175,7 @@ private :
             int16u  sar_height;
             int8u   aspect_ratio_idc;
             int8u   video_format;
+            int8u   video_full_range_flag;
             int8u   colour_primaries;
             int8u   transfer_characteristics;
             int8u   matrix_coefficients;
@@ -184,7 +185,7 @@ private :
             bool    colour_description_present_flag;
             bool    timing_info_present_flag;
 
-            vui_parameters_struct(xxl* NAL_, xxl* VCL_, xxl_common* xxL_Common_, int32u num_units_in_tick_, int32u time_scale_, int16u sar_width_, int16u sar_height_, int8u aspect_ratio_idc_, int8u video_format_, int8u colour_primaries_, int8u transfer_characteristics_, int8u matrix_coefficients_, bool aspect_ratio_info_present_flag_, bool video_signal_type_present_flag_, bool frame_field_info_present_flag_, bool colour_description_present_flag_, bool timing_info_present_flag_)
+            vui_parameters_struct(xxl* NAL_, xxl* VCL_, xxl_common* xxL_Common_, int32u num_units_in_tick_, int32u time_scale_, int16u sar_width_, int16u sar_height_, int8u aspect_ratio_idc_, int8u video_format_, int8u video_full_range_flag_, int8u colour_primaries_, int8u transfer_characteristics_, int8u matrix_coefficients_, bool aspect_ratio_info_present_flag_, bool video_signal_type_present_flag_, bool frame_field_info_present_flag_, bool colour_description_present_flag_, bool timing_info_present_flag_)
                 :
                 NAL(NAL_),
                 VCL(VCL_),
@@ -195,6 +196,7 @@ private :
                 sar_height(sar_height_),
                 aspect_ratio_idc(aspect_ratio_idc_),
                 video_format(video_format_),
+                video_full_range_flag(video_full_range_flag_),
                 colour_primaries(colour_primaries_),
                 transfer_characteristics(transfer_characteristics_),
                 matrix_coefficients(matrix_coefficients_),
@@ -223,6 +225,7 @@ private :
         size_t  AnnexB_Buffer_Size;
         #endif //MEDIAINFO_DEMUX
         int32u  profile_space;
+        bool    tier_flag;
         int32u  profile_idc;
         int32u  level_idc;
         int32u  pic_width_in_luma_samples;
@@ -248,7 +251,7 @@ private :
         int8u   ChromaArrayType() {return separate_colour_plane_flag?0:chroma_format_idc;}
 
         //Constructor/Destructor
-        seq_parameter_set_struct(vui_parameters_struct* vui_parameters_, int32u profile_space_, int32u profile_idc_, int32u level_idc_, int32u pic_width_in_luma_samples_, int32u pic_height_in_luma_samples_, int32u conf_win_left_offset_, int32u conf_win_right_offset_, int32u conf_win_top_offset_, int32u conf_win_bottom_offset_, int8u video_parameter_set_id_, int8u chroma_format_idc_, bool separate_colour_plane_flag_, int8u log2_max_pic_order_cnt_lsb_minus4_, int8u bit_depth_luma_minus8_, int8u bit_depth_chroma_minus8_, bool general_progressive_source_flag_, bool general_interlaced_source_flag_, bool general_frame_only_constraint_flag_)
+        seq_parameter_set_struct(vui_parameters_struct* vui_parameters_, int32u profile_space_, bool tier_flag_, int32u profile_idc_, int32u level_idc_, int32u pic_width_in_luma_samples_, int32u pic_height_in_luma_samples_, int32u conf_win_left_offset_, int32u conf_win_right_offset_, int32u conf_win_top_offset_, int32u conf_win_bottom_offset_, int8u video_parameter_set_id_, int8u chroma_format_idc_, bool separate_colour_plane_flag_, int8u log2_max_pic_order_cnt_lsb_minus4_, int8u bit_depth_luma_minus8_, int8u bit_depth_chroma_minus8_, bool general_progressive_source_flag_, bool general_interlaced_source_flag_, bool general_frame_only_constraint_flag_)
             :
             vui_parameters(vui_parameters_),
             #if MEDIAINFO_DEMUX
@@ -257,6 +260,7 @@ private :
             #endif //MEDIAINFO_DEMUX
             profile_space(profile_space_),
             profile_idc(profile_idc_),
+            tier_flag(tier_flag_),
             level_idc(level_idc_),
             pic_width_in_luma_samples(pic_width_in_luma_samples_),
             pic_height_in_luma_samples(pic_height_in_luma_samples_),
@@ -434,6 +438,7 @@ private :
     int8u   profile_space;
     int8u   profile_idc;
     int8u   level_idc;
+    bool    tier_flag;
     bool    general_progressive_source_flag;
     bool    general_interlaced_source_flag;
     bool    general_frame_only_constraint_flag;
