@@ -22,6 +22,9 @@
 
 //---------------------------------------------------------------------------
 #include "MediaInfo/Video/File_Vc3.h"
+#if defined(MEDIAINFO_CDP_YES)
+    #include "MediaInfo/Text/File_Cdp.h"
+#endif
 //---------------------------------------------------------------------------
 
 namespace MediaInfoLib
@@ -252,7 +255,7 @@ const char* Vc3_CLR_FromCID (int32u CompressionID)
 const char* Vc3_SSC[2]=
 {
     "4:2:2",
-    "", // 4:4:4
+    "4:4:4",
 };
 
 //---------------------------------------------------------------------------
@@ -295,10 +298,23 @@ File_Vc3::File_Vc3()
     Frame_Count_Valid=2;
     FrameRate=0;
 
+    //Parsers
+    #if defined(MEDIAINFO_CDP_YES)
+        Cdp_Parser=NULL;
+    #endif //defined(MEDIAINFO_CDP_YES)
+
     //Temp
     FFC_FirstFrame=(int8u)-1;
 }
 
+//---------------------------------------------------------------------------
+File_Vc3::~File_Vc3()
+{
+    #if defined(MEDIAINFO_CDP_YES)
+        delete Cdp_Parser; //Cdp_Parser=NULL;
+    #endif //defined(MEDIAINFO_CDP_YES)
+}
+
 //***************************************************************************
 // Streams management
 //***************************************************************************
@@ -323,7 +339,8 @@ void File_Vc3::Streams_Fill()
             Fill(Stream_Video, 0, Video_BitDepth, Vc3_SBD_FromCID(CID));
         Fill(Stream_Video, 0, Video_ScanType, Vc3_SST_FromCID(CID));
         Fill(Stream_Video, 0, Video_ColorSpace, Vc3_CLR_FromCID(CID));
-        Fill(Stream_Video, 0, Video_ChromaSubsampling, Vc3_SSC_FromCID(CID));
+        if (!strcmp(Vc3_CLR_FromCID(CID), "YUV")) // YUV
+            Fill(Stream_Video, 0, Video_ChromaSubsampling, Vc3_SSC_FromCID(CID));
     }
     else
     {
@@ -331,13 +348,38 @@ void File_Vc3::Streams_Fill()
         Fill(Stream_Video, 0, Video_Height, ALPF*(SST?2:1));
         Fill(Stream_Video, 0, Video_BitDepth, Vc3_SBD(SBD));
         Fill(Stream_Video, 0, Video_ScanType, Vc3_SST[SST]);
-        Fill(Stream_Video, 0, Video_ColorSpace, Vc3_CLR[SSC]);
-        Fill(Stream_Video, 0, Video_ChromaSubsampling, Vc3_SSC[CLR]);
+        Fill(Stream_Video, 0, Video_ColorSpace, Vc3_CLR[CLR]);
+        if (CLR==0) // YUV
+            Fill(Stream_Video, 0, Video_ChromaSubsampling, Vc3_SSC[SSC]);
     }
     if (FFC_FirstFrame!=(int8u)-1)
         Fill(Stream_Video, 0, Video_ScanOrder, Vc3_FFC_ScanOrder[FFC_FirstFrame]);
 }
 
+//---------------------------------------------------------------------------
+void File_Vc3::Streams_Finish()
+{
+    #if defined(MEDIAINFO_CDP_YES)
+        if (Cdp_Parser && !Cdp_Parser->Status[IsFinished] && Cdp_Parser->Status[IsAccepted])
+        {
+            Finish(Cdp_Parser);
+            for (size_t StreamPos=0; StreamPos<Cdp_Parser->Count_Get(Stream_Text); StreamPos++)
+            {
+                Merge(*Cdp_Parser, Stream_Text, StreamPos, StreamPos);
+                Ztring MuxingMode=Cdp_Parser->Retrieve(Stream_Text, StreamPos, "MuxingMode");
+                Fill(Stream_Text, StreamPos, "MuxingMode", __T("VC-3 / Nexio user data / ")+MuxingMode, true);
+            }
+
+            Ztring LawRating=Cdp_Parser->Retrieve(Stream_General, 0, General_LawRating);
+            if (!LawRating.empty())
+                Fill(Stream_General, 0, General_LawRating, LawRating, true);
+            Ztring Title=Cdp_Parser->Retrieve(Stream_General, 0, General_Title);
+            if (!Title.empty() && Retrieve(Stream_General, 0, General_Title).empty())
+                Fill(Stream_General, 0, General_Title, Title);
+        }
+    #endif //defined(MEDIAINFO_CDP_YES)
+}
+
 //***************************************************************************
 // Buffer - Per element
 //***************************************************************************
@@ -438,6 +480,19 @@ bool File_Vc3::Demux_UnpacketizeContainer_Test()
 }
 #endif //MEDIAINFO_DEMUX
 
+//***************************************************************************
+// Buffer - Global
+//***************************************************************************
+
+//---------------------------------------------------------------------------
+void File_Vc3::Read_Buffer_Unsynched()
+{
+    #if defined(MEDIAINFO_CDP_YES)
+        if (Cdp_Parser)
+            Cdp_Parser->Open_Buffer_Unsynch();
+    #endif //defined(MEDIAINFO_CDP_YES)
+}
+
 //***************************************************************************
 // Buffer - Per element
 //***************************************************************************
@@ -492,6 +547,8 @@ void File_Vc3::Data_Parse()
         CodingControlB();
         Skip_XX( 3,                                             "Reserved");
         TimeCode();
+        Skip_XX(38,                                             "Reserved");
+        UserData();
 
         Skip_XX(640-Element_Offset,                             "ToDo");
     }
@@ -699,6 +756,62 @@ void File_Vc3::TimeCode()
     Element_End0();
 }
 
+//---------------------------------------------------------------------------
+void File_Vc3::UserData()
+{
+    //Parsing
+    Element_Begin1("User Data");
+    int8u UserDataLabel;
+
+    BS_Begin();
+    Get_S1 (4, UserDataLabel,                                   "User Data Label");
+    Mark_0();
+    Mark_0();
+    Mark_0();
+    Mark_1();
+    BS_End();
+
+    switch (UserDataLabel)
+    {
+        case 0x00: Skip_XX(260,                                 "Reserved"); break;
+        case 0x08: UserData_8(); break;
+        default  : Skip_XX(260,                                 "Reserved for future use");
+    }
+
+    Element_End0();
+}
+
+//---------------------------------------------------------------------------
+void File_Vc3::UserData_8()
+{
+    if (Element_Offset + 0x104 < Element_Size
+        && Buffer[Buffer_Offset + (size_t)Element_Offset + 0xBA] == 0x96
+        && Buffer[Buffer_Offset + (size_t)Element_Offset + 0xBB] == 0x69)
+    {
+        Skip_XX(0xBA,                                           "Nexio private data?");
+        #if defined(MEDIAINFO_CDP_YES)
+            if (Cdp_Parser==NULL)
+            {
+                Cdp_Parser=new File_Cdp;
+                Open_Buffer_Init(Cdp_Parser);
+                Frame_Count_Valid=300;
+            }
+            if (!Cdp_Parser->Status[IsFinished])
+            {
+                ((File_Cdp*)Cdp_Parser)->AspectRatio=16.0/9.0;
+                Open_Buffer_Continue(Cdp_Parser, Buffer + Buffer_Offset + (size_t)Element_Offset, 0x49);
+            }
+            Element_Offset+=0x49;
+            Skip_B1(                                            "Nexio private data?");
+        #else //MEDIAINFO_CDP_YES
+            Skip_XX(0x4A                                        "CDP data");
+        #endif //MEDIAINFO_CDP_YES
+    }
+    else
+        Skip_XX(260,                                            "Nexio private data?");
+
+}
+
 //***************************************************************************
 // C++
 //***************************************************************************
