@@ -36,10 +36,12 @@ public :
 
     //constructor/Destructor
     File_Vc3();
+    ~File_Vc3();
 
 private :
     //Streams management
     void Streams_Fill();
+    void Streams_Finish();
 
     //Buffer - Synchro
     bool Synchronize();
@@ -50,6 +52,9 @@ private :
     bool Demux_UnpacketizeContainer_Test();
     #endif //MEDIAINFO_DEMUX
 
+    //Buffer - Global
+    void Read_Buffer_Unsynched();
+
     //Buffer - Per element
     bool Header_Begin ();
     void Header_Parse ();
@@ -63,8 +68,14 @@ private :
     void CodingControlB();
     void TimeCode();
     void UserData();
+    void UserData_8();
     void MacroblockScanIndices();
 
+    //Parsers
+    #if defined(MEDIAINFO_CDP_YES)
+        File__Analyze*  Cdp_Parser;
+    #endif //defined(MEDIAINFO_CDP_YES)
+
     //Temp
     int32u  CID;
     bool    CRCF;
